#ifndef COLORDEF_HPP
#define COLORDEF_HPP
//----------------------------------------------------------------------------------------
/// @file Common COLORREF color definitions
//----------------------------------------------------------------------------------------
// Includes
//----------------------------------------------------------------------------------------
#if defined(MIC_VCMFC)
#include <wingdi.h>
#endif

//========================================================================================
#if !defined(MIC_VCMFC)
using COLORREF = uint_32;
constexpr COLORREF RGB(COLORREF uiRed, COLORREF uiGreen, COLORREF uiBlue)
{
    return ((uiBlue & 0xFF) << 16) | ((uiGreen) << 8) | (uiRed & 0xFF);
}

constexpr uint_8 GetRValue(COLORREF uiRGB)
{
    return static_cast<uint_8>(uiRGB & 0xFF);
}

constexpr uint_8 GetGValue(COLORREF uiRGB)
{
    return static_cast<uint_8>((uiRGB >> 8) & 0xFF);
}

constexpr uint_8 GetBValue(COLORREF uiRGB)
{
    return static_cast<uint_8>((uiRGB >> 16) & 0xFF);
}

// The API doc url for the windows GDI constants these are based on is:
// https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-wmf/2af5f7e4-9abb-4fb4-b428-d739c8b23829
constexpr int PS_SOLID = 0x00000000;
constexpr int PS_DASH = 0x00000001;
constexpr int PS_DOT = 0x00000002;
constexpr int PS_NULL = 0x00000005;

#endif

static_assert(sizeof(COLORREF) == 4, "COLORREF must be 4 bytes");

//========================================================================================
namespace NColorDef
{

    /// RGB color definitions encoded as COLORREF unsigned integers.
    enum : COLORREF
    {
        ceBlack = RGB(0, 0, 0),
        ceWhite = RGB(255, 255, 255),

        ceMatplotLibC0 = RGB(0x1f, 0x77, 0xb4),
        ceMatplotLibC1 = RGB(0xff, 0x7f, 0x0e),
        ceMatplotLibC2 = RGB(0x2c, 0xa0, 0x2c),
        ceMatplotLibC3 = RGB(0xd6, 0x27, 0x29),
        ceMatplotLibC4 = RGB(0x94, 0x67, 0xbd),
        ceMatplotLibC5 = RGB(0x8c, 0x56, 0x4b),
        ceMatplotLibC6 = RGB(0xe3, 0x77, 0xc2),
        ceMatplotLibC7 = RGB(0x7f, 0x7f, 0x7f),
        ceMatplotLibC8 = RGB(0xbc, 0xbd, 0x22),
        ceMatplotLibC9 = RGB(0x17, 0xbe, 0xcf),

        ceLightBlack = RGB(105, 105, 105),
        ceDarkGray = RGB(128, 128, 128),
        ceGray = RGB(160, 160, 160),
        ceLightGray = RGB(192, 192, 192),
        ceGrayGreen = RGB(160, 192, 160),

        ceDarkBlue = RGB(0, 0, 130),
        ceBlue = RGB(0, 0, 225),
        ceBrightBlue = RGB(0, 0, 255),
        ceDarkBlueGreen = RGB(0, 128, 128),
        ceLightBlue = RGB(0, 192, 255),
        ceCyan = RGB(0, 255, 255),
        ceAquamarine = RGB(70, 230, 192),
        ceBlueGrey = RGB(89, 150, 240),

        ceDarkGreen = RGB(0, 128, 0),
        ceGreen = RGB(0, 192, 0),
        ceBrightGreen = RGB(0, 220, 0),
        ceGasFlowGreen = RGB(0, 198, 50),
        ceLimeGreen = RGB(128, 252, 0),
        ceOlive = RGB(128, 128, 0),

        ceMaroon = RGB(128, 0, 0),
        ceDarkRed = RGB(192, 0, 0),
        ceRed = RGB(224, 0, 0),
        ceBrightRed = RGB(255, 0, 0),

        ceMustardYellow = RGB(230, 230, 20),
        ceGold = RGB(255, 201, 14),
        ceYellow = RGB(255, 255, 0),
        ceLightYellow = RGB(255, 255, 128),

        ceMagenta = RGB(255, 0, 255),
        ceBrightPink = RGB(255, 20, 147),

        ceLightOrange = RGB(255, 128, 64),
        ceOrange = RGB(255, 128, 0),

        cePurple = RGB(128, 0, 128),
        ceLightPurple = RGB(164, 72, 164),

        ceBrown = RGB(185, 122, 87),
    };
    namespace NLiveGraph
    {
        /// Live graph colors
        enum : COLORREF
        {
            ceDarkBlue          = RGB(   0,  60, 120 ),
            ceCyan              = RGB(   0, 205, 205 ),
            cePurple            = RGB( 158,   0, 158 ),
            ceDarkGreen         = RGB(   0, 225,   0 ),
            ceDarkBlueGreen     = RGB(   0, 158, 158 ),
            ceYellow            = RGB( 158, 158,   0 ),
        };
    }
    namespace NDiagWidgets
    {
        /// Diagnostic widget colors
        enum : COLORREF
        {
            ceDarkBlue          = RGB(   0,   0, 179 ),
            ceDarkRed           = RGB( 179,   0,   0 ),
            ceLightGray         = RGB( 180, 180, 180 ),
        };
    }
}

#endif // COLORDEF_HPP
