#ifndef COMCRC_HPP
#define COMCRC_HPP

// ================================================================================================
/// This is the class for objects that can calculate a CRC value.
///
/// Construction and destrucion is trivial, (except for the initial one), so the user can create
/// these objects as needed.
class CCommCRC
{
public:
    /// Initialize the tables if not already done.
    CCommCRC();

    /// This calculates the crc value of the given segment. Multiple segments can be calculated in
    /// order. and will result in the same crc value as having a single crc calculated for all.
    uint_16 operator()(const char* pData, size_t uiSize) { return operator()(pData, uiSize, 0); }

    /// This calculates the crc value of the given segment. Multiple segments can be calculated in
    /// order. and will result in the same crc value as having a single crc calculated for all.
    uint_16 operator()(const char* pData, size_t uiSize, uint_16 uiCRC);

private:
    DECLARE_MSG()
};

#endif  // COMCRC_HPP
