#ifndef COMSTRMB_HPP
#define COMSTRMB_HPP
//-------------------------------------------------------------------------------------------------
// Includes
//-------------------------------------------------------------------------------------------------
#include "comstrtb.hpp"

//  ===============================================================================================
/// This class handles the mass (embedded) side of the startup connection. A single object of this
/// class should be created to handle the connection with the front end.
class CCommStartupMassBase : public CCommStartupBase
{
public:
    CCommStartupMassBase(CCommDataLink* pLink);

protected:
    // CCommTransport implementation.
    virtual void MessageReset(ID uiID, const char* pData, SIZE uiSize) /*override*/;
    virtual char* GetMemory(ID uiID, SIZE uiSize) /*override*/;
    virtual void MessageRecieved(ID uiID, char* pData, SIZE uiSize) /*override*/;

private:
    /// This is called if the other end of the link requested a reset of the communications
    /// subsystem. See Init() above.
    virtual void ResetChannel()
    {
        CCommStartupBase::ResetChannel();
        MessageReset(0, 0, 0);
    }

    /// Called as a result of the front end sending a query command. This will fill in the query
    /// data structure, and send it to the front end.
    virtual void OnQuery() = 0;

    /// Called as a result of the front end sending a queryError command. This will fill in the
    /// queryerror data structure, and send it to the front end.
    virtual void OnQueryError() = 0;

    /// This is called when the front end sends a reset command. It will send the Reset Recv
    /// command. Once that is sent The DoReset command is called.  to do the actual reset.
    void OnReset();

    /// This is called when the application should reset itself to execute from the boot block..
    virtual void DoReset() = 0;

    /// This is called when the front end sends an execute command. It will send the execure Recv
    /// command. Once that is sent The DoExecute command is called.to do the actual reset.
    void OnExecute();

    /// This is called when the application should reset itself to execute the application.
    virtual void DoExecute() = 0;

    /// @{
    /// The parameters of the blocked download.
    virtual size_t FlashBlockSize() const = 0;
    virtual size_t ComBlockSize() const = 0;
    /// @}

    /// See if it is apossible to download this data.
    virtual EDownloadResult CanDownload(const SDownloadInfo& rsInfo) const = 0;

    /// This is called to program that section of the download.
    virtual bool DoDownload(char* pData, uint_32 uiStart, uint_32 uiSize, const SDownloadInfo& rsInfo)
        = 0;

    /// Check to see if the download proceeded OK.
    virtual EDownloadResult CheckDownload(const SDownloadInfo& rsInfo) const = 0;

    /// This is called when the caller wants to set the IP address for the next time the applicaiton
    /// starts.
    virtual void OnSetIPData(const SIPData& rData) = 0;

    /// This is called when the front-end hjas asked that all system errors be cleared.
    virtual void OnClearErrors(void) = 0;

    /// This is called when this receives a download message. It sets up the transfer.
    void OnDownload();

    /// This is called whenever this received a block of data from the front end. It programs the
    /// flash, and requests the next block.
    void OnDownloadBlock();

    bool m_fReseting;   ///<  Handle the flags to see which Reset command is to be called.
    bool m_fExecuting;  ///<  Handle the flags to see which Reset command is to be called.

    /// @{
    ///  The Information about the file in progress.
    SDownloadInfo m_DownloadInfo;
    char m_achDownloadInfoBuff[sizeof(uint_8) + sizeof(uint_32)];
    /// @}

    /// The information about the last requested block from the Front end.
    SDownloadBlockReq m_BlockReq;
    /// The information to be sent at the end of the download.
    char m_achDownloadResultBuff[sizeof(uint_8)];

    char* m_pBlockMem;  ///<  The block of memory to house the data to be programmed.

    /// Download com block offset into the 64kb flash block (downloading com blocks rather than
    /// flash blocks is done purely to facilitate more timely progress displays at the front end)
    uint_32 m_uiComStart;

    /// Check the session ID provided with the current. If the current ID is zero, set the
    /// session ID to the provided value; if non-zero, ignore the provided value. Return
    /// the session ID to the frontend.
    void OnGetSetSessionID(uint_32 uiSessionID);
    /// The session ID provided by the frontend. Used by the frontend to determine whether
    /// the instrument has restarted since the last successful connection. Zero on
    /// construction.
    uint_32 m_uiSessionID;
    /// Comm buffer for session ID message data.
    uint_32 m_uiSessionIDBuffer;

    /// The information to be sent on SetIPData.
    SIPData m_IPData;

    DECLARE_MSG()
};
#endif  // COMSTRMB_HPP
