#ifndef EVENTGROUP_HPP
#define EVENTGROUP_HPP
//-----------------------------------------------------------------------------
// Library:	    baselib
// Description:	
//
//      DM643 Sventgroup functionality for a single process (eventloop)
//      armlinux process. 
//
// Contents:
//
//      class   CEventGroup
//
//-----------------------------------------------------------------------------
// Includes
//-----------------------------------------------------------------------------
#if defined(MIC_DM643)
#include <cpp/nucpp.h>
#endif
//-----------------------------------------------------------------------------
// Globals, Constants, Defines, Macros, Forward References
//-----------------------------------------------------------------------------
class CEventGroupArmImp;

/* ========================================================================
** CEventGroup
** ======================================================================== */
class CEventGroup
{
public:
    CEventGroup();
    //  Create and initialize the event. 

    void    Set( uint_32 iBits );
    //  Sets the bits in the event group.

    void    Clear( uint_32 iBits = (uint_32)(-1) );
    //  Clears the bits requested in the event group. 

    bool    RetrieveMS( uint_32 iBits, uint_32* puRet, uint_32 ulTimeMS );
    void    Retrieve( uint_32 iBits, uint_32* puRet );
    //  retuns true if the one or more of the bits got set before the timeout
    //  expired. 
    
#if defined(MIC_DM643)

    EventGroup& GetEventGroup() { return m_cEvents; }

#endif

protected:

private:

#if defined(MIC_DM643)
    EventGroup  m_cEvents;
#endif
    
    CEventGroupArmImp*  m_pImplementation;
    //  The implementation of the WaitHandleEvents() functionality on the arm
    //  system. 

    DECLARE_MSG()
};

// ----------------------------------------------------------------------------
//  Inline implementation for dm643
//
#if defined(MIC_DM643)
inline  void    CEventGroup::Set( uint_32 iBits )
{
    m_cEvents.Set( iBits, NU_OR );
}
inline  void    CEventGroup::Clear( uint_32 iBits )
{
    m_cEvents.Set( ~iBits, NU_AND );
}
inline  void    CEventGroup::Retrieve( uint_32 iBits, uint_32* puRet )
{
    UNSIGNED    uRet = 0;
    m_cEvents.Retrieve( iBits, NU_OR_CONSUME, &uRet, NU_SUSPEND );
    if ( puRet )
        *puRet = (uint_32)uRet;
}

#endif

#if defined(MIC_DM643)
inline  bool    CEventGroup::RetrieveMS( uint_32 iBits,
                                         uint_32* puRet,
                                         uint_32 ulTimeMS )
{
    UNSIGNED    uRet = 0;
	STATUS	stat = m_cEvents.RetrieveMS( iBits, NU_OR_CONSUME, &uRet, 
                                         ulTimeMS );
    if ( puRet )
        *puRet = (uint_32)uRet;
    return ( stat == NU_SUCCESS ? true : false );
}
#endif

//-----------------------------------------------------------------------------
#endif // EVENTGROUP_HPP
