#ifndef JSON_UTIL_HPP
#define JSON_UTIL_HPP
//-----------------------------------------------------------------------------
/// @file
/// Utilitiy functions wor working with json data.
//-----------------------------------------------------------------------------
// Includes
//-----------------------------------------------------------------------------
#include "../rapidjson/fwd.h"
#include "../rapidjson/document.h"
#include <string>
#include <vector>

//-----------------------------------------------------------------------------
// Globals, Constants, Defines, Macros, Forward References
//-----------------------------------------------------------------------------
class CStr;

///@{ Convert to json for Fundamental types
rapidjson::Value ToJson(rapidjson::Document::AllocatorType& rAlloc, const CStr& cData);
rapidjson::Value ToJson(rapidjson::Document::AllocatorType& rAlloc, const std::string& cszData);
///@}

/// @returns json vector of the @p cvData.  The type @p T must be of type that has ToJson(rAlloc,
/// const T&) defined, or this template function can be specialized. See below.
template<typename T>
rapidjson::Value ToJson(rapidjson::Document::AllocatorType& rAlloc, const std::vector<T>& cvData)
{
    auto value = rapidjson::Value(rapidjson::kArrayType);
    for(const auto& cItem : cvData)
        value.PushBack(ToJson(rAlloc, cItem).Move(), rAlloc);
    return value;
}

///@ returns json vector of the types.
template<>
rapidjson::Value ToJson<double>(rapidjson::Document::AllocatorType& rAlloc,
    const std::vector<double>& cvData);

/// @returns the formatted string for the json @p cDoc
std::string ToStdString(const rapidjson::Document& cDoc);
std::string ToStdString(const rapidjson::Value& cValue);

/// @returns the json document parsed from @p cszJson
rapidjson::Document ParseJson(const std::string& cszJson);

/// @returns true if the @p cszJson is validly formatted json.
bool IsJsonValid(const std::string& cszJson);

///@{ @returns true if the @p doc validates to the cszSchema
bool IsJsonValid(const rapidjson::Document& cDoc, const std::string& cszSchema);
bool IsJsonValid(const rapidjson::Value& cDoc, const std::string& cszSchema);
///@}

#endif // JSON_UTIL_HPP
