#ifndef METADATA_TRAITS_HPP
#define METADATA_TRAITS_HPP
//------------------------------------------------------------------------------
/// @file
/// Type trait info for the metadata system. Used to identify expected available
/// type functionality or type usage.
//------------------------------------------------------------------------------
namespace NMeta
{
    /// Metadata type trait for iterable classes. A class that is iterable must contain
    /// a type definition for the apparent enclosed type T, e.g.,
    ///
    ///     typedef T value_type; // or using value_type = T;
    ///
    /// It must also implement the following member functions;
    ///
    ///     1) bool empty() const,
    ///     2) size_t size() const,
    ///     3) T& operator[](n) and const T& operator[](n) const,
    ///     4) U begin() and const U begin() const, where U is iterator-like access to the
    ///        container elements providing valid unary incrementation, e.g., T*,
    ///     5) U end() and const U end() const
    ///
    struct IsIterable {};
    /// Metadata type trait for annotated data-containing base classes.
    struct IsDataContainer {};
}

#endif // METADATA_TRAITS_HPP
