#ifndef NUMPEAK_HPP
#define NUMPEAK_HPP
//-----------------------------------------------------------------------------
/// @file
/// Classes used to find peaks.
//-----------------------------------------------------------------------------
// Includes
//-----------------------------------------------------------------------------
#ifndef NUMVECT_HPP
#include "numvect.hpp"
#endif
//-----------------------------------------------------------------------------
// Globals, Constants, Defines, Macros, Forward References
//-----------------------------------------------------------------------------

// ============================================================================
class CNumPeakList
{
public:
    typedef CNumVector<size_t> CIndexVector;
    /// std::multimap makes accessing and indexing elements very inconvenient.
    /// As a result a map of vectors was chosen as a replacement.
    typedef CNumVector<CIndexVector> C2DVector;

    /// Default constructor.
    CNumPeakList() {}

    /// Find the peaks
    static CNumPeakList Find(const CNumVector<double>& cradDifferential,
        const CNumVector<double>& cradCumulative,
        double dMinValleyFraction,
        double dMinPeakFraction);

    /// Filter out differential data at indices where the data is not within
    /// the range provided by adMin[i] and adMax[i] and then find peaks from
    /// remaining data.
    /// crmMultiMap has to be filled by the caller since comparisons need to be
    /// done using the formatter's operators.
    static CNumPeakList Find(const CNumVector<double>& cradDifferential,
        const CNumVector<double>& cradCumulative,
        const C2DVector& craWidths,
        const CNumVector<double>& cradMin,
        const CNumVector<double>& cradMax);

    /// Create the peaks from the boundary conditions table.
    static CNumPeakList CreateFromBounds(const CNumVector<double>& crradData,
        const CNumVector<double>& cradBounds,
        const CNumVector<double>& cradMin,
        const CNumVector<double>& cradMax);

    /// Access to the peak limits.
    size_t NumPeaks() const { return m_auiLower.Dim(); }
    size_t Mode(size_t i) const { return m_auiMode[i]; }
    size_t LowerBound(size_t i) const { return m_auiLower[i]; }
    size_t UpperBound(size_t i) const { return m_auiUpper[i]; }

private:
    CNumPeakList(const CNumVector<size_t>& crauiMode,
        const CNumVector<size_t>& crauiLower,
        const CNumVector<size_t>& crauiUpper)
        : m_auiMode(crauiMode),
          m_auiLower(crauiLower),
          m_auiUpper(crauiUpper)
    {
    }

    CNumVector<size_t> m_auiMode;
    CNumVector<size_t> m_auiLower;
    CNumVector<size_t> m_auiUpper;

    DECLARE_MSG()
};

#endif // NUMPEAK_HPP
