#ifndef NUMSVD_HPP
#define NUMSVD_HPP
//-----------------------------------------------------------------------------
// Includes
//-----------------------------------------------------------------------------
#ifndef NUMFCN_HPP
#include "numfcn.hpp"
#endif
#ifndef NUMMAT_HPP
#include "nummat.hpp"
#endif
//-----------------------------------------------------------------------------
// Globals, Constants, Defines, Macros, Forward References
//-----------------------------------------------------------------------------
// ============================================================================
/// This class implements the CNumLongFunction interface for the problem
/// of Singular value decomposition. See numerical recipies in C for the
/// description of the use and algorithms of this class.
class CNumSVD : public CNumLongFunction
{
public:
    CNumSVD() {}
    CNumSVD(const CNumMatrix<float_64>& a) { Set(a); }
    ~CNumSVD() {}

    void Set(const CNumMatrix<float_64>& a) { m_U = a; }

    void ZeroBelowRelative(float_64 dEps);
    void BackSub(const CNumVector<float_64>& b, CNumVector<float_64>& x);

    const CNumMatrix<float_64>& U()
    {
        Run();
        return m_U;
    }
    const CNumVector<float_64>& W()
    {
        Run();
        return m_W;
    }
    const CNumMatrix<float_64>& V()
    {
        Run();
        return m_V;
    }

protected:
#if defined(MIC_DM643)
    virtual void InitExec();
    virtual void StopExec();
    virtual bool NextStep();
#else
    virtual void InitExec() override;
    virtual void StopExec() override;
    virtual bool NextStep() override;
#endif

private:
    //  Output paremeters.
    CNumMatrix<float_64> m_U;  //  Input also get coverted.
    CNumVector<float_64> m_W;
    CNumMatrix<float_64> m_V;
};
#endif // NUMSVD_HPP
