#ifndef RSDENSITY_GRAPH_VIEW_HPP
#define RSDENSITY_GRAPH_VIEW_HPP
//-------------------------------------------------------------------------------------------------
/// @file
/// Density graphics
//-------------------------------------------------------------------------------------------------
// Includes
//-------------------------------------------------------------------------------------------------
#include "rsitemview.hpp"

//-------------------------------------------------------------------------------------------------
// Globals, Constants, Defines, Macros, Forward References
//-------------------------------------------------------------------------------------------------

class CRSGraphAxisData;
class CRSGraphAxisView;
class CRSGraphSurfaceData;

//=================================================================================================
/// A raster type graph which shows surface data, but instead shows colored rectangles to represent
/// the vertical axis data. If the underlying surface data object has contours then these are shown
/// instead of the raster graph.  The colors of the rectangles (or contours) are determined
/// by a cold-hot (blue-red) 'Jet' like scheme where blue is the minimum and red is the maximum.
class CDensityGraphView
{
public:
    /// @parma pData is the graph data.
    /// @param pXAxis is the horizontal (x) axis view.
    /// @param pDepthAxis is the depth (z) axis view which becomes the vertical axis for this graph.
    /// @param pYAxisData is the hidden (y) axis whose data gives the color of the rectangles.
    /// The view is never created for this axis because the 'hide' flag should be set for this axis
    /// data.
    CDensityGraphView(CRSGraphSurfaceData* pData,
        CRSGraphAxisView* pXAxis,
        CRSGraphAxisView* pDepthAxis,
        CRSGraphAxisData* pYAxisData);
    virtual ~CDensityGraphView() = default;

    /// Draw the graph data as required by this class.
    void Paint(CReportDisplay& rDisp);

private:
    CRSGraphSurfaceData* m_pData;    ///< x,y,z plot data
    CRSGraphAxisView* m_pXAxis;      ///< x axis
    CRSGraphAxisView* m_pDepthAxis;  ///< depth axis
    CRSGraphAxisData* m_pYAxisData;  ///< y axis data
};

#endif // RSDENSITY_GRAPH_VIEW_HPP
