#ifndef RSIMAGEDATA_HPP
#define RSIMAGEDATA_HPP
//-----------------------------------------------------------------------------
// Includes
//-----------------------------------------------------------------------------
#include "rsitemdata.hpp"
#include "cstr.hpp"

// ========================================================================
/// The CReportDataItemBase that holds an image from a file on disk.
///
/// The images can be either Bitmap files, of metafiles.  For bitmap files, the
/// data is loaded (and cached) here.  If the data is a matafile, the view
/// needs to load (and cache) the data.
class CReportImageData : public CReportDataItemBase
{
public:
    CReportImageData();
    CReportImageData(CReportImageData&&) = default;
    CReportImageData operator=(const CReportImageData&) = delete;
    ~CReportImageData();

    void SerializeData(CDataArchive& rAr, const VDataItem& cvDataItems) override;

#if defined(_DEBUG)
    virtual CStr DbgName() const override;
#endif

    /// Set the data from the filename passed in.
    bool SetFile(const CStr& cszFName);

    /// @ name View access to the information.
    /// @{

    /// @return if this can access the bitmap data
    bool IsBitmap() const;
    /// @return if this is a metafile (just the name).
    bool IsMetafile() const;

#if defined(MIC_VCMFC)
    /// @return the LPBITMAPINFO if this is a bitmap type.
    LPBITMAPINFO GetBitmapInfo();
    /// @return the bitmap bits if this is a bitmap type.
    char* GetBitmapBits();
#endif

    /// @return the filename so the view can load.
    CStr GetFilename() const { return m_szFilename; }

    /// @}

private:
    enum EStyle
    {
        ceUninit,
        ceBitmapData,
        ceBitmapFile,
        ceMetafile,
    };

    ///  What type of information there is in here.
    EStyle m_eStyle;

    /// The name of the file containing the information.
    CStr m_szFilename;

    ///  true iff this file is locked in the cache.
    bool m_fIsLocked;

    DECLARE_MSG()
};

#endif  // RSIMAGEDATA_HPP
