#ifndef RSLEGENDDATA_HPP
#define RSLEGENDDATA_HPP
//-----------------------------------------------------------------------------
// Includes
//-----------------------------------------------------------------------------
//-----------------------------------------------------------------------------
// Globals, Constants, Defines, Macros, Forward References
//-----------------------------------------------------------------------------
// ============================================================================
/// The data for the CReportGraphData legend parameters.
class CRSGraphLegendData final
{
public:
    /// The enumeration for where the type should be shown.
    enum EType
    {
        ceNone = 0,
        ceAboveHorz,
        ceLeft,
        ceRight,
        ceBottom,
        ceTypeNum
    };

    /// Create the default legend.
    CRSGraphLegendData(EType eType = ceNone);

    ~CRSGraphLegendData() = default;

    ///  Set if and where the legend should be shown.
    void SetType(EType eType) { m_eType = eType; }

    /// @name The accessors used by the view.
    /// @{

    ///   Access the attributes.
    EType GetType() const { return m_eType; }

    bool IsVertical() const { return ms_fIsVertical[m_eType]; }
    bool IsHorizontal() const { return ms_fIsVertical[m_eType] ? false : true; }
    bool IsLeft() const { return ms_fIsLeft[m_eType]; }
    bool IsRight() const { return ms_fIsRight[m_eType]; }
    bool IsAbove() const { return ms_fIsAbove[m_eType]; }
    bool IsBelow() const { return ms_fIsBelow[m_eType]; }

    /// @}

private:
    /// Where the legend should be shown.
    EType m_eType;

    //  Static lookup tables for type properties.
    static bool ms_fIsVertical[ceTypeNum];
    static bool ms_fIsLeft[ceTypeNum];
    static bool ms_fIsRight[ceTypeNum];
    static bool ms_fIsAbove[ceTypeNum];
    static bool ms_fIsBelow[ceTypeNum];
};

#endif
