#ifndef RSLEGENDVIEW_HPP
#define RSLEGENDVIEW_HPP
#if _MSC_VER > 1000
#pragma once
#endif  // _MSC_VER > 1000
//-------------------------------------------------------------------------------------------------
// Includes
//-------------------------------------------------------------------------------------------------
#include "rslegenddata.hpp"
#include "rscurveview.hpp"
#include "rsitemview.hpp"

// ================================================================================================
class CRSGraphLegendView final
{
public:
    using CCurveViewList = std::vector<std::unique_ptr<CRSGraphCurveView>>;
    using CCurveViewConstIter = CCurveViewList::const_iterator;

    CRSGraphLegendView(CRSGraphLegendData* pData, const CCurveViewList& crCurveList);
    CRSGraphLegendView(const CRSGraphLegendView&) = delete;
    CRSGraphLegendView& operator=(const CRSGraphLegendView&) = delete;
    ~CRSGraphLegendView() = default;

    //  Forward the type information.
    bool IsVertical() const { return m_pData->IsVertical(); }
    bool IsHorizontal() const { return m_pData->IsHorizontal(); }
    bool IsLeft() const { return m_pData->IsLeft(); }
    bool IsRight() const { return m_pData->IsRight(); }
    bool IsAbove() const { return m_pData->IsAbove(); }
    bool IsBelow() const { return m_pData->IsBelow(); }

    /// This will calculate all the internal sizes used by the object and save them to be used in a
    /// subsequent call to Paint().
    /// @param iPlotWidth is the maximum available plot rectangle width.
    /// @param iPlotHeight is the maximum available plot rectangle height.
    void CalcSizes(CReportDisplay& rDisp, int iPlotWidth, int iPlotHeight);

    ///  Give access to the items.
    int Height() const { return m_iHeight; }
    int Width() const { return m_iWidth; }

    /// Draws the axis items as required by this class at iX, iY.  The iX, iY is the corner that
    /// makes the most sense for the type.
    void Paint(CReportDisplay& rDisp, int iX, int iY);

private:
    //  true if the legend for this is unique.
    bool IsFirst(const CRSGraphCurveView* pCurveView) const;

    /// The associated parameters.
    CRSGraphLegendData* m_pData;

    //  The list of curve views to show as part of this.
    const CCurveViewList& m_cCurveList;

    // Cached data determined by CalcSizes() and used by Paint().
    int m_iHeight = 0;          ///< Height of the legend.
    int m_iWidth = 0;           ///< Width of the legend.
    uint_16 m_uiCols = 1;       ///< number of columns used.
    uint_16 m_uiItemWidth = 0;  ///< Width of curve titles.
    uint_16 m_uiItemHeight = 0;  ///< Height of curve titles.

    DECLARE_MSG()
};

//-----------------------------------------------------------------------------
#endif  // RSLEGENDVIEW_HPP
