#ifndef RSOVERLAYDATA_HPP
#define RSOVERLAYDATA_HPP
//-----------------------------------------------------------------------------
// Includes
//-----------------------------------------------------------------------------
#include "cstr.hpp"
#include "numpoly.hpp"
#include "colordef.hpp"

//-----------------------------------------------------------------------------
// Forward Declarations
//-----------------------------------------------------------------------------

// ============================================================================
/// Defines the data for an overlay on a CReportGraphData object.
///
/// Overlays can be vertical lines or Polynomials (which include horizontal and
/// diagonal lines.  The overlay can have it own pen style and color.  Note
/// that even if the axes have units, the overlay is defined in internal
/// units.
class CRSGraphOverlayData final
{
public:
    /// The type of overlay this is.
    enum EType
    {
        cePolynomial,
        ceVerticalLine
    };

    /// Construct the overlay of type @p eType connected to the @p uiXAxixID
    /// and @p uiYAxixID axes.
    CRSGraphOverlayData(EType eType, int iXAxixID, int iYAxixID);
    ~CRSGraphOverlayData() = default;

    /// Show or hide the overlay.
    void SetShow(bool fShow) { m_fShow = fShow; }

    /// Set the color of the overlay.
    void SetPenColor(COLORREF ulColor) { m_ulPenColor = ulColor; }
    /// Set the line style of the overlay.
    void SetPenStyle(int iStyle) { m_iPenStyle = iStyle; }

    /// For vertical lines, set the horizontal position of the line.
    void SetXPos(double dXPos);
    /// For polynomial lines set the polynomial to use.
    void SetPolynomial(const CNumPolynomialExtrap& rcPoly);

    /// @name Accessors for the parameters for the view.
    /// @{

    bool IsShown() const { return m_fShow; }
    COLORREF GetPenColor() const { return m_ulPenColor; }
    int GetPenStyle() const { return m_iPenStyle; }
    int GetHorzAxisID() const { return m_ciHorzAxisID; }
    int GetVertAxisID() const { return m_ciVertAxisID; }
    EType GetType() const { return m_ceType; }

    // cePolynomial parameters.
    const CNumPolynomialExtrap& GetPolynomial() const;

    //  ceVerticalLine parameters.
    double GetXPos() const;

    /// @}

private:
    //  The data itself.
    const EType m_ceType;
    CNumPolynomialExtrap m_Poly;
    double m_dXPos;

    //  Display options.
    bool m_fShow;
    COLORREF m_ulPenColor;
    int m_iPenStyle;

    //  The ID that is used to identify the axis that each of the curves
    //  belongs to. This is bone By ID to make the persistance easier. It is
    //  up to the graph object to containing this and the axis to handle the
    //  explicit link.
    const int m_ciHorzAxisID;
    const int m_ciVertAxisID;
};

#endif
