#ifndef RSOVERLAYVIEW_HPP
#define RSOVERLAYVIEW_HPP
#if _MSC_VER > 1000
#pragma once
#endif  // _MSC_VER > 1000
//-------------------------------------------------------------------------------------------------
// Includes
//-------------------------------------------------------------------------------------------------
#include "rsoverlaydata.hpp"
#include "rsitemview.hpp"

//-------------------------------------------------------------------------------------------------
class CRSGraphAxisView;

// ================================================================================================
class CRSGraphOverlayView final
{
public:
    CRSGraphOverlayView(CRSGraphOverlayData* pData, CRSGraphAxisView* pXAxis, CRSGraphAxisView* pYAxis);
    CRSGraphOverlayView(const CRSGraphOverlayView&) = delete;
    CRSGraphOverlayView& operator=(const CRSGraphOverlayView&) = delete;

    ///  Sets the reference points for the axis.
    void SetPlotRange(int iXLow, int iYLow, int iXHigh, int iYHigh);

    ///  Draws the curve items as required by this class.
    void Paint(CReportDisplay& rDisp);

private:
    ///  Draw the strainght line on either a linear or logaritmic plot.
    void DrawPolynomial(CReportDisplay& rDisp);

    ///  draws the part of the line that is visible in the plotting area.
    void DrawClippedLine(CReportDisplay& rDisp, int iX1, int iY1, int iX2, int iY2);

    ///  The asociated dat set.
    CRSGraphOverlayData* m_pData;

    ///  The plot area to show.
    int m_iPlotXLow = 0;
    int m_iPlotYLow = 0;
    int m_iPlotXHigh = 0;
    int m_iPlotYHigh = 0;

    ///  The axes for the curve.
    CRSGraphAxisView* m_pXAxis;
    CRSGraphAxisView* m_pYAxis;

    DECLARE_MSG()
};

//{{AFX_INSERT_LOCATION}}
#endif  // #define RSOVERLAYVIEW_HPP
