#ifndef RSSAVEASCII_HPP
#define RSSAVEASCII_HPP
//-------------------------------------------------------------------------------------------------
/// @file
/// Public interface to saving a report model to Ascii format.
//-------------------------------------------------------------------------------------------------
// Includes
//-------------------------------------------------------------------------------------------------
#include <iosfwd>
#include <utility>

//-------------------------------------------------------------------------------------------------
// Globals, Constants, Defines, Macros, Forward References
//-------------------------------------------------------------------------------------------------
class CStr;
class CReportModel;
class CReportPageData;
class CReportDataItemBase;

#if defined(MIC_VCMFC)
using mic_ostream = std::wostream;
using mic_ofstream = std::wofstream;
#else
using mic_ostream = std::ostream;
using mic_ofstream = std::ofstream;
#endif

// ================================================================================================
namespace NRSSaveAs
{
    /// Write a single item (@p cData) at @p uiRow into @p os.
    /// @returns the numbers of rows added.
    void ASCIIOut(const CReportDataItemBase& cData, mic_ostream& os);

    /// Write an individual page (@p cData) to the current sheet of @os
    void ASCIIOut(const CReportPageData& cData, mic_ostream& os);

    /// Create the file @p szFilename and put all the data from @p cData into it in ASCII.
    void SaveAsASCII(const CReportModel& cData, const CStr& szFilename);

    /// Send the report as an ascii to the file given by @p cszFilename
    /// @returns an error string if it failed, or an empty string on success.
    CStr ExportASCII(const CReportModel& cData, const CStr& cszFilename);
}

#endif  // RSSAVEASCII_HPP
