#ifndef RSTABLEVIEW_HPP
#define RSTABLEVIEW_HPP
//-------------------------------------------------------------------------------------------------
// Includes
//-------------------------------------------------------------------------------------------------
#include "rsitemview.hpp"
#include "rstabledata.hpp"

// ================================================================================================
/// The view for the CReportTableData.
class CReportTableView : public TReportDataItemView<CReportTableData>
{
public:
    virtual ~CReportTableView() = default;

    virtual void OnBaseChanged(unsigned int uiUpdateFlag) override;
    virtual void AutoSize() override;
    virtual void PrintPartial(uint_32 uPageIndex, const CPageInfoVec& cPageInfo) override;
    virtual void DrawItem(const SRect& cLocation) override;

    /// Update the cached layout parameters based on the currently selected display.
    void UpdateLayout();

    void Draw(int iVisTop, int iVisHeight, int iXOffs = 0, int iYOffs = 0);

private:
    virtual CPageInfoVec CalculatePrintInfo(uint_32 uPageOffset,
        uint_32 uStartPageIndex,
        const SRect& sItemRect,
        const SRect& sPrintRect,
        CLayoutSupport& rLayout) override;

    /// @returns true iff each row of the table has a unique height.
    bool IsVariableHeight() const;

    ///  This draw the item into the the last UpdateLayout rectangle.
    void DrawHeader(CReportDisplay& rDisp,
        int iLeft,
        int iHeaderTop,
        int iRowStart,
        int iRowNum,
        bool fScreen);

    /// This draws the snaking columns of the table.
    void DrawTable(CReportDisplay& rDisp,
        int iLeft,
        int iTableTop,
        int iRowStart,
        int iRowNum,
        bool fScreen);

    int m_iTitleHeight = 0;
    int m_iHeaderHeight = 0;
    int m_iNumSnake = 1;
    int m_iSnakeSep = 0;
    int m_iLeftOffset = 0;  ///< The offset needed to center the table.
    int m_iRowHeight = 0;
    std::vector<int> m_viStartHeight;
    size_t m_uiStartHeightNum = 0;
};

#endif // RSTABLEVIEW_HPP
