#ifndef RSTEXTDATA_HPP
#define RSTEXTDATA_HPP
//-----------------------------------------------------------------------------
// Includes
//-----------------------------------------------------------------------------
#include "rsitemdata.hpp"
#include "unitscontext.hpp"

class CReportTextWin;

//=============================================================================
/// Responsible for storing text configuration information and item text
/// contents.
class CReportTextData final : public CReportDataItemBase
{
    friend CReportTextWin;

public:
    CReportTextData();
    ~CReportTextData() = default;

    CReportTextData(const CReportTextData& rcCopy) = delete;
    CReportTextData& operator=(const CReportTextData& rcCopy) = delete;

    void SerializeData(CDataArchive& rAr, const VDataItem& cvDataItems) override;

#if defined(_DEBUG)
    virtual CStr DbgName() const override;
#endif

    /// Set the units context used to show the text.
    void SetUnitsContext(std::shared_ptr<CUnitsContext> pContext);

    /// Get The formatted text.
    CStr GetTextData() const;

    /// Clear the contents of the Text Data buffer.
    void ClearTextData() { m_Text = CUnitsStr(CStr()); }

    /// Set the contents of the Text Data buffer.
    void SetTextData(const CUnitsStr& szData);

    /// @name Parameters for how to show the item.
    /// @{

    /// Set character format to use.
    void SetFontType(EFontType eFontType) { m_eFontType = eFontType; }
    /// @returns the character format to use.
    EFontType GetFontType() const { return m_eFontType; }

    bool IsAlignLeft() const { return m_eAlignment == ceLeft; }
    bool IsAlignCenter() const { return m_eAlignment == ceCenter; }
    bool IsAlignRight() const { return m_eAlignment == ceRight; }

    /// Right align the text.
    void AlignTextRight();
    /// Center the text.
    void AlignTextCenter();
    /// Left align the text.
    void AlignTextLeft();

    void AutoVFit(bool fArg);
    void ReadOnly(bool fArg);

    void ForceUniformFont(bool fArg);

    /// @}

private:
    enum EAlignment
    {
        ceLeft,
        ceCenter,
        ceRight
    };

    EAlignment m_eAlignment;
    bool m_fAutoVFit;
    bool m_fReadOnly;
    bool m_fForceUniformFont;

    /// The text (and quantities) to show for this string.
    CUnitsStr m_Text;

    /// The units context to use for string formatting.
    std::shared_ptr<CUnitsContext> m_pContext;

    /// The font to use with this text item.
    EFontType m_eFontType;
};

#endif  // RSTEXTDATA_HPP
