#ifndef RSTITLEVIEW_HPP
#define RSTITLEVIEW_HPP
//-------------------------------------------------------------------------------------------------
// Includes
//-------------------------------------------------------------------------------------------------
#include "rstextview.hpp"
#include "rsgraphdata.hpp"

// ================================================================================================
class CRSGraphTitleView final
{
public:
    CRSGraphTitleView(CReportTextData* pTitle, CReportTextData* pSubTitle);
    CRSGraphTitleView(const CRSGraphTitleView&) = delete;
    CRSGraphTitleView& operator=(const CRSGraphTitleView&) = delete;
    ~CRSGraphTitleView() = default;

    /// This will calculate all the internal sizes used by the object.  The *pfHeightChanged is set
    /// to true of false depending on if the overall height changed from the last call. The
    /// *pfWidthChanged is set simmilarly if the Width changed.
    void CalcSizes(CReportDisplay& rDisp,
        bool* pfHeightChanged = nullptr,
        bool* pfWidthChanged = nullptr);

    ///  Returns the height of this item on that particular device.
    int Height() const { return m_iHeight; }

    ///  Returns the height of this item on that particular device.
    int Width() const { return m_iWidth; }

    ///  Sets the reference points for the title
    void SetPlotRange(int iXLow, int iYLow, int iXHigh, int iYHigh);

    ///  Draws the axis items as required by this class.
    void Paint(CReportDisplay& rDisp, int iExtraY);

private:
    ///  The preferred size of the Title object.
    int m_iHeight, m_iWidth, m_iTitleHeight, m_iTitleWidth, m_iSubWidth;
    size_t m_uiNumLines = 1;  ///< Number of lines for the title. Default = 1.

    ///  The plot rectangle.
    int m_iPlotXLow = 0;
    int m_iPlotXHigh = 0;
    int m_iPlotYLow = 0;
    int m_iPlotYHigh = 0;

    ///  The associated data object.
    CReportTextData* m_pTitleData;
    CReportTextData* m_pSubTitleData;

    DECLARE_MSG()
};

#endif  // RSTITLEVIEW_HPP
