#ifndef XLS_HPP
#define XLS_HPP
//-----------------------------------------------------------------------------
#include "cstr.hpp"
#include "log-query.hpp"
#include <utility>

#if defined(MIC_VCMFC)
#include "vcmfc/basicexcel.hpp"
#define MIC_VCMFC_EXCEL
#else
#include <fstream>
#define MIC_PYTHON_EXCEL
#endif

//-----------------------------------------------------------------------------
// Globals, Constants, Defines, Macros, Forward References
//-----------------------------------------------------------------------------
namespace NRSSaveAs
{
    class CRSXLSOutput;
}

// ========================================================================
/// A helper class that is used the report system to write data to an xls data
/// file.
class NRSSaveAs::CRSXLSOutput final
{
public:
    /// Sets up the object so that the data can be added.  The file of file @p
    /// filename is written on destruction.
    CRSXLSOutput(const CStr& szFName);

    CRSXLSOutput(const CRSXLSOutput&) = delete;
    CRSXLSOutput& operator=(const CRSXLSOutput&) = delete;

    /// Writes out the file returns the fOK, szError pair.  fOK is true if the file was written OK,
    /// and false if not.  szError is the error string if the file was not ok.
    CStr Close();

    /// Creates and uses a new excel worksheet.
    /// @param cszWorksheetName Title of the new excel worksheet.
    void UseNewWorksheet(const CStr& cszWorksheetName);

    /// Access to the maximum row used so far.
    uint_32 GetMaxRow() const { return m_uiMaxRow; }
    /// Access to the maximum column used so far.
    uint_32 GetMaxCol() const { return m_uiMaxCol; }

    ///  Set the offset relative to which each item will be presented.
    void SetOffset(uint_32 uiRow, uint_32 uiCol)
    {
        m_uiOffsetRow = uiRow;
        m_uiOffsetCol = uiCol;
    }

    ///  Give access to the row of the offset.
    uint_32 GetOffsetRow() const { return m_uiOffsetRow; }
    ///  Give access to the column of the offset.
    uint_32 GetOffsetCol() const { return m_uiOffsetCol; }

    ///@{
    /// Add a value at @p uiRow, @p uiCol relative to the last called
    /// SetOffset().
    void AddFloat(uint_32 uiRow, uint_32 uiCol, float_64 dVal);
    void AddInt(uint_32 uiRow, uint_32 uiCol, int_16 iVal);
    void AddLabel(uint_32 uiRow, uint_32 uiCol, const CStr& szVal);
    ///@}

private:
    CStr m_szFName;
    CStr m_szCurrentSheetName;
    uint_32 m_uiOffsetRow, m_uiOffsetCol;
    uint_32 m_uiMaxRow, m_uiMaxCol;
    size_t m_uiCurrentSheet;

#if defined(MIC_VCMFC_EXCEL)
    YExcel::BasicExcel m_Xls;
    YExcel::BasicExcelWorksheet* m_Sheet;
#endif

#if defined(MIC_PYTHON_EXCEL)
    CStr m_szPythonFilename;
    std::ofstream m_osPython;
#endif
};
#endif  // XLS_HPP
