#ifndef SCRCOM_HPP
#define SCRCOM_HPP
//-----------------------------------------------------------------------------
//
// Library:			BaseLib
//
// Description:
//
//		This describes the types that are common between the front and back 
//		ends using the scripting subsystem.
//
// Contents:
//
//-----------------------------------------------------------------------------
// Includes
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Globals, Constants, Defines, Macros, Forward References
//-----------------------------------------------------------------------------

/* ========================================================================
**	EScriptState
**
**	This defines state that the script execution can be in. 
**
**	Idle		- The script is not executing.
**	Running		- The script is executing in the normal state.
**	Terminating	- The script is in the termination phase of the execution.
**				  This typically implies that it cannot be canceled.
**				  The state is entered by executing the built-in terminate step.
**	Done/
**	Canceled	- The script is no longer executing, but remains in a non
**				  idle state to allow the front end to upload any data that
**				  it requires before notifying that it is done with this 
**				  script. If the script was canceled, it enters the Canceled
**				  state, if the script ended without a cancel, it enters the
**				  Done state.
**	
** ======================================================================== */
enum	EScriptState
{
	ceScriptStateIdle,
	ceScriptStateRunning,
	ceScriptStateTerminating,
	ceScriptStateDone,
	ceScriptStateCanceled

};
/* ========================================================================
**	EScriptStep
**
**	This defines the script ID's That are built into the Script Processor
**	i.e. they do not call an external function to execute them. See the 
**	CScrProcess class for an explanation of what these steps do.
**
** ======================================================================== */
enum	EScriptStep
{
	ceScriptStepFirst = 0x7FF0,
	ceScriptStepLogSteps = ceScriptStepFirst,
	ceScriptStepStep,
	ceScriptStepRepeat,
	ceScriptStepEndRepeat,
	ceScriptStepTerminate,
    ceScriptStepRepeatCond,
    ceScriptStepDoIf,
    ceScriptStepEndDoIf,

    ceScriptStepRecordTables,
    ceScriptStepRecordSetupTable,
    ceScriptStepRecordStart,
    ceScriptStepRecordEnd,
    ceScriptStepRecordData,

    ceScriptStepStepFirst
};

#endif // SCRCOM_HPP
