#ifndef SCRLOGD_HPP
#define SCRLOGD_HPP
//-----------------------------------------------------------------------------
//
// Library:			BaseLib
//
// Description:
//
//		This contains the functionality for the holding the log information for
//		a script execution.
//
// Contents:
//
//		class	CScrLogItem
//		class	CScrLogItemIter
//

//-----------------------------------------------------------------------------
// Includes
//-----------------------------------------------------------------------------
#include <cpp/tmint.hpp>

#if defined(__GNUC__)
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif

//-----------------------------------------------------------------------------
// Globals, Constants, Defines, Macros, Forward References
//-----------------------------------------------------------------------------
/* ========================================================================
** CScrLogItem
**
**	The purpose of this class it to make it easy to work with a memory 
**	block that correcponds to a log item. This a small lightweight class and 
**	therefore can be passed aound at will. The data to which this refers,
**	however, must exist as long as it is refreed to.
** ======================================================================== */
class CScrLogItem
{
public:

	CScrLogItem( char* pData )	: m_pData( pData ) {}
	//	Set up the recording point to work with the data provided.

	static	uint_16	Size( uint_16 uiNumArg ) 
		{ return sizeof(SLogStrucHead) + uiNumArg*sizeof(float_32); }
	//	Calculates the size of the structure with that many arguments.

	uint_16	Size() const
		{ return ((SLogStrucHead*)m_pData)->uiSize; }
	//	Returns teh numebr of bytes used by this log item.

	uint_16	GetLogNum() const
		{ return ((SLogStrucHead*)m_pData)->uiLogNum; }
	//	Returns the index/count that identifies this log item.

	const	CTimeInterval&	GetTime() const
		{ return ((SLogStrucHead*)m_pData)->Time; }
	//	Retruns the time of the log message.

	uint_16	GetLogCode() const
		{ return ((SLogStrucHead*)m_pData)->uiLogCode; }
	//	Return the application specific log code.

	uint_16	GetLogType() const
		{ return ((SLogStrucHead*)m_pData)->uiLogType; }
	//	Return the application specific target mask bits.

	uint_16	GetLogSrc() const
		{ return ((SLogStrucHead*)m_pData)->uiLogSrc; }
	//	Return the application specific target mask bits.

	uint_16	GetNumArgs() const 
		{ return (Size()-sizeof(SLogStrucHead)) / sizeof(float_32); }
	//	Return the number of arguments in the log item.

	const float_32*	GetArgPtr() const { return (const float_32*)GetArgLoc(0); }
	//	Get the pointer to the arguments.

	uint_16		GetArgUInt16( uint_16 ui ) const { return *(uint_16 *)GetArgLoc( ui ); }
	int_16		GetArgInt16 ( uint_16 ui ) const { return *(int_16  *)GetArgLoc( ui ); }
	uint_32		GetArgUInt32( uint_16 ui ) const { return *(uint_32 *)GetArgLoc( ui ); }
	int_32		GetArgInt32 ( uint_16 ui ) const { return *(int_32  *)GetArgLoc( ui ); }
	float_32	GetArgFloat ( uint_16 ui ) const { return *(float_32*)GetArgLoc( ui ); }
	//	Give access to the arguments. The types of the argument are 
	//	dependent on the message. It is the applications responcibility
	//	to make sure that the arguments are set and read in the proper 
	//	types.

	void	SetSize( uint_16 uiSize )
		{ ((SLogStrucHead*)m_pData)->uiSize = uiSize; }
	//	Store the size of the item in the structure.

	void	SetLogNum( uint_16 uiLogNum )
		{ ((SLogStrucHead*)m_pData)->uiLogNum = uiLogNum; }
	//	Returns the index/count that identifies this log item.

	void	Set( const CTimeInterval& rTime, uint_16 uiLogCode, 
				 uint_16 uiLogType, uint_16 uiLogSrc )
		{ 
			((SLogStrucHead*)m_pData)->Time     = rTime; 
			((SLogStrucHead*)m_pData)->uiLogCode = uiLogCode; 
			((SLogStrucHead*)m_pData)->uiLogType = uiLogType; 
			((SLogStrucHead*)m_pData)->uiLogSrc  = uiLogSrc; 
		}
	//	Sets the code and target of this item.

	void	Set( uint_16 uiLogCode, uint_16 uiLogType, uint_16 uiLogSrc )
		{ 
			((SLogStrucHead*)m_pData)->Time     = CTimeInterval::MilliSec(0);
			((SLogStrucHead*)m_pData)->uiLogCode = uiLogCode; 
			((SLogStrucHead*)m_pData)->uiLogType = uiLogType; 
			((SLogStrucHead*)m_pData)->uiLogSrc  = uiLogSrc; 
		}
	//	Sets the code and target of this item.

	void	SetArg( uint_16 ui, uint_16	 uiArg )
		{ *(uint_32 *)GetArgLoc( ui ) = uiArg; }
	void	SetArg( uint_16 ui, int_16	  iArg )
		{ *(int_32 *)GetArgLoc( ui ) = iArg; }
	void	SetArg( uint_16 ui, uint_32	 uiArg )
		{ *(uint_32 *)GetArgLoc( ui ) = uiArg; }
	void	SetArg( uint_16 ui, int_32	  iArg )
		{ *(int_32 *)GetArgLoc( ui ) = iArg; }
	void	SetArg( uint_16 ui, float_32 flArg )
		{ *(float_32 *)GetArgLoc( ui ) = flArg; }
	//	Set the arguments of this method.

protected:

private:

	void*			GetArgLoc( uint_16 uiArg )
		{ return (char*)m_pData + sizeof(SLogStrucHead) + uiArg*sizeof(float_32); }
	const	void*	GetArgLoc( uint_16 uiArg ) const
		{ return (char*)m_pData + sizeof(SLogStrucHead) + uiArg*sizeof(float_32); }
	//	Find the location of this argument in the structure.

	struct	SLogStrucHead
	{
		uint_16			uiSize;			//	how many bytes total to use.
		uint_16			uiLogNum;		//	Thie index of the log item.
		CTimeInterval	Time;			//	The time when the item was taken.
		uint_16 		uiLogCode;		//	App specific code.
		uint_16 		uiLogType;		//	App specific code.
		uint_16			uiLogSrc;		//	App specifiv code.
        uint_16         uiFill;
	};

	void*		m_pData;
	//	The pointer to the data that contains the information for the logitem.
	//	The format is the SLogStrucHead followed by 4 bytes per argument.

};
/* ========================================================================
** CScrLogItemIter
**
**	This class is an iterator over a set of CScrLogItem's that reside in
**	a continuous block of memry. The iterator should be used as follows:
**
**	
**	for ( CScrLogIterator itr( pData, uiSize ); !itr.Done(); itr.Next() )
**		Dosomething( itr.Curr() );
**
** ======================================================================== */
class CScrLogItemIter
{
public:

	CScrLogItemIter( const char* pData, uint_16 uiSize )
		:	m_pCurr( pData ), m_pEnd( pData + uiSize ) {}
	//	Sets up the iterator for the items in the class.

	bool	Done() const { return bool( m_pCurr >= m_pEnd ); }
	//	This returns true iff the iteration is done.

	CScrLogItem		Curr() { return CScrLogItem( (char*)m_pCurr ); }
	//	Returns the current log item in the iteration.

	void			Next() { m_pCurr += CScrLogItem( (char*)m_pCurr ).Size(); }
	//	Points the iteration to the next item in the list.

protected:

private:

	const char*		m_pCurr;
	//	the pointer to the next item in the list.

	const char*		m_pEnd;
	//	The pointer to one past the end of the list.
};

#if defined(__GNUC__)
#pragma GCC diagnostic pop
#endif

#endif // SCRLOGD_HPP
