#ifndef SCRSYSARM_HPP
#define SCRSYSARM_HPP
//-----------------------------------------------------------------------------
//
// Library:			5200/mass
//
// Description:		The back end scripting transpor tlayer and subsystem
//
//
// Contents:		CScrCommTransportMass
//
//-----------------------------------------------------------------------------
// Includes
//-----------------------------------------------------------------------------
#include "scrtrnsb.hpp"
//-----------------------------------------------------------------------------
// Globals, Constants, Defines, Macros, Forward References
//-----------------------------------------------------------------------------
class   CScrSystemArm;
class	CScrProcess;
class	CScrControl;
class	CScrLogMonitor;
class	CScrRecData;
class	CScrRecTask;
/* ========================================================================
** CScrCommTransportMass
**
**	This class encapsulates the script subsystem and transport layer of the 
**	mass side of the scripting. 
** ======================================================================== */
class CScrCommTransportMass
	:	public	CScrCommTransportBase
{
public:

#if defined(MIC_DM643)
	CScrCommTransportMass( CCommDataLink* pLink,
						   uint_16 eTransportID, uint_16 uiScriptID,
						   OPTION PriorityScript, OPTION PriorityRecord,
						   uint_16 uiMaxRecBlocks = 0, uint_16 uiMaxLogData = 0 );
	//	Crate and initialize the subsystem.
#endif
    
	~CScrCommTransportMass();
	//	Free up any resources.

	CScrProcess*	GetScrProcess() const { return m_pcScriptProcessor; }
	//	Give access to the script control object.

	CScrControl*	GetScrControl() const { return m_pcScriptControl; }
	//	Give access to the script control object.

	void	CheckStatus();
	//	This should be called every so often to see if the status has 
	//	changed. If it has, this will send the status to the front end.
	//	The reason for this way of handling this is so that the status
	//	does cause too much network trafic if it changes too often.

protected:

	/*
	**	CCommTransport implementation.
	*/
	virtual	void	MessageSent( ID uiID, const char* pData, SIZE uiSize );
	//	This gets called once the message has been sucessfuly recieved by
	//	the datalink layer. There is, however, no guarentee that the message
	//	was properly interpreted and processed by the other end.

	virtual	void	MessageReset( ID uiID, const char* pData, SIZE uiSize );
	//	This gets called when a message was in the middle of being sent, and
	//	the data-link was reset or initialized. The message will not be resent
	//	unless this requests a resend.

	virtual	char*	GetMemory( ID uiID, SIZE uiSize );
	//	This is called when the first packet of a message is recieved to 
	//	'allocate' the memory of the message. This memory is used internaly
	//	until eiter the message is complete and MessageRecieved() is called,
	//	or the datalink is reset and DiscardMemory() is called.

	virtual	void	MessageRecieved( ID uiID, char* pData, SIZE uiSize );
	//	This is called when a message has been sucessfuly recieved. If the 
	//	message was of zero size, pData will be null, and no GetMemory() call
	//	was made.

	virtual	void	DiscardMemory( ID uiID, char* pData, SIZE uiSize );
	//	This is called when the datalink was reset in the middle of 
	//	recieving a message that required a call to GetMemory(). This 
	//	allows the 'allocated' memory to be deallocated.
	
private:

	enum
	{
		ceMaxTableStatus	= 128
        // NOTE: Coordinate with the one in the following files: scrdata.hpp,
        // scrtrnsm.hpp, scrcoll.hpp (needs version control), scrmon.hpp (could
        // have version control), scrtrnsf.
	};
	
	/*
	**	Message support.
	*/
	void	OnReqLogData( const SReqLogData& rReq );
	//	Called when the front end requests more log entries. This will
	//	result in the data being sent to the front end.

	void	OnReqTableBlock( const SReqTableBlock& rReq );
	//	Called when the front end asks for a block of the table. This will
	//	send the data to the front end.

	void	UploadStatus();
	//	This will send the current status to the front end 


	SReqLogData		m_sReqLogData;		// Stores the data for the message.
	SReqTableBlock	m_sReqTableBlock;	// Stores the message contents.
	float_32		m_flWaitDataValue;	// Stores the data value of the
										// ceReqContinueDataScript command. 

	struct
	{
		SScriptStatus	sScriptStatus;
		STableStatus	asTableStatus[ceMaxTableStatus];

	}				m_sUploadStatus;	//	The memory to upload the status.

	uint_16			m_uiUploadStatusCount;
	//	The number of satuses that are currently queued.

	/*
	**	Subsystems contained in this system.
	*/
	CScrProcess*	m_pcScriptProcessor;
	CScrControl*	m_pcScriptControl;
	CScrLogMonitor*	m_pcLogMonitor;
	CScrRecData*	m_pcRecordData;

#if defined(MIC_DM643)

	CScrRecTask*	m_pcRecordTask;

#endif

	DECLARE_MSG()
};
#endif // SCRSYSARM_HPP
