#ifndef STRTSIM_HPP
#define STRTSIM_HPP
//-----------------------------------------------------------------------------
//
// Library:			BaseLib
//
// Description:		The Startip connection (mass) simulator
//
// Contents:		CSimulateStartup
//
//-----------------------------------------------------------------------------
// Includes
//-----------------------------------------------------------------------------
#include <cpp/comstrtb.hpp>
//-----------------------------------------------------------------------------
// Globals, Constants, Defines, Macros, Forward References
//-----------------------------------------------------------------------------

/* ========================================================================
** CSimulateStartup
** ======================================================================== */
class CSimulateStartup
	:	public	CCommStartupBase
{
public:

	CSimulateStartup( CCommDataLink* pLink );
	//	Create this simulation.

protected:

	/*
	**	CCommTransport implementation.
	*/
	virtual	char*	GetMemory( ID uiID, SIZE uiSize );
	//	This is called when the first packet of a message is recieved to
	//	'allocate' the memory of the message. This memory is used internaly
	//	until eiter the message is complete and MessageRecieved() is called,
	//	or the datalink is reset and DiscardMemory() is called.
	//
	//	If you do not want the whole message placed in a single memory
	//	buffer, this should return NULL, in which case whenever the next
	//	packet becomes available the NextPacketRecieved() function is called.
	//	The MessageRecieved(), or DiscardMemory() functions are still called
	//	at the end. This mode can be used for 'pass-through' mode where
	//	the reciever just has to pass the data to another process(or).

	virtual	void	MessageRecieved( ID uiID, char* pData, SIZE uiSize );
	//	This is called when a message has been sucessfuly recieved. If the
	//	message was of zero size, pData will be null, and no GetMemory() call
	//	was made.

private:

	SQueryInfo		m_sQueryInfo;
	//	The structure to send to the front end.

	SDownloadInfo		m_DownloadInfo;
	//	The Information about the file in progress.

	SDownloadBlockReq	m_BlockReq;
	//	The information about the last requested block from the Front end.

	uint_32				m_ulVerOffs;
	//	The location to store the version offset.

	SDownloadResult		m_DownloadResult;
	//	The information to be sent at the end of the download.

	SIPData				m_sIPData;
	//	The IP data to be downloaded.

	SErrorInfo			m_sErrorInfo;
	//	The error information from the system errors. 

    /// Simulated backend session ID.
    uint_32             m_uiSessionID;

	DECLARE_MSG()
};

/* ========================================================================
** CSimulateStartupArm
** ======================================================================== */
class CSimulateStartupArm
	:	public	CCommStartupBase
{
public:

    enum EBackendType
    {
        ceTypeARM,
        ceTypeDM643
    };
    
	CSimulateStartupArm( CCommDataLink* pLink, EBackendType eType = ceTypeARM );
	//	Create this simulation.

protected:

	/*
	**	CCommTransport implementation.
	*/
	virtual	char*	GetMemory( ID uiID, SIZE uiSize );
	//	This is called when the first packet of a message is recieved to
	//	'allocate' the memory of the message. This memory is used internaly
	//	until eiter the message is complete and MessageRecieved() is called,
	//	or the datalink is reset and DiscardMemory() is called.
	//
	//	If you do not want the whole message placed in a single memory
	//	buffer, this should return NULL, in which case whenever the next
	//	packet becomes available the NextPacketRecieved() function is called.
	//	The MessageRecieved(), or DiscardMemory() functions are still called
	//	at the end. This mode can be used for 'pass-through' mode where
	//	the reciever just has to pass the data to another process(or).

	virtual	void	MessageRecieved( ID uiID, char* pData, SIZE uiSize );
	//	This is called when a message has been sucessfuly recieved. If the
	//	message was of zero size, pData will be null, and no GetMemory() call
	//	was made.

private:

    SQuery643Info       m_sQueryInfoDM643;
    SQueryArmInfo&      m_sQueryInfo;
	//  The structure to send to the front end. Note that the DM643 struct 
    //  contains the ARM struct; the ARM reference is to the DM643 struct member. 

	SDownloadInfo		m_DownloadInfo;
	//	The Information about the file in progress.

	SDownloadBlockReq	m_BlockReq;
	//	The information about the last requested block from the Front end.

	SDownloadResult		m_DownloadResult;
	//	The information to be sent at the end of the download.

	SIPData				m_sIPData;
	//	The IP data to be downloaded.

	SErrorArmInfo		m_sErrorInfo;
	//	The error information from the system errors. 

    /// Simulated backend session ID.
    uint_32             m_uiSessionID;

	const EBackendType  m_eBackendType;
	//  The ARM and DM643 boards use similar data structures such that the
	//  overriden CCommStartupBase behavior is identical except in a few ways.
	//  This flag is used to allow for those differences in behaviors.
	
	DECLARE_MSG()
};
//-----------------------------------------------------------------------------
#endif // STRTSIM_HPP
