#ifndef TMTIMER_HPP
#define TMTIMER_HPP
//-----------------------------------------------------------------------------
/// @file
/// A timer for measuring the duration of events
//-----------------------------------------------------------------------------
// Includes
//-----------------------------------------------------------------------------
#include "tmint.hpp"

//-----------------------------------------------------------------------------
// Globals, Constants, Defines, Macros, Forward References
//-----------------------------------------------------------------------------

// ============================================================================
/// A timer for measuring the duration of events
class CTimeTimer
{
    friend class CTimeOneShot;

public:
    /// Create and start the timer.
    CTimeTimer() { Reset(); }

    CTimeTimer& Reset();    ///< Reset the timer to Zero. Returns ref to self.
    CTimeTimer& Suspend();  ///< Suspend the ticking of the timer. Returns ref to self.
    CTimeTimer& Resume();   ///< Resume the ticking of the timer. Returns ref to self.

    /// @return the amount of time since creation or the last reset, not counting the time
    /// spent suspended.
    CTimeInterval Elapsed() const;

    /// @return true if the timer is suspended.
    bool IsSuspended() const { return m_fSuspended; }

private:
    CTimeTimer( const CTimeTimer& );             ///< copy constructor is not implemented
    CTimeTimer& operator=( const CTimeTimer& );  ///< assignment is not implemented

    /// Return the current system time.  Wraps to zero every 25 days.  Do not use for
    /// calculating time intervals.  Creating a timer and call Elapsed() instead.
    static CTimeInterval Unsafe_Now();

    /// The time when the timer started (adjusted for the time spent suspended).
    CTimeInterval m_ulStart;

    /// The last time the timer was suspended.
    CTimeInterval m_ulSuspended;

    /// True if the timer is currently suspended.
    bool m_fSuspended;
};

#endif // TMTIMER_HPP
