#ifndef CALC_FOAMRESULTS_HPP
#define CALC_FOAMRESULTS_HPP
//-------------------------------------------------------------------------------------------------
/// @file The calculcations and formatting for the foampic reports.
//-------------------------------------------------------------------------------------------------
// Includes
//-------------------------------------------------------------------------------------------------
#include <pycnometry/calcaccu.hpp>
#include <pycnometry/calcfoam.hpp>

//-------------------------------------------------------------------------------------------------
// Globals, Constants, Defines, Macros, Forward References
//-------------------------------------------------------------------------------------------------
class CReportPageData;
class CReportStdTable;
class CReportOptionsTable;
class CReportTextData;
class CNumDistribution;
template<typename T> class CNumVector;

// ================================================================================================
namespace NPyc
{
    struct SFoamPycRaw
    {
        CNumVector<double> adVol;
        CNumVector<double> adP1;
        CNumVector<double> adP2;
        CNumVector<uint_32> aulTime;
        CNumVector<uint_8> afExclude;
    };

    void FoamPycAReport(CReportStdTable& rTable,
        CReportStdTable& rStat,
        CReportOptionsTable& rSummary,
        const CCalcAccuPycCore& cCalcAccuPyc,
        const CCalcFoamPycMethodA& cCalcFoamPyc,
        const SFoamPycRaw& csRaw);

    void FoamPycBReport(CReportStdTable& rInitialTable,
        CReportStdTable& rInitialStat,
        CReportStdTable& rRecutTable,
        CReportStdTable& rRecutStat,
        CReportOptionsTable& rSummary,
        const CCalcAccuPycCore& cCalcAccuPyc,
        const CCalcFoamPycMethodB& cCalcFoamPyc,
        const SFoamPycRaw& csInitialRaw,
        const SFoamPycRaw& csRecutRaw);

    void FoamPycCReport(CReportStdTable& rTable,
        CReportStdTable& rStat,
        CReportOptionsTable& rSummary,
        const CCalcAccuPycCore& cCalcAccuPyc,
        const CCalcFoamPycMethodC& cCalcFoamPyc,
        const SFoamPycRaw& csRaw);

    void FoamPycDReport(CReportStdTable& rTable,
        CReportOptionsTable& rSummary,
        const CCalcAccuPycCore& cCalcAccuPyc,
        const CCalcFoamPycMethodD& cCalcFoamPyc,
        const SFoamPycRaw& csRaw);

    void FoamPycEReport(CReportStdTable& rTable,
        CReportOptionsTable& rSummary,
        const CCalcAccuPycCore& cCalcAccuPyc,
        const CCalcFoamPycMethodE& cCalcFoamPyc,
        const SFoamPycRaw& csRaw);

    void AddFoamPycA(CReportPageData& rPage,
        const CCalcAccuPycCore& cCalcAccuPyc,
        const CCalcFoamPycMethodA& cCalcFoamPyc,
        const SFoamPycRaw& csRaw);

    void AddFoamPycB(CReportPageData& rPage,
        const CCalcAccuPycCore& cCalcAccuPyc,
        const CCalcFoamPycMethodB& cCalcFoamPyc,
        const SFoamPycRaw& csInitialRaw,
        const SFoamPycRaw& csRecutRaw);

    void AddFoamPycC(CReportPageData& rPage,
        const CCalcAccuPycCore& cCalcAccuPyc,
        const CCalcFoamPycMethodC& cCalcFoamPyc,
        const SFoamPycRaw& csRaw);

    void AddFoamPycD(CReportPageData& rPage,
        const CCalcAccuPycCore& cCalcAccuPyc,
        const CCalcFoamPycMethodD& cCalcFoamPyc,
        const SFoamPycRaw& csRaw);

    void AddFoamPycE(CReportPageData& rPage,
        const CCalcAccuPycCore& cCalcAccuPyc,
        const CCalcFoamPycMethodE& cCalcFoamPyc,
        const SFoamPycRaw& csRaw);
}  // namespace NPyc

#endif // CALC_FOAMRESULTS_HPP
