"""Support functionality for all mic-instruments."""
import base64
import hashlib
import getpass
import subprocess


def gen_config_passwd(model, serial):
    """Generate a 4 letter password from the model and serial number.

    This uses a base64 encodes sha1 hash on the model and serial number
    string.  It then truncates to 4 characters, makes them all lowercase,
    and finally replaces any numbers with letters to make it easy to
    enter on a touch screen instrument.
    """

    hash_gen = hashlib.sha1()
    hash_gen.update((model + '--' + serial).encode('utf-8'))
    enc = base64.urlsafe_b64encode(hash_gen.digest()).decode('utf-8')

    passwd = ""
    for char in enc[:4].lower():
        if char.isdigit():
            passwd += chr(ord(char) - ord('0') + ord('a'))
        else:
            passwd += char

    return passwd


def is_instrument():
    'if we are running as root, assume that we are on the instrument.'
    return getpass.getuser() == 'root'


def set_instrument_time(set_ntp, set_time):
    'Set the system time'
    if is_instrument():
        subprocess.run(['timedatectl', 'set-ntp', '1' if set_ntp else '0'], check=False)
        if not set_ntp:
            subprocess.run(['timedatectl', 'set-time',
                            set_time.strftime("%Y-%m-%d %H:%M:%S UTC")],
                           check=False)
