"""The views that support the software upgrades for yocto linux systems."""
import datetime
import gettext
from django.utils import timezone
from .rest import function_to_json_view
from .models import Settings
from .sw_deb_upgrade import (
    install_and_restart,
    new_version_dir_if_available,
    new_version_if_available,
)

_ = gettext.gettext


def make_sw_update_version_view(model, app_version):
    """Return a django view that handles the version endpoint."""

    def sw_update_version_view(is_reminder=False):
        new_version = new_version_if_available(model)
        if is_reminder:
            settings = Settings.objects.get()
            show = True
            if settings.update_reminder == 'A':
                show = True
            elif settings.update_reminder == 'N':
                show = False
            elif settings.update_reminder in 'VL' and settings.update_version != new_version:
                show = True
            elif settings.update_reminder == 'V':
                show = False
            elif settings.update_reminder == 'L':
                show = settings.update_next_date < timezone.now()
            if not show:
                new_version = ""
        return {
            "new_version": new_version,
            "app_version": app_version["version"],
        }

    return lambda request: function_to_json_view(request, sw_update_version_view)


def make_sw_update_view(model):
    """Return a django view that handles the update endpoint."""

    def install_now():
        version_dir = new_version_dir_if_available(model)
        if version_dir:
            settings = Settings.objects.get()
            if settings.update_reminder != 'N':
                settings.update_reminder = 'A'
                settings.save()
            error = install_and_restart(version_dir)
        else:
            error = _("Software update no longer accessible.")
        return {'error': error}

    def remind_later():
        settings = Settings.objects.get()
        settings.update_reminder = 'L'
        settings.update_version = new_version_if_available(model)
        settings.update_next_date = timezone.now() + datetime.timedelta(days=7)
        settings.save()

    def disable_remind_version():
        settings = Settings.objects.get()
        settings.update_reminder = 'V'
        settings.update_version = new_version_if_available(model)
        settings.update_next_date = timezone.now() + datetime.timedelta(days=7)
        settings.save()

    def disable_remind_ever():
        settings = Settings.objects.get()
        settings.update_reminder = 'N'
        settings.save()

    def sw_update_view(action):
        if action == "install":
            return install_now()
        if action == "remind":
            return remind_later()
        if action == "noremindversion":
            return disable_remind_version()
        if action == "noremind":
            return disable_remind_ever()
        return None

    return lambda request: function_to_json_view(request, sw_update_view)
