import icu
import datetime

LOCALE_OPTIONS = { # from /usr/share/i18n/SUPPORTED on Debian 11
    "en": [
        "en_AG",
        "en_AU",
        "en_BW",
        "en_CA",
        "en_DK",
        "en_GB",
        "en_HK",
        "en_IE",
        "en_IL",
        "en_IN",
        "en_NG",
        "en_NZ",
        "en_PH",
        "en_SC",
        "en_SG",
        "en_US",
        "en_ZA",
        "en_ZM",
    ],
    "zh": [
        "zh_CN",
        "zh_HK",
        "zh_SG",
        "zh_TW",
    ],
    "fr": [
        "fr_BE",
        "fr_CA",
        "fr_CH",
        "fr_FR",
        "fr_LU",
    ],
    "de": [
        "de_AT",
        "de_BE",
        "de_CH",
        "de_DE",
        "de_IT",
        "de_LI",
        "de_LU",
    ],
    "it": [
        "it_CH",
        "it_IT",
    ],
    "ja": [
        "ja_JP",
    ],
    "ko": [
        "ko_KR",
    ],
    "es": [
        "es_AR",
        "es_BO",
        "es_CL",
        "es_CO",
        "es_CR",
        "es_CU",
        "es_DO",
        "es_EC",
        "es_ES",
        "es_GT",
        "es_HN",
        "es_MX",
        "es_NI",
        "es_PA",
        "es_PE",
        "es_PR",
        "es_PY",
        "es_SV",
        "es_US",
        "es_UY",
        "es_VE",
    ],
}


def fmt_datetime(date, locale):
    return format_datetime(date, format="short", locale=locale)


if __name__ == "__main__":
    today = datetime.datetime.today()
    ret = {}

    for language, locales in LOCALE_OPTIONS.items():
        unique_results = []
        unique_locs = []
        for loc in locales:
            date_fmt = icu.DateFormat.createDateTimeInstance(
                icu.DateFormat.SHORT, icu.DateFormat.SHORT, icu.Locale(loc)
            )
            num_fmt = icu.NumberFormat.createInstance(icu.Locale(loc))
            result = (date_fmt.format(today), num_fmt.format(123.456))
            if result not in unique_results:
                print(f"{loc}: {result[0]} {result[1]}")
                unique_results.append(result)
                unique_locs.append(loc)

        ret[language] = unique_locs
    print(ret)
