'''
Django app configuration for conditions
'''
import django
from django.apps import AppConfig
from mic_python_lib.settings import init_languages, init_units, set_language
from mic_python_lib.mic_cifs import start_automount

import i1350


class PycSampleConfig(AppConfig):
    '''Set name attribute in metadata for django app'''
    name = 'pyc_sample'

    def ready(self):
        # pylint: disable=import-outside-toplevel
        # cannot import at top level, just after django initialization.
        from .models import AnalysisResult1350, Calibration, OtherOperation, ResultCache
        from .models import Settings  # pylint: disable=import-outside-toplevel
        from mic_python_lib.settings_views import add_settings_changed_callback
        from mic_python_lib.models import InstrumentScriptRun

        _init_mic_python_lib()

        # If the table does not exist yet, then don't do anything.
        try:
            settings = Settings.objects.get()
            set_language(settings.locale, settings.time_zone)
        except django.db.utils.OperationalError:
            pass

        # Delete all cached results when settings changed.
        add_settings_changed_callback(lambda: ResultCache.objects.all().delete())

def _edit_unit_selections():
    '''The function that returns the json to edit the unit selections.'''

    return i1350.EditUnitSelections1350(True)


def _init_mic_python_lib():
    '''Initialize the generic python functionality.'''

    init_languages(
        available=['en-US', 'zh-CN', 'fr-FR', 'de-DE', 'ja-JP', 'ko-KR', 'es-ES'],
        domain='i1350',
        domain_ui='i1350-ui',
        set_translate_locale_fcn=i1350.SetTranslationLocale1350,
        udp_set_translate_locale_fcn=i1350.UDPSetTranslationLocale,
    )

    init_units(
        unit_sel_and_simple_fcn=i1350.GlobalUnitsJson1350,
        update_selection_fcn=i1350.UpdateLinkedUnits,
        notify_updates_fcn=i1350.UDPUpdateUnitSelections,
        edit_units_fcn=_edit_unit_selections,
    )

    start_automount()
