"""The django management command to restart mic-chromium if it is using too much memory."""
from datetime import datetime
from django.core.management.base import BaseCommand
from django.utils import timezone
from mic_python_lib.models import Settings
import os
import pytz
import time

class Command(BaseCommand):
    """Usual django management command handler class."""
    help = 'Restart mic-chromium at a suitable time of day if it is using too much memory.'
    HIGH_MEM_PCT = 100. / 3.  # We have seen slowdowns and crashes starting around this much memory usage.

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.high_mem_counter = 0

    def check_chromium_memory(self):
        # Get % memory of the chromium process that uses the most memory.
        mem_cmd = "ps -eo %mem,command --sort -%mem | grep chromium | head -n 1 | awk '{print $1}'"
        mem_pct = float(os.popen(mem_cmd).read())

        # Get the user's local time (hour of the day).
        tzname = Settings.objects.get().time_zone
        utc_time = datetime.now(timezone.utc)
        local_time = utc_time.astimezone(pytz.timezone(tzname))
        local_hour = int(local_time.strftime('%H'))

        # Restart chromium if it's been using too much memory for an hour,
        # and it's between 2-4 AM local time. This reduces user disruption.
        self.high_mem_counter = self.high_mem_counter + 1 if mem_pct > self.HIGH_MEM_PCT else 0
        if self.high_mem_counter > 6 and (local_hour == 2 or local_hour == 3):
            self.high_mem_counter = 0
            os.system('systemctl restart mic-chromium')

    def handle(self, *args, **kwargs):  # pylint: disable=unused-argument
        while True:
            try:
                self.check_chromium_memory()
            except:
                print('Chromium memory check failed.')
            time.sleep(10 * 60)
