#pylint: disable=invalid-name # allow this module to be named mic-net-events.
"""The django management command to run the mic-net event server"""
import requests
from django.core.management.base import BaseCommand
from mic_python_lib.mic_net_events import MicNetEventHandler
from mic_python_lib.rest import BadInstrument
from pyc_sample.accupyc1345 import scrape_all
from pyc_sample.models import Instrument
from pyc_sample.rest_api import REST_API_DATA_1350


class Command(BaseCommand):
    """Usual django management command handler class."""
    help = 'Run the mic-net event handling server for this instrument.'

    def handle(self, *args, **kwargs):  # pylint: disable=unused-argument
        print("Waiting for server...")
        while True:
            try:
                page = requests.get("http://127.0.0.1:8000/rest/api-supported/", timeout=5)
                if page.status_code == 200:
                    break
            # if the server is not there, try again.
            except requests.exceptions.ConnectTimeout:
                pass
            except requests.exceptions.ConnectionError:
                pass
        print("Waiting for server done.")

        local = Instrument.objects.local()
        mic_events = MicNetEventHandler(
            local.model,
            local.serial,
            new_data_fcn=new_data,
            tick_time=15 * 60,
            tick_fcn=check_new_legacy
        )
        mic_events.run()


def new_data(addr, model, serial):
    "Callback for when there is new data.  If it is a known model, update the data."
    local = Instrument.objects.local()
    if model == '1350' and serial != local.serial:
        try:
            REST_API_DATA_1350.update_from_instrument(addr)
        except BadInstrument:
            # This is expected if a development system is attached.  Don't get data from it.
            # It is at a bad IP address.
            pass
        except Exception:  # pylint: disable=broad-except
            # Anything that goes wrong here we ignore so that we go onto the next instrument or
            # event.
            pass


def check_new_legacy():
    "Called periodically to check on legacy instruments."
    scrape_all()
