# Generated by Django 3.0.5 on 2021-10-28 12:15

from django.db import migrations, models


def update_last_density(apps, schema_editor):
    """Update all the "Last Density" records with the appropriate result_rank. """
    Result = apps.get_model('pyc_sample', 'Result')
    Result.objects.filter(result_type='Last Density').update(result_rank='R')


def update_volume(apps, schema_editor):
    """Update all the "Volume" records with the appropriate result_rank. """
    Result = apps.get_model('pyc_sample', 'Result')
    Result.objects.filter(result_type='Volume').update(result_rank='S')


def update_result_name(apps, schema_editor):
    """Update all the results to fill in the proper name. """
    Result = apps.get_model('pyc_sample', 'Result')
    for result_type, result_name in {
        "Volume": "volume",
        "Absolute Density": "absolute_density",
        "Last Density": "last_density",
        "Open Cell Percent": "open_cell_percent",
        "P1 Percent Change": "p1_percent_change",
        "Percent Change": "percent_change",
    }.items():
        Result.objects.filter(result_type=result_type).update(result_name=result_name)


def move_results(apps, schema_editor):
    """Update all the Results backlinks to the AnalysisResult many to many forward link. """
    Result = apps.get_model('pyc_sample', 'Result')
    for result in Result.objects.all():  # pragma: no cover # don't worry about old migrations.
        result.analysis.results.add(result)


def move_results_model(apps, schema_editor):
    """Move the pyc_sample_results model data to mic_python_lib_results"""
    AnalysisResult = apps.get_model('pyc_sample', 'AnalysisResult')
    NewResult = apps.get_model('mic_python_lib', 'Result')
    for anl in AnalysisResult.objects.all():  # pragma: no cover # don't worry about old migrations.
        # for now, there are only one anl object for each result.  That may change in the future,
        # but this is OK here.
        for old in anl.results.all():
            new = NewResult(
                analysis_technique=old.analysis_technique,
                result_title=old.result_title,
                result_name=old.result_name,
                result_rank=old.result_rank,
                value=old.value,
                std_dev=old.std_dev,
                units_json=old.units_json,
                format_json=old.format_json,
            )
            new.save()
            anl.newresults.add(new)


class Migration(migrations.Migration):

    dependencies = [
        ('pyc_sample', '0030_add_cup_to_anal_and_cal'),
        ('mic_python_lib', '0008_move_results'),
    ]

    operations = [
        migrations.AddField(
            model_name='result',
            name='result_rank',
            field=models.CharField(
                choices=[('P', 'primary'), ('S', 'secondary'), ('C', 'calculated'),
                         ('R', 'runtime monitor')],
                default='P',
                max_length=1
            ),
        ),
        migrations.RunPython(update_last_density),
        migrations.RunPython(update_volume),
        migrations.AddField(
            model_name='result',
            name='result_name',
            field=models.CharField(default='', max_length=32),
            preserve_default=False,
        ),
        migrations.RunPython(update_result_name),
        migrations.RenameField(
            model_name='result',
            old_name='result_type',
            new_name='result_title',
        ),
        migrations.AddField(
            model_name='analysisresult',
            name='results',
            field=models.ManyToManyField(to='pyc_sample.Result'),
        ),
        migrations.RunPython(move_results),
        migrations.RemoveField(
            model_name='result',
            name='analysis',
        ),
        migrations.AddField(
            model_name='analysisresult',
            name='newresults',
            field=models.ManyToManyField(to='mic_python_lib.Result'),
        ),
        migrations.RunPython(move_results_model),
        migrations.RemoveField(
            model_name='analysisresult',
            name='results',
        ),
        migrations.DeleteModel(name='Result',),
        migrations.RenameField(
            model_name='analysisresult',
            old_name='newresults',
            new_name='results',
        ),
    ]
