from django.db import migrations, models
from pyc_sample.models import copy_model_obj


def copy_used_inserts(apps, schema_editor):

    def _remove_duplicates(kind):
        dup_names = (
            Insert.objects.filter(kind=kind,
                                  is_method=True).values('name').annotate(models.Count('id')
                                                                         ).filter(id__count__gt=1)
        )
        for dup in dup_names:
            dups = list(Insert.objects.filter(kind=kind, is_method=True, name=dup['name']))
            for ins in dups[1:]:
                # Update the methods that refer to the duplicate insert by making them refer to
                # the kept one.  (note that calibrations and analysis results have copies so
                # that they are not affected.)
                if kind == 'C':
                    AnalysisParameters.objects.filter(cup=ins).update(cup=dups[0])
                elif kind == 'I':
                    AnalysisParameters.objects.filter(insert=ins).update(insert=dups[0])
                ins.delete()

    AnalysisParameters = apps.get_model('pyc_sample', 'AnalysisParameters')
    Insert = apps.get_model('pyc_sample', 'Insert')
    Calibration = apps.get_model('pyc_sample', 'Calibration')

    # inserts on parameter files that are local to a result need a copy.
    for prm in AnalysisParameters.objects.filter(is_method=False):
        if prm.cup is not None:
            prm.cup = copy_model_obj(Insert, prm.cup, save=False)
            prm.cup.active = True
            prm.cup.save()
        if prm.insert is not None:
            prm.insert = copy_model_obj(Insert, prm.insert, save=False)
            prm.insert.active = True
            prm.insert.save()
            prm.save()

    # calibrations require copies of inserts as well.
    for cal in Calibration.objects.all():
        cal.ref_ball = copy_model_obj(Insert, cal.ref_ball, save=False)
        cal.ref_ball.active = True
        cal.ref_ball.save()
        if cal.cup is not None:
            cal.cup = copy_model_obj(Insert, cal.cup, save=False)
            cal.cup.active = True
            cal.cup.save()
            cal.save()

    # now delete all the inactive ones. Those used are copied, those not used are unneeded.
    Insert.objects.filter(active=False).delete()

    # now remove duplicates that may have crept in.
    _remove_duplicates('C')
    _remove_duplicates('I')
    _remove_duplicates('R')


class Migration(migrations.Migration):

    dependencies = [
        ('pyc_sample', '0047_correct_cycles_default'),
    ]
    operations = [
        migrations.AddField(
            model_name='insert',
            name='is_method',
            field=models.BooleanField(default=True),
        ),
        migrations.RunPython(copy_used_inserts),
        migrations.RemoveField(
            model_name='insert',
            name='active',
        ),
        migrations.AddConstraint(
            model_name='insert',
            constraint=models.UniqueConstraint(
                condition=models.Q(is_method=True), fields=('name', 'kind'), name='unique_name'
            ),
        ),
    ]
