# Generated by Django 3.1.2 on 2022-04-19 15:29

import datetime
import pytz
from django.db import migrations, models
from django.utils import timezone
import pyc_sample.models


def set_last_updated(apps, schema_editor):
    "Set the last_updated in AnalysisParameters to now for methods."
    AnalysisParameters = apps.get_model('pyc_sample', 'AnalysisParameters')
    AnalysisParameters.objects.filter(is_method=True).update(
        last_updated=datetime.datetime(2020, 1, 1, 0, 0, 0, 0, pytz.UTC)
    )
    Inserts = apps.get_model('pyc_sample', 'Insert')
    Inserts.objects.filter(is_method=True).update(
        last_updated=datetime.datetime(2020, 1, 1, 0, 0, 0, 0, pytz.UTC)
    )


class Migration(migrations.Migration):

    dependencies = [
        ('pyc_sample', '0048_save_inst_therm_expan_in_cal'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='insert',
            name='unique_name',
        ),
        migrations.AddField(
            model_name='insert',
            name='last_updated',
            field=models.DateTimeField(null=True),
        ),
        migrations.AddField(
            model_name='analysisparameters',
            name='last_updated',
            field=models.DateTimeField(null=True),
        ),
        migrations.AddField(
            model_name='analysisresult',
            name='last_updated',
            field=models.DateTimeField(default=timezone.now()),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='calibration',
            name='last_updated',
            field=models.DateTimeField(default=timezone.now()),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='instrument',
            name='last_updated',
            field=models.DateTimeField(default=timezone.now()),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='calibration',
            name='cup_name',
            field=models.CharField(
                blank=True,
                default="Cup(???)",
                max_length=16,
                verbose_name='Cup Name',
            ),
        ),
        migrations.RunPython(set_last_updated),
        migrations.AddConstraint(
            model_name='insert',
            constraint=models.CheckConstraint(
                check=models.Q(('is_method', False), ('last_updated__isnull', False),
                               _connector='OR'),
                name='insert_methods_must_have_updated'
            ),
        ),
        migrations.AddConstraint(
            model_name='insert',
            constraint=models.CheckConstraint(
                check=models.Q(('is_method', True), ('last_updated__isnull', True),
                               _connector='OR'),
                name='insert_copies_dont_have_updated'
            ),
        ),
        migrations.AddConstraint(
            model_name='analysisparameters',
            constraint=models.CheckConstraint(
                check=models.Q(('is_method', False), ('last_updated__isnull', False),
                               _connector='OR'),
                name='methods_must_have_updated'
            ),
        ),
        migrations.AddConstraint(
            model_name='analysisparameters',
            constraint=models.CheckConstraint(
                check=models.Q(('is_method', True), ('last_updated__isnull', True),
                               _connector='OR'),
                name='copies_dont_have_updated'
            ),
        ),
        migrations.AddConstraint(
            model_name='analysisparameters',
            constraint=models.UniqueConstraint(
                condition=models.Q(is_method=True), fields=('name',), name='unique_method_name'
            ),
        ),
        migrations.AddConstraint(
            model_name='analysisresult',
            constraint=models.UniqueConstraint(
                fields=('start_time', 'instrument'), name='result_id'
            ),
        ),
        migrations.AddConstraint(
            model_name='calibration',
            constraint=models.UniqueConstraint(fields=('start_time', 'instrument'), name='cal_id'),
        ),
        migrations.AddConstraint(
            model_name='insert',
            constraint=models.UniqueConstraint(
                condition=models.Q(is_method=True),
                fields=('name', 'kind'),
                name='unique_insert_name'
            ),
        ),
        migrations.AddConstraint(
            model_name='instrument',
            constraint=models.UniqueConstraint(
                condition=models.Q(is_local=True), fields=('model', 'serial'), name='single_local'
            ),
        ),
    ]
