"The mock request functionality that allows setting up a file. "
import contextlib
import sys
# pylint: disable=too-few-public-methods,missing-class-docstring,attribute-defined-outside-init

_CONTEXT = None


class HTTPFile:
    "Simulates a file that can be served as an http object."

    def __init__(self, name, contents):
        self.name = name
        self.contents = contents


class HTTPSite:
    "Simulates a whole site with multiple files."

    def __init__(self):
        self.urls = {}

    def add_file(self, url, filename, contents=""):
        "add a file to the site."
        file_url = url + '/' + filename
        self.urls[file_url] = HTTPFile(filename, contents)

    def page(self, url):
        "get the page at that url."
        if url in self.urls.keys():
            return self.urls[url]
        if url+"/index.html" in self.urls.keys():
            return self.urls[url+"/index.html"]
        return None


@contextlib.contextmanager
def http_context():
    "Create a context for a site."
    site = HTTPSite()
    setattr(sys.modules[__name__], "_CONTEXT", site)
    yield site
    setattr(sys.modules[__name__], "_CONTEXT", None)


def get(url, stream=False, timeout=None): # pylint: disable=unused-argument
    "mock the requests.get call."
    class Object:
        pass

    ret = Object()
    page = _CONTEXT.page(url) if _CONTEXT else None
    if page is None:
        ret.status_code = 404
    else:
        ret.status_code = 200
        if stream:
            ret.iter_content = \
                lambda chunk_size: [_CONTEXT.page(url).contents.encode('utf-8')]
        else:
            ret.content = _CONTEXT.page(url).contents.encode('utf-8')
    return ret

class exceptions: # pylint: disable=invalid-name
    class ConnectTimeout:
        pass
    class ConnectionError:
        pass
