"""test driver for the accupyc1345 functionality. """
import datetime
import importlib
import json
from django.test import TestCase
from django.utils import timezone
from mic_python_lib.models import LogMessage, Settings
import i1350
from mic_cpp import cpp
import pyc_sample.accupyc1345 as accu
from ..models import AnalysisResult1345, Instrument, LegacyInstrument
from ..services import accu_or_foam_results_from_anl

# pylint: disable=too-many-lines,invalid-name,missing-function-docstring,too-many-statements
mock_requsts = importlib.import_module(".mock_requests", "pyc_sample.tests")
# =========================================================================
_NO_DATA_REPORT = """<pre>
No collected data to report, or all cycles excluded.
</pre>"""

_STD_REPORT_1 = """<pre>
                           AccuPycII 1345 V4.00
                            Serial Number: 4467
                         Density and Volume Report


Sample ID: Test this                    Started: 13/05/22  08:58:36
Sample Mass:   0.0000 g                 Completed: 13/05/22  09:06:55
Temperature: 22.080 °C
Number of Purges:  10                   Equilibration Rate:  0.0345 kPag/min
Cell Volume: 110.6135 cm3               Expansion Volume:  73.6274 cm3


            Volume    Deviation   Density   Deviation   Elapsed  Temperature
   Cycle#     cm3        cm3       g/cm3      g/cm3      Time        °C
   ------  --------   ---------   -------   ---------  --------  -----------
      1      0.0101    -0.0343     0.0000     0.0000    0:04:55      21.995
      2      0.0234    -0.0210     0.0000     0.0000    0:06:07      22.074
      3      0.0997     0.0553     0.0000     0.0000    0:07:20      22.045


Average Volume:   0.0444 cm3            Standard Deviation:  0.0395 cm3
Average Density:  0.0000 g/cm3          Standard Deviation: 0.0000 g/cm3
</pre>"""

_STD_REPORT_1A = """<pre>
                           AccuPycII 1345 V4.00
                            Serial Number: 4467
                         Density and Volume Report


Sample ID: Test this                    Started: 26/05/22  08:58:36
Sample Mass:   0.0000 g                 Completed: 26/05/22  09:06:55
Temperature: 22.080 °C
Number of Purges:  10                   Equilibration Rate:  0.0345 kPag/min
Cell Volume: 110.6135 cm3               Expansion Volume:  73.6274 cm3


            Volume    Deviation   Density   Deviation   Elapsed  Temperature
   Cycle#     cm3        cm3       g/cm3      g/cm3      Time        °C
   ------  --------   ---------   -------   ---------  --------  -----------
      1      0.0101    -0.0343     0.0000     0.0000    0:04:55      21.995
      2      0.0234    -0.0210     0.0000     0.0000    0:06:07      22.074
      3      0.0997     0.0553     0.0000     0.0000    0:07:20      22.045


Average Volume:   0.0444 cm3            Standard Deviation:  0.0395 cm3
Average Density:  0.0000 g/cm3          Standard Deviation: 0.0000 g/cm3
</pre>"""

# File from Chris 5/23/2022: ID, Description, 10P, 10C, kPag, Volume.html
_STD_REPORT_2 = """
<!-- saved from url=(0056)http://192.168.78.1/4474/Sample%20ID%20for%20Stefan.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           AccuPycII 1345 V4.00
                            Serial Number: 4474
                         Density and Volume Report
                           Stefan D1!@#%^-1235
                           Line 2 *&amp;^`


Sample ID: Sample ID for Stefan         Started: 23/05/22  08:46:03
Sample Mass:   0.0000 g                 Completed: 23/05/22  09:11:50
Temperature: 24.024 °C
Number of Purges:  10                   Equilibration Rate:  0.0345 kPag/min
Cell Volume:  11.7687 cm3               Expansion Volume:   8.4018 cm3


            Volume    Deviation   Density   Deviation   Elapsed  Temperature
   Cycle#     cm3        cm3       g/cm3      g/cm3      Time        °C
   ------  --------   ---------   -------   ---------  --------  -----------
      1      6.3599    -0.0006     0.0000     0.0000    0:06:53      23.804
      2      6.3592    -0.0013     0.0000     0.0000    0:08:56      23.799
      3      6.3598    -0.0007     0.0000     0.0000    0:10:52      23.815
      4      6.3597    -0.0008     0.0000     0.0000    0:12:57      23.873
      5      6.3614     0.0009     0.0000     0.0000    0:15:04      23.922
      6      6.3611     0.0006     0.0000     0.0000    0:17:07      23.919
      7      6.3601    -0.0004     0.0000     0.0000    0:19:11      23.882
      8      6.3611     0.0006     0.0000     0.0000    0:21:22      23.991
      9      6.3615     0.0010     0.0000     0.0000    0:23:29      23.931
     10      6.3612     0.0008     0.0000     0.0000    0:25:39      24.011


Average Volume:   6.3605 cm3            Standard Deviation:  0.0008 cm3
Average Density:  0.0000 g/cm3          Standard Deviation: 0.0000 g/cm3
</pre>
</body></html>"""

# File from Chris 5/23/2022: 1P, 1C.html
_STD_REPORT_3 = """<!-- saved from url=(0040)http://192.168.78.1/4474/untitled-2.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           AccuPycII 1345 V4.00
                            Serial Number: 4474
                         Density and Volume Report




Sample ID:                              Started: 23/05/22  09:42:55
Sample Mass:   0.0000 g                 Completed: 23/05/22  09:47:11
Temperature: 23.990 °C
Number of Purges:   1                   Equilibration Rate: 0.0060 psig/min
Cell Volume:  11.7687 cm3               Expansion Volume:   8.4018 cm3


            Volume    Deviation   Density   Deviation   Elapsed  Temperature
   Cycle#     cm3        cm3       g/cm3      g/cm3      Time        °C
   ------  --------   ---------   -------   ---------  --------  -----------
      1      6.3612     0.0000     0.0000     0.0000    0:04:08      24.064


Average Volume:   6.3612 cm3            Standard Deviation:  0.0000 cm3
Average Density:  0.0000 g/cm3          Standard Deviation: 0.0000 g/cm3
</pre>
</body></html>"""

# File from Chris 5/23/2022: 30s interval, specific gravity, 5P, 15C, Cup mass.html
_STD_REPORT_4 = """<!-- saved from url=(0040)http://192.168.78.1/4467/untitled-2.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           AccuPycII 1345 V4.00
                            Serial Number: 4467
                    Specific Gravity and Volume Report


Sample ID:                              Started: 23/05/22  08:44:49
Sample Mass:   1.0000 g                 Completed: 23/05/22  09:26:25
Temperature: 20.036 °C                  Cup Mass:   1.0000 g
Number of Purges:   5                   Interval time:    30 s
Cell Volume: 110.6318 cm3               Expansion Volume:  73.7282 cm3


            Volume    Deviation   Specific  Deviation   Elapsed  Temperature
   Cycle#     cm3        cm3      Gravity     g/cm3      Time        °C
   ------  --------   ---------   -------   ---------  --------  -----------
      1     51.1047     0.1128     0.0196    -0.0000    0:06:39      20.020
      2     50.9446    -0.0472     0.0197     0.0000    0:09:09      19.973
      3     50.9339    -0.0579     0.0197     0.0000    0:11:41      20.040
      4     50.8962    -0.0956     0.0197     0.0000    0:14:08      20.050
      5     50.9084    -0.0835     0.0197     0.0000    0:16:36      19.982
      6     50.8967    -0.0951     0.0197     0.0000    0:19:06      20.025
      7     51.0292     0.0374     0.0196    -0.0000    0:21:36      20.004
      8     50.8988    -0.0931     0.0197     0.0000    0:24:09      20.051
      9     50.9207    -0.0711     0.0197     0.0000    0:26:38      20.002
     10     51.0962     0.1043     0.0196    -0.0000    0:29:07      20.052
     11     51.1059     0.1141     0.0196    -0.0000    0:31:35      20.037
     12     51.1141     0.1223     0.0196    -0.0000    0:34:02      20.009
     13     51.0758     0.0840     0.0196    -0.0000    0:36:29      20.006
     14     51.0708     0.0790     0.0196    -0.0000    0:38:57      20.049
     15     50.8814    -0.1104     0.0197     0.0000    0:41:28      20.062


Average Volume:  50.9918 cm3            Standard Deviation:  0.0905 cm3
Average Specific Gravity:  0.0196       Standard Deviation: 0.0000
</pre>
</body></html>"""

# File from Chris 5/23/2022: 35cc insert, psig, 1P, 4C.html
_STD_REPORT_5 = """
<!-- saved from url=(0040)http://192.168.78.1/4466/untitled-2.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           AccuPycII 1345 V4.00
                            Serial Number: 4466
                         Density and Volume Report


Sample ID:                              Started: 23/05/22  09:44:17
Sample Mass:   1.0000 g                 Completed: 23/05/22  09:56:09
Temperature: 22.540 °C
Number of Purges:   1                   Equilibration Rate: 0.0100 psig/min
Cell Volume:  38.8890 cm3               Expansion Volume:  76.1100 cm3


            Volume    Deviation   Density   Deviation   Elapsed  Temperature
   Cycle#     cm3        cm3       g/cm3      g/cm3      Time        °C
   ------  --------   ---------   -------   ---------  --------  -----------
      1    -22.6128     0.0047     0.0000     0.0000    0:04:52      22.512
      2    -22.6220    -0.0045     0.0000     0.0000    0:07:08      22.536
      3    -22.6271    -0.0096     0.0000     0.0000    0:09:27      22.521
      4    -22.6081     0.0094     0.0000     0.0000    0:11:45      22.590


Average Volume: -22.6175 cm3            Standard Deviation:  0.0075 cm3
Average Density:  0.0000 g/cm3          Standard Deviation: 0.0000 g/cm3
</pre>
</body></html>"""

# File from Chris 5/23/2022: FoamPyc - Standard.html
_STD_REPORT_6 = """<!-- saved from url=(0031)http://192.168.78.1/4474/1.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           AccuPycII 1345 V4.00
                            Seriennummer: 4474
                         Dichte und Volumenbericht
                           65
                           2


Probenname: 1                           Beginn: 23/05/22  13:06:57
Probengewicht:   0.0000 g               Ende: 23/05/22  13:21:20
Temperatur: 24.1 °C
Spülzyklen:   3                         Gleichgewicht: 0.0100 psig/min
Zellvolumen:  11.7687 cm3               Expansionsvolumen:   8.4018 cm3


    Mess.   Volumen   Abweichung  Dichte   Abweichung   Meßzeit  Temperatur
     Nr       cm3        cm3       g/cm3      g/cm3     (h:m:s)      °C
   ------  --------   ----------  -------  ----------  --------  ----------
      1      6.3603    -0.0006     0.0000     0.0000    0:03:59      24.0
      2      6.3607    -0.0002     0.0000     0.0000    0:05:43      24.0
      3      6.3602    -0.0007     0.0000     0.0000    0:07:27      24.0
      4      6.3614     0.0005     0.0000     0.0000    0:09:12      24.0
      5      6.3610     0.0001     0.0000     0.0000    0:10:54      24.1
      6      6.3615     0.0006     0.0000     0.0000    0:12:35      24.1
      7      6.3612     0.0003     0.0000     0.0000    0:14:15      24.1


Mittleres Volumen:   6.3609 cm3         Standardabweichung:  0.0005 cm3
Mittlere Dichte:     0.0000 g/cm3       Standardabweichung: 0.0000 g/cm3
</pre>
</body></html>"""

_STD_REPORT_7 = """<!-- saved from url=(0037)http://192.168.78.1/4474/Quattro.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           AccuPycII 1345 V4.00
                         Numero di Matricola: 4474
                        Report di Densita' e Volume
                           Ciao
                           Pasta


Ser.Num.del Camp: Quattro               Iniziata: 26/05/22  07:38:44
Peso del Campione:   0.0000 g           Terminata: 26/05/22  07:44:52
Temperatura: 23.729 °C
Num. Cicli Condiz:   1                  Intervallo di tempo:    10 s
Volume Della Cella:  11.7687 cm3        Vol.Camera in Espan:   8.4018 cm3


            Volume    Deviazione  Densita' Deviazione  Durata    Temperatura
   Ciclo#     cm3        cm3       g/cm3      g/cm3   dell' Analisi   °C
   ------  --------   ----------  -------- ----------  ----------- ---------
      1      5.7911    -0.0202     0.0000     0.0000    0:03:00      23.692
      2      5.8097    -0.0016     0.0000     0.0000    0:04:31      23.694
      3      5.8332     0.0219     0.0000     0.0000    0:06:00      23.717


Volume Medio:     5.8113 cm3            Deviazione Standard:  0.0172 cm3
Densita' Media:   0.0000 g/cm3          Deviazione Standard: 0.0000 g/cm3
</pre>
</body></html>"""

_STD_REPORT_8 = """
<!-- saved from url=(0034)http://192.168.78.1/4474/Tres.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           AccuPycII 1345 V4.00
                           Numero de Serie: 4474
                       Reporte de Densidad y Volumen
                           Cuatro
                           Cinco


ID Muestra: Tres                        Comenzado: 26/05/22  07:30:26
Peso Muestra:   0.0000 g                Completado: 26/05/22  07:36:32
Temperatura: 23.616 °C
Numero de Purgas:   1                   Intervalo de tiempo:    10 s
Volumen Celda:   11.7687 cm3            Volumen Expansion:   8.4018 cm3


            Volumen   Desviacion  Densidad Desviacion  Duracion  Temperatura
   Proc#      cm3        cm3       g/cm3      g/cm3    (h:m:s)       °C
   ------  --------   ----------  -------- ----------- --------- -----------
      1      5.7885    -0.0100     0.0000     0.0000    0:02:58      23.593
      2      5.7997     0.0011     0.0000     0.0000    0:04:29      23.635
      3      5.8075     0.0089     0.0000     0.0000    0:05:59      23.640


Volumen Promedio:   5.7986 cm3          Desviacion Standard:  0.0078 cm3
Densidad Promedio:  0.0000 g/cm3        Desviacion Standard: 0.0000 g/cm3
</pre>
</body></html>"""

_STD_REPORT_9 = """<!-- saved from url=(0031)http://192.168.78.1/4474/2.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           AccuPycII 1345 V4.00
                           Numero de Serie: 4474
                      Rapport de Densite et de Volume
                           2
                           3


ID echantillon: 2                       Commence: 26/05/22  07:22:49
Poids echantillon:   0.0000 g           Fini: 26/05/22  07:28:58
Temperature: 23.551 °C
Nombre de Purges:   1                   Intervalle de temps:    10 s
Volume de Cellule:  11.7687 cm3         Volume d'Expansion:   8.4018 cm3


            Volume    Deviation   Densite   Deviation   Temps    Temperature
   Proc#      cm3        cm3       g/cm3      g/cm3     Ecoule       °C
   ------  --------   ----------  -------  ----------  --------  -----------
      1      5.7688    -0.0659     0.0000     0.0000    0:03:00      23.546
      2      5.8667     0.0319     0.0000     0.0000    0:04:31      23.564
      3      5.8687     0.0340     0.0000     0.0000    0:06:01      23.562


Volume Moyen:     5.8347 cm3            Deviation Standard:  0.0466 cm3
Densite Moyenne:  0.0000 g/cm3          Deviation Standard: 0.0000 g/cm3
</pre>
</body></html>"""

_STD_REPORT_10 = """<!-- saved from url=(0031)http://192.168.78.1/4474/1.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           AccuPycII 1345 V4.00
                            Seriennummer: 4474
                         Dichte und Volumenbericht
                           1
                           2


Probenname: 1                           Beginn: 26/05/22  07:06:32
Probengewicht:   0.0000 g               Ende: 26/05/22  07:12:42
Temperatur: 23.533 °C
Spülzyklen:   1                         Intervall Dauer:    10 s
Zellvolumen:  0.97687 cm3               Expansionsvolumen:   0.84018 cm3


    Mess.   Volumen   Abweichung  Dichte   Abweichung   Meßzeit  Temperatur
     Nr       cm3        cm3       g/cm3      g/cm3     (h:m:s)      °C
   ------  --------   ----------  -------  ----------  --------  ----------
      1      5.7739    -0.0233     0.0000     0.0000    0:03:02      23.420
      2      5.7788    -0.0184     0.0000     0.0000    0:04:32      23.410
      3      5.8389     0.0417     0.0000     0.0000    0:06:03      23.450


Mittleres Volumen:   5.7972 cm3         Standardabweichung:  0.0295 cm3
Mittlere Dichte:     0.0000 g/cm3       Standardabweichung: 0.0000 g/cm3
</pre>
</body></html>"""

_STD_REPORT_11 = """
<!-- saved from url=(0031)http://192.168.78.1/4474/0.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           AccuPycII 1345 V4.00
                            Serial Number: 4474
                         Density and Volume Report
                           0
                           0


Sample ID: 0                            Started: 27/05/22  07:46:28
Sample Mass:   0.0000 g                 Completed:
Temperature:
Number of Purges:   0                   Interval time:    10 s
Cell Volume:  11.7687 cm3               Expansion Volume:   8.4018 cm3


            Volume    Deviation   Density   Deviation   Elapsed  Temperature
   Cycle#     cm3        cm3       g/cm3      g/cm3      Time        °C
   ------  --------   ---------   -------   ---------  --------  -----------
      1*    -2.4487    -0.2965     0.0000     0.0000    0:01:15      23.562
      2*    -2.2761    -0.1238     0.0000     0.0000    0:03:20      23.607
      3*    -2.1814    -0.0291     0.0000     0.0000    0:05:28      23.593
      4*    -2.0089     0.1433     0.0000     0.0000    0:07:35      23.583
      5     -2.2336    -0.0813     0.0000     0.0000    0:09:41      23.652
      6     -2.1419     0.0103     0.0000     0.0000    0:11:49      23.704
      7     -2.1607    -0.0085     0.0000     0.0000    0:13:55      23.795
      8     -2.1276     0.0247     0.0000     0.0000    0:16:02      23.785
      9     -2.0974     0.0548     0.0000     0.0000    0:18:09      23.829


Average Volume:  -2.1522 cm3            Standard Deviation:  0.0456 cm3
Average Density:  0.0000 g/cm3          Standard Deviation: 0.0000 g/cm3
</pre>
</body></html>"""

# File from Chris 5/23/2022: FoamPyc - Deutsch, Correction Cell Dimension, in.html
_METHOD_A_1 = """<!-- saved from url=(0040)http://192.168.78.1/4467/untitled-3.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Seriennummer: 4467
                        Volumen-Bericht, korrigiert
                   Korrektur auf Basis Zellendimensionen


Probenname:                             Beginn: 23/05/22  13:09:51
Probengewicht:  67.0000 g               Ende: 23/05/22  13:14:57
Temperatur: 20.0 °C                     Geometrisches Vol.:   0.2500 in3
Spülzyklen:   1                         Intervall Dauer:    10 s
Zellvolumen:   6.7512 in3               Expansionsvolumen:   4.4992 in3
Zellwanddichte:  2.0000 g/cm3           Aktive Fläeche: 1.5000 in2
Sehnenlänge: 0.0394 in
Anzahl Häuete: 3


                                                         Zellwand+
                                                           Anteil
 Mess.    P1       P2     Volumen  Abweichung  Offen-   geschlossen Messzeit
  Nr     psig     psig      in3        in3   zelligk.%    Zellen %   (h:m:s)
------  -------  -------  -------- ---------- -------- ------------- -------
   1     3.8591   2.6854   -3.5646     0.0099  1505.10    -1405.10      0:01:43
   2     3.9332   2.7320   -3.5039     0.0706  1480.83    -1380.83      0:02:32
   3     3.9655   2.7693   -3.6879    -0.1134  1554.43    -1454.43      0:03:21
   4     3.9493   2.7515   -3.6064    -0.0319  1521.83    -1421.83      0:04:10
   5     3.9867   2.7696   -3.5096     0.0649  1483.09    -1383.09      0:04:59


Mittleres Volumen:  -3.5745 in3         Standardabweichung:  0.0681 in3


        -----------------------------------------------------------
        Volumen Zellwand:   2.0443 in3
        Prozentualer Anteil Zellwand: 817.72%
        Offenzelligkeit / %: 1509.05%
        Prozentualer Anteil Zellwand + geschlossene Zellen: -1409.05%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_A_2 = """<!-- saved from url=(0040)http://192.168.78.1/4467/untitled-5.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Seriennummer: 4467
                        Volumen-Bericht, korrigiert
                   Korrektur auf Basis Zellendimensionen


Probenname:                             Beginn: 25/05/22  08:43:23
Probengewicht:   0.0000 g               Ende: 25/05/22  08:48:29
Temperatur: 20.0 °C                     Geometrisches Vol.:   0.7854 in3
Spülzyklen:   1                         Gleichgewicht: 0.1000 psig/min
Zellvolumen:   6.7512 in3               Expansionsvolumen:   4.4992 in3
Zellwanddichte:  1.0000 g/cm3           Aktive Fläeche: 3.9270 in2
Zelldurchmesserr: 0.0394 in
Anzahl Häuete: 1


                                                         Zellwand+
                                                           Anteil
 Mess.    P1       P2     Volumen  Abweichung  Offen-   geschlossen Messzeit
  Nr     psig     psig      in3        in3   zelligk.%    Zellen %   (h:m:s)
------  -------  -------  -------- ---------- -------- ------------- -------
   1     3.7637   1.6810    3.1196    -0.0015  -310.77    410.77      0:02:26
   2     3.7862   1.6904    3.1222     0.0010  -311.10    411.10      0:03:43
   3     3.8164   1.7041    3.1216     0.0005  -311.03    411.03      0:04:59


Mittleres Volumen:   3.1211 in3         Standardabweichung:  0.0011 in3


        -----------------------------------------------------------
        Volumen Zellwand:   0.0000 in3
        Prozentualer Anteil Zellwand:   0.00%
        Offenzelligkeit / %: -310.97%
        Prozentualer Anteil Zellwand + geschlossene Zellen: 410.97%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_A_3 = """
<!-- saved from url=(0040)http://192.168.78.1/4474/untitled-5.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Seriennummer: 4474
                        Volumen-Bericht, korrigiert
                   Korrektur auf Basis Zellendimensionen




Probenname:                             Beginn: 25/05/22  08:43:18
Probengewicht:   0.0000 g               Ende: 25/05/22  08:47:39
Temperatur: 23.9 °C                     Geometrisches Vol.:   1.0000 in3
Spülzyklen:   1                         Gleichgewicht: 0.1000 psig/min
Zellvolumen:   0.7182 in3               Expansionsvolumen:   0.5127 in3
Zellwanddichte:  1.0000 g/cm3           Aktive Fläeche: 5.0000 in2
Sehnenlänge: 0.0394 in
Anzahl Häuete: 1


                                                         Zellwand+
                                                           Anteil
 Mess.    P1       P2     Volumen  Abweichung  Offen-   geschlossen Messzeit
  Nr     psig     psig      in3        in3   zelligk.%    Zellen %   (h:m:s)
------  -------  -------  -------- ---------- -------- ------------- -------
   1    19.9770   7.8236    0.3881    -0.0000   43.91     56.09      0:02:49
   2    20.0230   7.8411    0.3882     0.0000   43.90     56.10      0:04:13


Mittleres Volumen:   0.3881 in3         Standardabweichung:  0.0000 in3


        -----------------------------------------------------------
        Volumen Zellwand:   0.0000 in3
        Prozentualer Anteil Zellwand:   0.00%
        Offenzelligkeit / %:  43.91%
        Prozentualer Anteil Zellwand + geschlossene Zellen:  56.09%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_A_4 = """<!-- saved from url=(0040)http://192.168.78.1/4467/untitled-4.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Serial Number: 4467
                          Corrected Volume Report
                     Correction using Cell Dimensions


Sample ID:                              Started: 25/05/22  08:35:05
Sample Mass:   0.0000 g                 Completed: 25/05/22  08:40:12
Temperature: 20.0 °C                    Geometric Volume:   0.7854 in3
Number of Purges:   1                   Equilibration Rate: 0.1000 psig/min
Cell Volume:   6.7512 in3               Expansion Volume:   4.4992 in3
Cell Wall Density:  1.0000 g/cm3        Active Area: 3.9270 in2
Cell Diameter: 0.0394 in
Number of Skins: 1


          P1       P2      Volume   Deviation   Open    Cell Wall+   Elapsed
Cycle#   psig     psig      in3        in3     Cell %  Closed Cell %   Time
------  -------  -------  --------  ---------  ------  ------------  -------
   1     3.8017   1.6975    3.1214     0.0007  -311.00    411.00      0:02:24
   2     3.7932   1.6946    3.1180    -0.0027  -310.57    410.57      0:03:41
   3     3.8481   1.7179    3.1227     0.0020  -311.16    411.16      0:04:59


Average Volume:   3.1207 in3            Standard Deviation:  0.0020 in3


        -----------------------------------------------------------
        Cell Wall Volume:   0.0000 in3
        Cell Wall Volume Percentage:   0.00%
        Open Cell Percentage: -310.91%
        Cell Wall + Closed Cell Percentage: 410.91%
        -----------------------------------------------------------
</pre>
</body></html>
"""

_METHOD_A_5 = """
<!-- saved from url=(0038)http://192.168.78.1/4474/untitled.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Serial Number: 4474
                          Corrected Volume Report
                     Correction using Cell Dimensions




Sample ID:                              Started: 25/05/22  08:35:00
Sample Mass:   0.0000 g                 Completed: 25/05/22  08:39:22
Temperature: 24.0 °C                    Geometric Volume:   1.0000 in3
Number of Purges:   1                   Equilibration Rate: 0.1000 psig/min
Cell Volume:   0.7182 in3               Expansion Volume:   0.5127 in3
Cell Wall Density:  1.0000 g/cm3        Active Area: 5.0000 in2
Chord Length: 0.0394 in
Number of Skins: 1


          P1       P2      Volume   Deviation   Open    Cell Wall+   Elapsed
Cycle#   psig     psig      in3        in3     Cell %  Closed Cell %   Time
------  -------  -------  --------  ---------  ------  ------------  -------
   1    20.0258   7.8426    0.3881    -0.0000   43.91     56.09      0:02:49
   2    19.9192   7.7995    0.3882     0.0000   43.90     56.10      0:04:14


Average Volume:   0.3882 in3            Standard Deviation:  0.0000 in3


        -----------------------------------------------------------
        Cell Wall Volume:   0.0000 in3
        Cell Wall Volume Percentage:   0.00%
        Open Cell Percentage:  43.90%
        Cell Wall + Closed Cell Percentage:  56.10%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_A_6 = """<!-- saved from url=(0040)http://192.168.78.1/4467/untitled-6.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                           Numero de Serie: 4467
                        Rapport sur volume corrige
                  Correction par dimension de la cellule


ID echantillon:                         Commence: 25/05/22  09:05:29
Poids echantillon:   0.0000 g           Fini: 25/05/22  09:10:36
Temperature: 20.0 °C                    Volume geometrique:   0.7854 in3
Nombre de Purges:   1                   Taux d'Equilibre: 0.1000 psig/min
Volume de Cellule:   6.7512 in3         Volume d'Expansion:   4.4992 in3
Densite de la Paroi Cellulaire:  1.0000 g/cm3Surface active: 3.9270 in2
Diametre cellule: 0.0394 in
Nombre de arretes: 1


          P1       P2      Volume   Deviation  Cellule Resine+Cell.   Temps
Proc#    psig     psig      in3        in3    Ouverte%   Fermee%     Ecoule
------  -------  -------  --------  --------- -------- ------------- -------
   1     3.9230   1.7528    3.1172    -0.0025  -310.47    410.47      0:02:25
   2     4.0183   1.7953    3.1177    -0.0020  -310.53    410.53      0:03:43
   3     3.9340   1.7559    3.1242     0.0045  -311.36    411.36      0:05:00


Volume Moyen:     3.1197 in3            Deviation Standard:  0.0032 in3


        -----------------------------------------------------------
        Volume de paroi cellulaire:   0.0000 in3
        Pourcentage de volume de paroi cellulaire:   0.00%
        Purcentage cellules ouvertes: -310.79%
        Paroi cellulaire + pourcentage de cellules fermées: 410.79%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_A_7 = """<!-- saved from url=(0040)http://192.168.78.1/4474/untitled-2.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                           Numero de Serie: 4474
                        Rapport sur volume corrige
                  Correction par dimension de la cellule




ID echantillon:                         Commence: 25/05/22  09:05:34
Poids echantillon:   0.0000 g           Fini: 25/05/22  09:09:53
Temperature: 24.0 °C                    Volume geometrique:   1.0000 in3
Nombre de Purges:   1                   Taux d'Equilibre: 0.1000 psig/min
Volume de Cellule:   0.7182 in3         Volume d'Expansion:   0.5127 in3
Densite de la Paroi Cellulaire:  1.0000 g/cm3Surface active: 5.0000 in2
Longueur arrete: 0.0394 in
Nombre de arretes: 1


          P1       P2      Volume   Deviation  Cellule Resine+Cell.   Temps
Proc#    psig     psig      in3        in3    Ouverte%   Fermee%     Ecoule
------  -------  -------  --------  --------- -------- ------------- -------
   1    19.9538   7.8142    0.3881     0.0000   43.91     56.09      0:02:47
   2    19.9949   7.8308    0.3881    -0.0000   43.91     56.09      0:04:11


Volume Moyen:     0.3881 in3            Deviation Standard:  0.0000 in3


        -----------------------------------------------------------
        Volume de paroi cellulaire:   0.0000 in3
        Pourcentage de volume de paroi cellulaire:   0.00%
        Purcentage cellules ouvertes:  43.91%
        Paroi cellulaire + pourcentage de cellules fermées:  56.09%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_A_8 = """<!-- saved from url=(0040)http://192.168.78.1/4467/untitled-2.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                         Numero di Matricola: 4467
                        Report corretto del Volume
               Correzione mediante dimensioni della cellula


Ser.Num.del Camp:                       Iniziata: 25/05/22  09:51:21
Peso del Campione:   0.0000 g           Terminata: 25/05/22  09:56:27
Temperatura: 19.9 °C                    Volume geometrico:   0.7854 in3
Num. Cicli Condiz:   1                  Tempo di Equilibrio: 0.1000 psig/min
Volume Della Cella:   6.7512 in3        Vol.Camera in Espan:   4.4992 in3
Densita parete cell:  1.0000 g/cm3      Area attiva: 3.9270 in2
Diametro della cella 0.0394 in
Numero do pelli: 1


          P1       P2      Volume  Deviazione  Celle   Parete cell+ Durata dell'
Ciclo#   psig     psig      in3        in3    Aperte% % Cell chiuse  Analisi
------  -------  -------  -------- ---------- ------- ------------ -----------
   1     3.7520   1.6754    3.1214     0.0001  -311.00    411.00      0:02:27
   2     3.8218   1.7068    3.1205    -0.0008  -310.89    410.89      0:03:43
   3     3.8411   1.7150    3.1220     0.0007  -311.08    411.08      0:04:59


Volume Medio:     3.1213 in3            Deviazione Standard:  0.0006 in3


        -----------------------------------------------------------
        Volume della parete della cellula:   0.0000 in3
        Volume percentuale della parete della cellula   0.00%
        Percentuale delle celle aperte: -310.99%
        Parete della cellula + valore percentuale delle cellule chiuse 410.99%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_A_9 = """<!-- saved from url=(0040)http://192.168.78.1/4474/untitled-3.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                         Numero di Matricola: 4474
                        Report corretto del Volume
               Correzione mediante dimensioni della cellula




Ser.Num.del Camp:                       Iniziata: 25/05/22  09:51:18
Peso del Campione:   0.0000 g           Terminata: 25/05/22  09:55:40
Temperatura: 24.1 °C                    Volume geometrico:   1.0000 in3
Num. Cicli Condiz:   1                  Tempo di Equilibrio: 0.1000 psig/min
Volume Della Cella:   0.7182 in3        Vol.Camera in Espan:   0.5127 in3
Densita parete cell:  1.0000 g/cm3      Area attiva: 5.0000 in2
Lunghezza della cord 0.0394 in
Numero do pelli: 1


          P1       P2      Volume  Deviazione  Celle   Parete cell+ Durata dell'
Ciclo#   psig     psig      in3        in3    Aperte% % Cell chiuse  Analisi
------  -------  -------  -------- ---------- ------- ------------ -----------
   1    20.0784   7.8630    0.3881    -0.0000   43.91     56.09      0:02:50
   2    20.0035   7.8326    0.3882     0.0000   43.90     56.10      0:04:14


Volume Medio:     0.3882 in3            Deviazione Standard:  0.0000 in3


        -----------------------------------------------------------
        Volume della parete della cellula:   0.0000 in3
        Volume percentuale della parete della cellula   0.00%
        Percentuale delle celle aperte:  43.90%
        Parete della cellula + valore percentuale delle cellule chiuse  56.10%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_A_10 = """<!-- saved from url=(0038)http://192.168.78.1/4467/untitled.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                           Numero de Serie: 4467
                       Reporte de Volumen Corregido
                Correccion utilizando dimensiones de celda


ID Muestra:                             Comenzado: 25/05/22  09:25:06
Peso Muestra:   0.0000 g                Completado: 25/05/22  09:30:13
Temperatura: 19.9 °C                    Volumen geometrico:   0.7854 in3
Numero de Purgas:   1                   Tasa de Equilibrio: 0.1000 psig/min
Volumen Celda:    6.7512 in3            Volumen Expansion:   4.4992 in3
Densidad pared celda:  1.0000 g/cm3     Area activa: 3.9270 in2
Diametro  de celda: 0.0394 in
Numero de Membranas: 1


          P1       P2     Volumen  Desviacion  Celda   Resina+Celda Duracion
Proc#    psig     psig      in3        in3    Abierta%  Cerrada %    (h:m:s)
------  -------  -------  -------- ---------- -------- ------------ --------
   1     3.8600   1.7236    3.1214    -0.0003  -311.00    411.00      0:02:26
   2     3.8707   1.7281    3.1226     0.0009  -311.15    411.15      0:03:42
   3     3.8363   1.7131    3.1209    -0.0007  -310.94    410.94      0:04:59


Volumen Promedio:   3.1216 in3          Desviacion Standard:  0.0007 in3


        -----------------------------------------------------------
        Volumen de la pared de celda:   0.0000 in3
        Porcentaje de volumen de la pared de celda:   0.00%
        Porcentaje Celda Abierta: -311.03%
        Pared de celda + porcentaje de celda cerrada: 411.03%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_A_11 = """
<!-- saved from url=(0040)http://192.168.78.1/4474/untitled-6.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                           Numero de Serie: 4474
                       Reporte de Volumen Corregido
                Correccion utilizando dimensiones de celda




ID Muestra:                             Comenzado: 25/05/22  09:25:04
Peso Muestra:   0.0000 g                Completado: 25/05/22  09:29:26
Temperatura: 24.0 °C                    Volumen geometrico:   1.0000 in3
Numero de Purgas:   1                   Tasa de Equilibrio: 0.1000 psig/min
Volumen Celda:    0.7182 in3            Volumen Expansion:   0.5127 in3
Densidad pared celda:  1.0000 g/cm3     Area activa: 5.0000 in2
Longitud de cuerda: 0.0394 in
Numero de Membranas: 1


          P1       P2     Volumen  Desviacion  Celda   Resina+Celda Duracion
Proc#    psig     psig      in3        in3    Abierta%  Cerrada %    (h:m:s)
------  -------  -------  -------- ---------- -------- ------------ --------
   1    20.0157   7.8386    0.3881    -0.0000   43.91     56.09      0:02:50
   2    20.0522   7.8528    0.3881     0.0000   43.91     56.09      0:04:15


Volumen Promedio:   0.3881 in3          Desviacion Standard:  0.0000 in3


        -----------------------------------------------------------
        Volumen de la pared de celda:   0.0000 in3
        Porcentaje de volumen de la pared de celda:   0.00%
        Porcentaje Celda Abierta:  43.91%
        Pared de celda + porcentaje de celda cerrada:  56.09%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_A_11 = """
<!-- saved from url=(0040)http://192.168.78.1/4474/untitled-6.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                           Numero de Serie: 4474
                       Reporte de Volumen Corregido
                Correccion utilizando dimensiones de celda




ID Muestra:                             Comenzado: 25/05/22  09:25:04
Peso Muestra:   0.0000 g                Completado: 25/05/22  09:29:26
Temperatura: 24.0 °C                    Volumen geometrico:   1.0000 in3
Numero de Purgas:   1                   Tasa de Equilibrio: 0.1000 psig/min
Volumen Celda:    0.7182 in3            Volumen Expansion:   0.5127 in3
Densidad pared celda:  1.0000 g/cm3     Area activa: 5.0000 in2
Longitud de cuerda: 0.0394 in
Numero de Membranas: 1


          P1       P2     Volumen  Desviacion  Celda   Resina+Celda Duracion
Proc#    psig     psig      in3        in3    Abierta%  Cerrada %    (h:m:s)
------  -------  -------  -------- ---------- -------- ------------ --------
   1    20.0157   7.8386    0.3881    -0.0000   43.91     56.09      0:02:50
   2    20.0522   7.8528    0.3881     0.0000   43.91     56.09      0:04:15


Volumen Promedio:   0.3881 in3          Desviacion Standard:  0.0000 in3


        -----------------------------------------------------------
        Volumen de la pared de celda:   0.0000 in3
        Porcentaje de volumen de la pared de celda:   0.00%
        Porcentaje Celda Abierta:  43.91%
        Pared de celda + porcentaje de celda cerrada:  56.09%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_A_12 = """
<!-- saved from url=(0040)http://192.168.78.1/4474/untitled-6.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                           Numero de Serie: 4474
                       Reporte de Volumen Corregido
                Correccion utilizando dimensiones de celda




ID Muestra:                             Comenzado: 25/05/22  09:25:04
Peso Muestra:   0.0000 g                Completado: 25/05/22  09:29:26
Temperatura: 24.0 °C                    Volumen geometrico:   1.0000 in3
Numero de Purgas:   1                   Tasa de Equilibrio: 0.1000 psig/min
Volumen Celda:    0.7182 in3            Volumen Expansion:   0.5127 in3
Densidad pared celda:  1.0000 g/cm3     Area activa: 32.258 cm2
Longitud de cuerda: 0.100076 cm
Numero de Membranas: 1


          P1       P2     Volumen  Desviacion  Celda   Resina+Celda Duracion
Proc#    psig     psig      in3        in3    Abierta%  Cerrada %    (h:m:s)
------  -------  -------  -------- ---------- -------- ------------ --------
   1    20.0157   7.8386    0.3881    -0.0000   43.91     56.09      0:02:50
   2    20.0522   7.8528    0.3881     0.0000   43.91     56.09      0:04:15


Volumen Promedio:   0.3881 in3          Desviacion Standard:  0.0000 in3


        -----------------------------------------------------------
        Volumen de la pared de celda:   0.0000 in3
        Porcentaje de volumen de la pared de celda:   0.00%
        Porcentaje Celda Abierta:  43.91%
        Pared de celda + porcentaje de celda cerrada:  56.09%
        -----------------------------------------------------------
</pre>
</body></html>"""

# File from Chris 5/23/2022: FoamPyc - Francias, Correction by recutting, cm.html
_METHOD_B_1 = """<pre>
                           FoamPycII 1345 V4.00
                           Numero de Serie: 4467
                        Rapport sur volume corrige
                         Correction par decoupage


ID echantillon:                         Commence: 23/05/22  13:36:37
Poids echantillon:   5.0000 g           Fini: 23/05/22  13:54:44
Temperature: 20.1 °C                    Volume geometrique:  35.0000 cm3
Nombre de Purges:   1                   Taux d'Equilibre: 0.0100 psig/min
Volume de Cellule: 110.6318 cm3         Volume d'Expansion:  73.7282 cm3
Densite de la Paroi Cellulaire:  1.0000 g/cm3


                          Analyse avant recoupage
                    -----------------------------------
             P1          P2         Volume      Deviation      Temps
Proc#       psig        psig         cm3           cm3         Ecoule
------    --------    --------     --------     ---------     --------
   1        3.7731      1.6867      51.0312      -0.0174      0:02:47
   2        3.9395      1.7607      51.0541       0.0055      0:04:13
   3        3.8155      1.7054      51.0464      -0.0022      0:05:39
   4        3.8165      1.7058      51.0444      -0.0042      0:07:07
   5        3.8245      1.7091      51.0669       0.0183      0:08:34


Volume Moyen:    51.0486 cm3            Deviation Standard:  0.0118 cm3


                      Repeter analyse apres recoupage
                    -----------------------------------
             P1          P2         Volume      Deviation      Temps
Proc#       psig        psig         cm3           cm3         Ecoule
------    --------    --------     --------     ---------     --------
   1        3.8996      1.7429      51.0501      -0.0086      0:02:45
   2        3.8978      1.7417      51.0734       0.0146      0:04:11
   3        4.0092      1.7917      51.0620       0.0033      0:05:39
   4        3.8088      1.7022      51.0547      -0.0041      0:07:08
   5        3.9996      1.7875      51.0536      -0.0052      0:08:36


Volume Moyen:    51.0587 cm3            Deviation Standard:  0.0083 cm3


        -----------------------------------------------------------
        Volume cellules ouvertes: -16.0384 cm3
        Purcentage cellules ouvertes: -45.82%
        Paroi cellulaire + volume de cellules fermees:  51.0384 cm3
        Paroi cellulaire + pourcentage de cellules fermées: 145.82%
        Volume de paroi cellulaire:   5.0000 cm3
        Pourcentage de volume de paroi cellulaire:  14.29%
        -----------------------------------------------------------
</pre>"""

_METHOD_B_2 = """<pre>
                           FoamPycII 1345 V4.00
                            Serial Number: 4467
                          Corrected Volume Report
                      Correction by Recutting Sample


Sample ID:                              Started: 29/04/22  11:19:19
Sample Mass:   1.1519 g                 Completed: 29/04/22  13:07:40
Temperature: 20.6 °C                    Geometric Volume:   1.3396 in3
Number of Purges:  10                   Equilibration Rate:  0.0345 kPag/min
Cell Volume:   6.7501 in3               Expansion Volume:   4.4930 in3
Cell Wall Density:  1.0000 g/cm3


                        Analysis Prior to Recutting
                    -----------------------------------
             P1          P2         Volume      Deviation     Elapsed
Cycle#      kPag        kPag         in3           in3          Time
------    --------    --------     --------     ---------     --------
   1        26.913      13.228       2.4067       0.0010      0:05:27
   2        27.094      13.320       2.4052      -0.0005      0:07:24
   3        26.524      13.040       2.4051      -0.0005      0:09:08
   4        26.945      13.247       2.4047      -0.0010      0:10:55
   5        26.487      13.017       2.4080       0.0023      0:12:41
   6        27.261      13.403       2.4044      -0.0012      0:14:14
   7        27.097      13.323       2.4044      -0.0013      0:15:58
   8        25.949      12.749       2.4102       0.0045      0:17:34
   9        26.698      13.124       2.4064       0.0007      0:19:18
  10        27.325      13.439       2.4016      -0.0041      0:21:12


Average Volume:   2.4057 in3            Standard Deviation:  0.0022 in3


                      Repeat Analysis After Recutting
                    -----------------------------------
             P1          P2         Volume      Deviation     Elapsed
Cycle#      kPag        kPag         in3           in3          Time
------    --------    --------     --------     ---------     --------
   1        26.797      13.474       2.2061      -0.0011      0:07:06
   2        26.710      13.427       2.2080       0.0008      0:09:34
   3        26.428      13.289       2.2058      -0.0014      0:11:55
   4        26.721      13.433       2.2084       0.0012      0:14:19
   5        26.428      13.287       2.2071      -0.0001      0:16:56
   6        26.770      13.461       2.2057      -0.0015      0:19:26
   7        27.167      13.659       2.2066      -0.0006      0:21:47
   8        26.881      13.518       2.2051      -0.0021      0:24:23
   9        26.371      13.252       2.2114       0.0042      0:26:41
  10        27.250      13.700       2.2076       0.0005      0:29:09


Average Volume:   2.2072 in3            Standard Deviation:  0.0017 in3

                           FoamPycII 1345 V4.00
                            Serial Number: 4467
                          Corrected Volume Report
                      Correction by Recutting Sample


        -----------------------------------------------------------
        Open Cell Volume:  -1.2646 in3
        Open Cell Percentage: -94.40%
        Cell Wall + Closed Cell Volume:   2.6042 in3
        Cell Wall + Closed Cell Percentage: 194.40%
        Cell Wall Volume:   0.0703 in3
        Cell Wall Volume Percentage:   5.25%
        -----------------------------------------------------------
</pre>
"""

_METHOD_B_3 = """<!-- saved from url=(0040)http://192.168.78.1/4466/untitled-3.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Seriennummer: 4466
                        Volumen-Bericht, korrigiert
                          Korrektur neuer Schnitt


Probenname:                             Beginn: 24/05/22  15:30:21
Probengewicht:   0.0000 g               Ende: 24/05/22  15:39:07
Temperatur: 22.6 °C                     Geometrisches Vol.:   1.0000 in3
Spülzyklen:   1                         Gleichgewicht: 0.1000 psig/min
Zellvolumen:   6.7507 in3               Expansionsvolumen:   4.4962 in3
Zellwanddichte:  1.0000 g/cm3


                       Analyse vor Probenzerteilung
                    -----------------------------------
 Mess.       P1          P2        Volumen     Abweichung     Messzeit
  Nr        psig        psig         in3           in3        (h:m:s)
------    --------    --------     --------    ----------     --------
   1        5.0776      2.2673       3.1234       0.0005      0:02:44
   2        5.1908      2.3182       3.1223      -0.0005      0:03:58


Mittleres Volumen:   3.1228 in3         Standardabweichung:  0.0005 in3


                    Wiederholung nach Probenzerteilung
                    -----------------------------------
 Mess.       P1          P2        Volumen     Abweichung     Messzeit
  Nr        psig        psig         in3           in3        (h:m:s)
------    --------    --------     --------    ----------     --------
   1        5.1009      2.2779       3.1227      -0.0000      0:02:44
   2        5.1295      2.2907       3.1227       0.0000      0:03:59


Mittleres Volumen:   3.1227 in3         Standardabweichung:  0.0000 in3


        -----------------------------------------------------------
        Offenzelligkeit / Vol.:  -2.1230 in3
        Offenzelligkeit / %: -212.30%
        Volumen Zellwand + geschlossene Zellen:   3.1230 in3
        Prozentualer Anteil Zellwand + geschlossene Zellen: 312.30%
        Volumen Zellwand:   0.0000 in3
        Prozentualer Anteil Zellwand:   0.00%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_B_4 = """<!-- saved from url=(0040)http://192.168.78.1/4466/untitled-4.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Serial Number: 4466
                          Corrected Volume Report
                      Correction by Recutting Sample


Sample ID:                              Started: 24/05/22  15:54:32
Sample Mass:   0.0000 g                 Completed: 24/05/22  16:07:46
Temperature: 22.6 °C                    Geometric Volume:   1.0000 in3
Number of Purges:   1                   Equilibration Rate: 0.1000 psig/min
Cell Volume:   6.7507 in3               Expansion Volume:   4.4962 in3
Cell Wall Density:  1.0000 g/cm3


                        Analysis Prior to Recutting
                    -----------------------------------
             P1          P2         Volume      Deviation     Elapsed
Cycle#      psig        psig         in3           in3          Time
------    --------    --------     --------     ---------     --------
   1        5.1134      2.2837       3.1221      -0.0003      0:02:45
   2        5.1484      2.2992       3.1226       0.0003      0:03:59


Average Volume:   3.1224 in3            Standard Deviation:  0.0003 in3


                      Repeat Analysis After Recutting
                    -----------------------------------
             P1          P2         Volume      Deviation     Elapsed
Cycle#      psig        psig         in3           in3          Time
------    --------    --------     --------     ---------     --------
   1        5.1702      2.3074       3.1269       0.0027      0:02:58
   2        5.1285      2.2906       3.1215      -0.0027      0:04:11


Average Volume:   3.1242 in3            Standard Deviation:  0.0027 in3


        -----------------------------------------------------------
        Open Cell Volume:  -2.1205 in3
        Open Cell Percentage: -212.05%
        Cell Wall + Closed Cell Volume:   3.1205 in3
        Cell Wall + Closed Cell Percentage: 312.05%
        Cell Wall Volume:   0.0000 in3
        Cell Wall Volume Percentage:   0.00%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_B_5 = """<!-- saved from url=(0040)http://192.168.78.1/4466/untitled-6.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                           Numero de Serie: 4466
                       Reporte de Volumen Corregido
                 Correccion al volver a cortar la muestra


ID Muestra:                             Comenzado: 24/05/22  15:16:20
Peso Muestra:   0.0000 g                Completado: 24/05/22  15:27:23
Temperatura: 22.5 °C                    Volumen geometrico:   1.0000 in3
Numero de Purgas:   1                   Tasa de Equilibrio: 0.1000 psig/min
Volumen Celda:    6.7507 in3            Volumen Expansion:   4.4962 in3
Densidad pared celda:  1.0000 g/cm3


                        Analisis previo a recortar
                    -----------------------------------
             P1          P2        Volumen     Desviacion     Duracion
Proc#       psig        psig         in3           in3        (h:m:s)
-------   --------    --------     --------    ----------     --------
   1        5.1040      2.2796       3.1218       0.0001      0:02:45
   2        5.0635      2.2616       3.1217      -0.0001      0:04:00


Volumen Promedio:   3.1217 in3          Desviacion Standard:  0.0001 in3


                   Repetir analisis despues de recortar
                    -----------------------------------
             P1          P2        Volumen     Desviacion     Duracion
Proc#       psig        psig         in3           in3        (h:m:s)
-------   --------    --------     --------    ----------     --------
   1        5.1140      2.2844       3.1209      -0.0008      0:02:44
   2        5.1362      2.2938       3.1224       0.0008      0:03:57


Volumen Promedio:   3.1217 in3          Desviacion Standard:  0.0008 in3


        -----------------------------------------------------------
        Volumen Celda Abierta:  -2.1218 in3
        Porcentaje Celda Abierta: -212.18%
        Muro de celda + volumen de celda cerrada:   3.1218 in3
        Pared de celda + porcentaje de celda cerrada: 312.18%
        Volumen de la pared de celda:   0.0000 in3
        Porcentaje de volumen de la pared de celda:   0.00%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_B_6 = """
<!-- saved from url=(0040)http://192.168.78.1/4466/untitled-5.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                         Numero di Matricola: 4466
                        Report corretto del Volume
                  Correzione mediante taglio del provino


Ser.Num.del Camp:                       Iniziata: 24/05/22  14:51:58
Peso del Campione:   0.0000 g           Terminata: 24/05/22  15:14:28
Temperatura: 22.4 °C                    Volume geometrico:   1.0000 in3
Num. Cicli Condiz:   1                  Tempo di Equilibrio: 0.1000 psig/min
Volume Della Cella:   6.7507 in3        Vol.Camera in Espan:   4.4962 in3
Densita parete cell:  1.0000 g/cm3


                   Analisi prima del taglio del provino
                    -----------------------------------
             P1          P2         Volume     Deviazione   Durata dell'
Ciclo#      psig        psig         in3           in3        Analisi
------    --------    --------     --------     ---------   -----------
   1        5.1411      2.2954       3.1240      -0.0000      0:02:45
   2        5.1189      2.2855       3.1240       0.0000      0:04:00


Volume Medio:     3.1240 in3            Deviazione Standard:  0.0000 in3


            Ripetizione dell'analisi dopo il taglio del provino
                    -----------------------------------
             P1          P2         Volume     Deviazione   Durata dell'
Ciclo#      psig        psig         in3           in3        Analisi
------    --------    --------     --------     ---------   -----------
   1        5.1032      2.2792       3.1220      -0.0007      0:02:45
   2        5.1290      2.2902       3.1235       0.0007      0:03:59


Volume Medio:     3.1227 in3            Deviazione Standard:  0.0007 in3


        -----------------------------------------------------------
        Volume delle celle aperte:  -2.1252 in3
        Percentuale delle celle aperte: -212.52%
        Parete della cellula + volume cellule chiuse   3.1252 in3
        Parete della cellula + valore percentuale delle cellule chiuse 312.52%
        Volume della parete della cellula:   0.0000 in3
        Volume percentuale della parete della cellula   0.00%
        -----------------------------------------------------------
</pre>
</body></html>"""

# File from Chris 5/23/2022: FoamPyc - Cell Fracture Test.html
_METHOD_C_1 = """<!-- saved from url=(0040)http://192.168.78.1/4467/untitled-5.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                           Numero de Serie: 4467
                       Reporte de Volumen Corregido
                              Sin correccion


ID Muestra:                             Comenzado: 23/05/22  14:03:27
Peso Muestra:   2.0000 g                Completado: 23/05/22  14:12:05
Temperatura: 20.0 °C                    Volumen geometrico:   3.0512 in3
Numero de Purgas:   1                   Tasa de Equilibrio: 0.0100 psig/min
Volumen Celda:    6.7512 in3            Volumen Expansion:   4.4992 in3
Densidad pared celda:  1.0000 g/cm3


                                                       Pared de la
          P1       P2     Volumen  Desviacion  Celda    Celda % De   Duracion
Proc#    psig     psig      in3        in3    Abierta% celda cerrada (h:m:s)
------  -------  -------  --------  --------- -------- ------------  -------
   1     3.9781   1.7780    3.0924    -0.0012   -1.35    101.35      0:02:43
   2     4.0066   1.7903    3.0942     0.0006   -1.41    101.41      0:04:11
   3     3.8281   1.7105    3.0944     0.0008   -1.41    101.41      0:05:40
   4     3.7561   1.6785    3.0937     0.0001   -1.39    101.39      0:07:04
   5     4.0259   1.7992    3.0933    -0.0003   -1.38    101.38      0:08:30


Volumen Promedio:   3.0936 in3          Desviacion Standard:  0.0007 in3


        -----------------------------------------------------------
        Volumen de la pared de celda:   0.1220 in3
        Porcentaje de volumen de la pared de celda:   4.00%
        Porcentaje Celda Abierta:  -1.39%
        Pared de celda + porcentaje de celda cerrada: 101.39%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_C_2 = """<!-- saved from url=(0040)http://192.168.78.1/4474/untitled-6.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Seriennummer: 4474
                        Volumen-Bericht, korrigiert
                              Keine Korrektur




Probenname:                             Beginn: 25/05/22  08:01:56
Probengewicht:   0.0000 g               Ende: 25/05/22  08:06:20
Temperatur: 23.7 °C                     Geometrisches Vol.:   1.0000 in3
Spülzyklen:   1                         Gleichgewicht: 0.1000 psig/min
Zellvolumen:   0.7182 in3               Expansionsvolumen:   0.5127 in3
Zellwanddichte:  1.0000 g/cm3


 Mess.    P1       P2     Volumen  Abweichung  Offen-  Kunststoff+   Messzeit
  Nr     psig     psig      in3        in3   zelligk.% geschl. Zelle% (h:m:s)
------  -------  -------  --------  --------- -------- ------------- --------
   1    19.9634   7.8192    0.3881    -0.0000   61.19     38.81      0:02:52
   2    19.9133   7.7994    0.3881     0.0000   61.19     38.81      0:04:16


Mittleres Volumen:   0.3881 in3         Standardabweichung:  0.0000 in3


        -----------------------------------------------------------
        Volumen Zellwand:   0.0000 in3
        Prozentualer Anteil Zellwand:   0.00%
        Offenzelligkeit / %:  61.19%
        Prozentualer Anteil Zellwand + geschlossene Zellen:  38.81%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_C_3 = """<!-- saved from url=(0040)http://192.168.78.1/4474/untitled-2.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Serial Number: 4474
                          Corrected Volume Report
                               No Correction




Sample ID:                              Started: 25/05/22  07:53:33
Sample Mass:   0.0000 g                 Completed: 25/05/22  07:57:56
Temperature: 23.6 °C                    Geometric Volume:   1.0000 in3
Number of Purges:   1                   Equilibration Rate: 0.1000 psig/min
Cell Volume:   0.7182 in3               Expansion Volume:   0.5127 in3
Cell Wall Density:  1.0000 g/cm3


          P1       P2      Volume   Deviation   Open    Cell Wall +  Elapsed
Cycle#   psig     psig      in3        in3     Cell %  Closed Cell %   Time
------  -------  -------  --------  ---------  ------  ------------  -------
   1    19.9475   7.8144    0.3880    -0.0000   61.20     38.80      0:02:50
   2    19.9260   7.8048    0.3880     0.0000   61.20     38.80      0:04:16


Average Volume:   0.3880 in3            Standard Deviation:  0.0000 in3


        -----------------------------------------------------------
        Cell Wall Volume:   0.0000 in3
        Cell Wall Volume Percentage:   0.00%
        Open Cell Percentage:  61.20%
        Cell Wall + Closed Cell Percentage:  38.80%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_C_4 = """<!-- saved from url=(0040)http://192.168.78.1/4474/untitled-3.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                           Numero de Serie: 4474
                        Rapport sur volume corrige
                             Pas de correction




ID echantillon:                         Commence: 25/05/22  08:18:43
Poids echantillon:   0.0000 g           Fini: 25/05/22  08:23:06
Temperature: 23.8 °C                    Volume geometrique:   1.0000 in3
Nombre de Purges:   1                   Taux d'Equilibre: 0.1000 psig/min
Volume de Cellule:   0.7182 in3         Volume d'Expansion:   0.5127 in3
Densite de la Paroi Cellulaire:  1.0000 g/cm3


          P1       P2      Volume   Deviation  Cellule Resine+Cell.   Temps
Proc#    psig     psig      in3        in3    Ouverte%   Fermee%     Ecoule
------  -------  -------  --------  --------- -------- ------------  -------
   1    20.0375   7.8484    0.3880    -0.0000   61.20     38.80      0:02:49
   2    19.9960   7.8307    0.3881     0.0000   61.19     38.81      0:04:16


Volume Moyen:     0.3881 in3            Deviation Standard:  0.0000 in3


        -----------------------------------------------------------
        Volume de paroi cellulaire:   0.0000 in3
        Pourcentage de volume de paroi cellulaire:   0.00%
        Purcentage cellules ouvertes:  61.19%
        Paroi cellulaire + pourcentage de cellules fermées:  38.81%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_C_5 = """<!-- saved from url=(0040)http://192.168.78.1/4474/untitled-4.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                         Numero di Matricola: 4474
                        Report corretto del Volume
                            Nessuna correzione




Ser.Num.del Camp:                       Iniziata: 25/05/22  08:25:01
Peso del Campione:   0.0000 g           Terminata: 25/05/22  08:29:23
Temperatura: 23.8 °C                    Volume geometrico:   1.0000 in3
Num. Cicli Condiz:   1                  Tempo di Equilibrio: 0.1000 psig/min
Volume Della Cella:   0.7182 in3        Vol.Camera in Espan:   0.5127 in3
Densita parete cell:  1.0000 g/cm3


                                                         Parete
                                                        cellula +
          P1       P2      Volume  Deviazione  Celle    % Cellule   Durata dell'
Ciclo#   psig     psig      in3        in3    Aperte%    chiuse      Analisi
------  -------  -------  --------  --------- -------  ------------ --------
   1    20.0074   7.8353    0.3881     0.0000   61.19     38.81      0:02:49
   2    20.0925   7.8688    0.3881    -0.0000   61.19     38.81      0:04:15


Volume Medio:     0.3881 in3            Deviazione Standard:  0.0000 in3


        -----------------------------------------------------------
        Volume della parete della cellula:   0.0000 in3
        Volume percentuale della parete della cellula   0.00%
        Percentuale delle celle aperte:  61.19%
        Parete della cellula + valore percentuale delle cellule chiuse  38.81%
        -----------------------------------------------------------
</pre>
</body></html>"""

# File from Chris 5/23/2022: FoamPyc - Italiano, Compressibility Test.html
_METHOD_D_1 = """<!-- saved from url=(0040)http://192.168.78.1/4467/untitled-6.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                         Numero di Matricola: 4467
                        Report corretto del Volume
                          Prova di comprimibilita


Ser.Num.del Camp:                       Iniziata: 23/05/22  14:18:52
Peso del Campione:   0.0000 g           Terminata: 23/05/22  14:27:50
Temperatura: 20.0 °C                    Volume geometrico:   3.0512 in3
Num. Cicli Condiz:   1                  Tempo di Equilibrio: 0.0100 psig/min
Volume Della Cella:   6.7512 in3        Vol.Camera in Espan:   4.4992 in3
Densita parete cell:  1.0000 g/cm3


                         P1                  P2                Volume
      Ciclo#            psig                psig                in3
      ------          --------            --------            --------
         1              2.4273              1.0846              3.1169
         2              6.1878              2.7648              3.1170
         3             10.2357              4.5743              3.1159
         4             14.1492              6.3229              3.1163
         5             17.9574              8.0261              3.1151


Volume Medio:     3.1162 in3            Deviazione Standard:  0.0007 in3


        -----------------------------------------------------------
        Var. Media Volume per incr. unit. di P1:  -0.0001 in3/psig
        Variaz. % rispetto a Volume Geomtrico: -0.00 %/psig
        Var. Media Volume per incr. unit. di P2:  -0.0003 in3/psig
        Variaz. % rispetto a Volume Geomtrico: -0.01 %/psig
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_D_2 = """<!-- saved from url=(0038)http://192.168.78.1/4467/untitled.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Seriennummer: 4467
                        Volumen-Bericht, korrigiert
                           Kompressibilitatstest


Probenname:                             Beginn: 25/05/22  08:01:59
Probengewicht:   0.0000 g               Ende: 25/05/22  08:06:32
Temperatur: 20.0 °C                     Geometrisches Vol.:   3.0512 in3
Spülzyklen:   1                         Gleichgewicht: 0.1000 psig/min
Zellvolumen:   6.7512 in3               Expansionsvolumen:   4.4992 in3
Zellwanddichte:  1.0000 g/cm3


       Mess.             P1                  P2               Volumen
        Nr              psig                psig                in3
      ------          --------            --------            --------
         1              2.5970              1.1606              3.1161
         2             12.1849              5.4433              3.1185
         3             14.9934              6.6989              3.1175


Mittleres Volumen:   3.1174 in3         Standardabweichung:  0.0010 in3


        -----------------------------------------------------------
        Mittl. Volumenaenderung pro Druckschritt P1:  -0.0001 in3/psig
        % Aenderung vergl. mit geometr. Volumen: -0.00 %/psig
        Mittl. Volumenaenderung pro Druckschritt P2:  -0.0001 in3/psig
        % Aenderung vergl. mit geometr. Volumen: -0.00 %/psig
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_D_3 = """
<!-- saved from url=(0040)http://192.168.78.1/4467/untitled-6.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Serial Number: 4467
                          Corrected Volume Report
                           Compressibility Test


Sample ID:                              Started: 25/05/22  07:53:29
Sample Mass:   0.0000 g                 Completed: 25/05/22  07:58:03
Temperature: 20.0 °C                    Geometric Volume:   3.0512 in3
Number of Purges:   1                   Equilibration Rate: 0.1000 psig/min
Cell Volume:   6.7512 in3               Expansion Volume:   4.4992 in3
Cell Wall Density:  1.0000 g/cm3


                         P1                  P2                Volume
      Cycle#            psig                psig                in3
      ------          --------            --------            --------
         1              2.5244              1.1267              3.1245
         2             12.0899              5.4005              3.1188
         3             15.0680              6.7325              3.1172


Average Volume:   3.1202 in3            Standard Deviation:  0.0031 in3


        -----------------------------------------------------------
        Avg. Vol. Change per Unit Increase of P1:  -0.0006 in3/psig
        % Change Compared to Geometric Volume: -0.02 %/psig
        Avg. Vol. Change per Unit Increase of P2:  -0.0013 in3/psig
        % Change Compared to Geometric Volume: -0.04 %/psig
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_D_4 = """<!-- saved from url=(0040)http://192.168.78.1/4467/untitled-2.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                           Numero de Serie: 4467
                       Reporte de Volumen Corregido
                         Prueba de compresibilidad


ID Muestra:                             Comenzado: 25/05/22  08:09:10
Peso Muestra:   0.0000 g                Completado: 25/05/22  08:13:52
Temperatura: 20.0 °C                    Volumen geometrico:   3.0512 in3
Numero de Purgas:   1                   Tasa de Equilibrio: 0.1000 psig/min
Volumen Celda:    6.7512 in3            Volumen Expansion:   4.4992 in3
Densidad pared celda:  1.0000 g/cm3


                         P1                  P2               Volumen
      Proc#             psig                psig                in3
      ------          --------            --------            --------
         1              2.5252              1.1268              3.1260
         2             12.1372              5.4218              3.1187
         3             14.9946              6.6982              3.1187


Volumen Promedio:   3.1211 in3          Desviacion Standard:  0.0034 in3


        -----------------------------------------------------------
        Cambio en Volumen Promedio por unidad de incremento de P1:  -0.0004 in3/psig
        % en cambio comparado al Volumen Geometrico: -0.01 %/psig
        Cambio en Volumen Promedio por unidad de incremento de P2:  -0.0009 in3/psig
        % en cambio comparado al Volumen Geometrico: -0.03 %/psig
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_D_5 = """
<!-- saved from url=(0040)http://192.168.78.1/4467/untitled-3.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                           Numero de Serie: 4467
                        Rapport sur volume corrige
                          Test de compressibilite


ID echantillon:                         Commence: 25/05/22  08:18:47
Poids echantillon:   0.0000 g           Fini: 25/05/22  08:23:28
Temperature: 20.0 °C                    Volume geometrique:   3.0512 in3
Nombre de Purges:   1                   Taux d'Equilibre: 0.1000 psig/min
Volume de Cellule:   6.7512 in3         Volume d'Expansion:   4.4992 in3
Densite de la Paroi Cellulaire:  1.0000 g/cm3


                         P1                  P2                Volume
      Proc#             psig                psig                in3
      ------          --------            --------            --------
         1              2.4789              1.1062              3.1253
         2             12.0412              5.3778              3.1201
         3             15.0304              6.7147              3.1182


Volume Moyen:     3.1212 in3            Deviation Standard:  0.0030 in3


        -----------------------------------------------------------
        Changement moyen de volume / increment de P1:  -0.0006 in3/psig
        % changement aupres de volume geometrique: -0.02 %/psig
        Changement moyen de volume / increment de P2:  -0.0013 in3/psig
        % changement aupres de volume geometrique: -0.04 %/psig
        -----------------------------------------------------------
</pre>
</body></html>"""

# File from Chris 5/23/2022: FoamPyc - Cell Fracture Test.html
_METHOD_E_1 = """<!-- saved from url=(0038)http://192.168.78.1/4467/untitled.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Serial Number: 4467
                          Corrected Volume Report
                            Cell Fracture Test


Sample ID:                              Started: 23/05/22  14:32:48
Sample Mass:  70.0000 g                 Completed: 23/05/22  14:36:59
Temperature: 20.0 °C                    Geometric Volume:   2.5000 in3
Number of Purges:   1                   Equilibration Rate: 0.0100 psig/min
Cell Volume:   6.7512 in3               Expansion Volume:   4.4992 in3
Cell Wall Density:  1.0000 g/cm3


                              P1                P2             Volume
         Cycle#              psig              psig             in3
     ---------------       --------          --------         --------
       1 (lower P1)          2.5671            1.1473           3.0930
       2 (higher P1)         2.6105            1.1664           3.0943
       3 (lower P1)          2.5663            1.1466           3.0947


        -----------------------------------------------------------
        Change in Volume Between Phases 1 and 3:   0.0017 in3
        % Change in Geo. Volume Between Phases 1 and 3:   0.07%
        Cell Wall Volume as Percentage of Geo. Volume: 170.87%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_E_2 = """
<!-- saved from url=(0040)http://192.168.78.1/4466/untitled-2.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Seriennummer: 4466
                        Volumen-Bericht, korrigiert
                             Zell-Fraktur-Test


Probenname:                             Beginn: 25/05/22  08:02:04
Probengewicht:   0.0000 g               Ende: 25/05/22  08:06:17
Temperatur: 22.3 °C                     Geometrisches Vol.:   1.0000 in3
Spülzyklen:   1                         Gleichgewicht: 0.1000 psig/min
Zellvolumen:   6.7507 in3               Expansionsvolumen:   4.4962 in3
Zellwanddichte:  1.0000 g/cm3


          Mess.               P1                P2            Volumen
           Nr                psig              psig             in3
     ---------------       --------          --------         --------
       1 (unterer P1)        2.2060            0.9844           3.1276
       2 (oberer P1)        10.0473            4.4877           3.1213
       3 (unterer P1)        2.1819            0.9735           3.1285


        -----------------------------------------------------------
        Volumenaenderung zwischen Schritt 1 und 3:   0.0010 in3
        % Aenderung zwischen Schritt 1 und 3:   0.10%
        Prozentualer Anteil Zellwandvolumen am geometrischen Volumen:   0.00%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_E_3 = """<!-- saved from url=(0040)http://192.168.78.1/4466/untitled-5.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                           Numero de Serie: 4466
                       Reporte de Volumen Corregido
                        Prueba de fractura de celda


ID Muestra:                             Comenzado: 25/05/22  08:09:15
Peso Muestra:   0.0000 g                Completado: 25/05/22  08:13:28
Temperatura: 22.4 °C                    Volumen geometrico:   1.0000 in3
Numero de Purgas:   1                   Tasa de Equilibrio: 0.1000 psig/min
Volumen Celda:    6.7507 in3            Volumen Expansion:   4.4962 in3
Densidad pared celda:  1.0000 g/cm3


                              P1                P2             Volumen
         Proc#               psig              psig             in3
     ---------------       --------          --------         --------
       1 (P1 baja)           2.2145            0.9890           3.1219
       2 (P1 alta)          10.0322            4.4810           3.1213
       3 (P1 baja)           2.1338            0.9524           3.1262


        -----------------------------------------------------------
        Cambio en Volumen entre fases 1 y 3:   0.0043 in3
        % en cambio en Volumen Geometrico entre fases 1 y 3:   0.43%
        Volumen de la pared de celda como porcentaje de Geo. Volumen:   0.00%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_E_4 = """
<!-- saved from url=(0040)http://192.168.78.1/4466/untitled-6.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                           Numero de Serie: 4466
                        Rapport sur volume corrige
                        Test de rupture cellulaire


ID echantillon:                         Commence: 25/05/22  08:18:51
Poids echantillon:   0.0000 g           Fini: 25/05/22  08:23:04
Temperature: 22.4 °C                    Volume geometrique:   1.0000 in3
Nombre de Purges:   1                   Taux d'Equilibre: 0.1000 psig/min
Volume de Cellule:   6.7507 in3         Volume d'Expansion:   4.4962 in3
Densite de la Paroi Cellulaire:  1.0000 g/cm3


                              P1                P2             Volume
         Proc#               psig              psig             in3
     ---------------       --------          --------         --------
       1 (P1 plus bas)       2.1594            0.9641           3.1241
       2 (P1 plus haut)     10.0982            4.5100           3.1220
       3 (P1 plus bas)       2.1540            0.9611           3.1280


        -----------------------------------------------------------
        Changement de volume entre phases 1 et 3:   0.0039 in3
        % changement de volume geometrique entre phases 1 et 3:   0.39%
        Volume de la paroi cellulaire en pourcentage du volume geometrique:   0.00%
        -----------------------------------------------------------
</pre>
</body></html>"""

_METHOD_E_5 = """
<!-- saved from url=(0040)http://192.168.78.1/4466/untitled-3.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                         Numero di Matricola: 4466
                        Report corretto del Volume
                      Prova di frattura della cellula


Ser.Num.del Camp:                       Iniziata: 25/05/22  08:25:06
Peso del Campione:   0.0000 g           Terminata: 25/05/22  08:29:21
Temperatura: 22.4 °C                    Volume geometrico:   1.0000 in3
Num. Cicli Condiz:   1                  Tempo di Equilibrio: 0.1000 psig/min
Volume Della Cella:   6.7507 in3        Vol.Camera in Espan:   4.4962 in3
Densita parete cell:  1.0000 g/cm3


                              P1                P2             Volume
         Ciclo#              psig              psig             in3
     ---------------       --------          --------         --------
       1 (minore P1)         2.1982            0.9815           3.1236
       2 (maggiore P1)      10.0547            4.4912           3.1211
       3 (minore P1)         2.1369            0.9539           3.1256


        -----------------------------------------------------------
        Var. di vol. tra fase 1 e 3:   0.0020 in3
        Var. % di Volume Geomtrico tra fase 1 e 3:   0.20%
        Volume della parete della cellula come valore percentuale del volume geometrico   0.00%
        -----------------------------------------------------------
</pre>
</body></html>"""

FOAM_TEST_DATA = [
    (_METHOD_A_1, 1509.05, 1),
    (_METHOD_A_2, -310.97, 1),
    (_METHOD_A_3, 43.91, 1),
    (_METHOD_A_4, -310.91, 1),
    (_METHOD_A_5, 43.90, 1),
    (_METHOD_A_6, -310.79, 1),
    (_METHOD_A_7, 43.91, 1),
    (_METHOD_A_8, -310.99, 1),
    (_METHOD_A_9, 43.90, 1),
    (_METHOD_A_10, -311.03, 1),
    (_METHOD_A_11, 43.91, 1),
    (_METHOD_A_12, 43.91, 1),
    (_METHOD_B_1, -45.82, 2),
    (_METHOD_B_2, -94.40, 2),
    (_METHOD_B_3, -212.30, 2),
    (_METHOD_B_4, -212.05, 2),
    (_METHOD_B_5, -212.18, 2),
    (_METHOD_B_6, -212.52, 2),
    (_METHOD_C_1, -1.39, 2),
    (_METHOD_C_2, 61.19, 2),
    (_METHOD_C_3, 61.20, 2),
    (_METHOD_C_4, 61.19, 2),
    (_METHOD_C_5, 61.19, 2),
    (_METHOD_D_1, 0.00, 2),
    (_METHOD_D_2, 0.00, 2),
    (_METHOD_D_3, -0.02, 2),
    (_METHOD_D_4, -0.01, 2),
    (_METHOD_D_5, -0.02, 2),
    (_METHOD_E_1, 0.07, 2),
    (_METHOD_E_2, 0.10, 1),
    (_METHOD_E_3, 0.43, 2),
    (_METHOD_E_4, 0.39, 2),
    (_METHOD_E_5, 0.20, 2),
]

_BAD_REPORT_1 = """<pre>
                           AccuPycII 1345 V4.00
                            Serial Number: 4467
                         Density and Volume Report


Sample ID: Test this                    Started: 13/05/22  08:58:36
Sample Mass:   0.0000 g                 Completed: 13/05/22  09:06:55
Temperature: 22.080 °C
Cell Volume: 110.6135 cm3               Expansion Volume:  73.6274 cm3


            Volume    Deviation   Density   Deviation   Elapsed  Temperature
   Cycle#     cm3        cm3       g/cm3      g/cm3      Time        °C
   ------  --------   ---------   -------   ---------  --------  -----------
      1      0.0101    -0.0343     0.0000     0.0000    0:04:55      21.995
      2      0.0234    -0.0210     0.0000     0.0000    0:06:07      22.074
      3      0.0997     0.0553     0.0000     0.0000    0:07:20      22.045


Average Volume:   0.0444 cm3            Standard Deviation:  0.0395 cm3
Average Density:  0.0000 g/cm3          Standard Deviation: 0.0000 g/cm3
</pre>"""

_BAD_REPORT_2 = """<pre>
                           AccuPycII 1345 V4.00
                            Serial Number: 4467
                         Density and Volume Report


Sample ID: Test this                    Started: 13/05/22  08:58:36
Sample Mass:   0.0000 g                 Completed: 13/05/22  09:06:55
Temperature: 22.080 °C
Number of Purges:  10                   Equilibration Rate:  0.0345 kPag/min
Cell Volume: 110.6135 cm3               Expansion Volume:  73.6274 cm3


            Volume    Deviation   Density   Deviation   Elapsed  Temperature
   Cycle#     mm3        mm3       g/cm3      g/cm3      Time        °C
   ------  --------   ---------   -------   ---------  --------  -----------
      1      0.0101    -0.0343     0.0000     0.0000    0:04:55      21.995
      2      0.0234    -0.0210     0.0000     0.0000    0:06:07      22.074
      3      0.0997     0.0553     0.0000     0.0000    0:07:20      22.045


Average Volume:   0.0444 cm3            Standard Deviation:  0.0395 cm3
Average Density:  0.0000 g/cm3          Standard Deviation: 0.0000 g/cm3
</pre>"""

_BAD_REPORT_3 = """<pre>
                           AccuPycII 1345 V4.00
                            Serial Number: 4467
                         Density and Volume Report


Sample ID: Test this                    Started: 13/05/22  08:58:36
Sample Mass:   0.0000 g                 Completed: 13/05/22  09:06:55
Temperature: 22.080 °R
Number of Purges:  10                   Equilibration Rate:  0.0345 kPag/min
Cell Volume: 110.6135 cm3               Expansion Volume:  73.6274 cm3


            Volume    Deviation   Density   Deviation   Elapsed  Temperature
   Cycle#     cm3        cm3       g/cm3      g/cm3      Time        °C
   ------  --------   ---------   -------   ---------  --------  -----------
      1      0.0101    -0.0343     0.0000     0.0000    0:04:55      21.995
      2      0.0234    -0.0210     0.0000     0.0000    0:06:07      22.074
      3      0.0997     0.0553     0.0000     0.0000    0:07:20      22.045


Average Volume:   0.0444 cm3            Standard Deviation:  0.0395 cm3
Average Density:  0.0000 g/cm3          Standard Deviation: 0.0000 g/cm3
</pre>"""

_BAD_REPORT_4 = """<pre>
                           AccuPycII 1345 V4.00
                            Serial Number: 4467
                         Density and Volume Report


Sample ID: Test this                    Started: 13/05/22  08:58:36
Sample Mass:   0.0000 g                 Completed: 13/05/22  09:06:55
Temperature: 22.080 °C
Number of Purges:  10                   Equilibration Rate:  0.0345 xxx/min
Cell Volume: 110.6135 cm3               Expansion Volume:  73.6274 cm3


            Volume    Deviation   Density   Deviation   Elapsed  Temperature
   Cycle#     cm3        cm3       g/cm3      g/cm3      Time        °C
   ------  --------   ---------   -------   ---------  --------  -----------
      1      0.0101    -0.0343     0.0000     0.0000    0:04:55      21.995
      2      0.0234    -0.0210     0.0000     0.0000    0:06:07      22.074
      3      0.0997     0.0553     0.0000     0.0000    0:07:20      22.045


Average Volume:   0.0444 cm3            Standard Deviation:  0.0395 cm3
Average Density:  0.0000 g/cm3          Standard Deviation: 0.0000 g/cm3
</pre>"""

_BAD_REPORT_5 = """<pre>
                           AccuPycII 1345 V4.00
                            Serial Number: 4467
                         Density and Volume Report


Sample ID: Test this                    Started: bad/05/22  08:58:36
Sample Mass:   0.0000 g                 Completed: 13/05/22  09:06:55
Temperature: 22.080 °C
Number of Purges:  10                   Equilibration Rate:  0.0345 kPag/min
Cell Volume: 110.6135 cm3               Expansion Volume:  73.6274 cm3


            Volume    Deviation   Density   Deviation   Elapsed  Temperature
   Cycle#     cm3        cm3       g/cm3      g/cm3      Time        °C
   ------  --------   ---------   -------   ---------  --------  -----------
      1      0.0101    -0.0343     0.0000     0.0000    0:04:55      21.995
      2      0.0234    -0.0210     0.0000     0.0000    0:06:07      22.074
      3      0.0997     0.0553     0.0000     0.0000    0:07:20      22.045


Average Volume:   0.0444 cm3            Standard Deviation:  0.0395 cm3
Average Density:  0.0000 g/cm3          Standard Deviation: 0.0000 g/cm3
</pre>"""

_BAD_REPORT_6 = """<pre>
                           AccuPycII 1345 V4.00
                            Serial Number: 4467
                         Density and Volume Report


Sample XXX: Test this                   Started: 13/05/22  08:58:36
Sample Mass:   0.0000 g                 Completed: 13/05/22  09:06:55
Temperature: 22.080 °C
Number of Purges:  10                   Equilibration Rate:  0.0345 kPag/min
Cell Volume: 110.6135 cm3               Expansion Volume:  73.6274 cm3


            Volume    Deviation   Density   Deviation   Elapsed  Temperature
   Cycle#     cm3        cm3       g/cm3      g/cm3      Time        °C
   ------  --------   ---------   -------   ---------  --------  -----------
      1      0.0101    -0.0343     0.0000     0.0000    0:04:55      21.995
      2      0.0234    -0.0210     0.0000     0.0000    0:06:07      22.074
      3      0.0997     0.0553     0.0000     0.0000    0:07:20      22.045


Average Volume:   0.0444 cm3            Standard Deviation:  0.0395 cm3
Average Density:  0.0000 g/cm3          Standard Deviation: 0.0000 g/cm3
</pre>"""

_BAD_REPORT_7 = """<pre>
                           AccuPycII 1345 V4.00
                            Serial Number: 4467
                         Density and Volume Report


Sample ID: Test this                    Started: 13/05/22  08:58:36
Sample Mass:   0.0000 g                 Completed: 13/05/22  09:06:55
Temperature: 22.080 °C
Number of Purges:  10
Cell Volume: 110.6135 cm3               Expansion Volume:  73.6274 cm3


            Volume    Deviation   Density   Deviation   Elapsed  Temperature
   Cycle#     cm3        cm3       g/cm3      g/cm3      Time        °C
   ------  --------   ---------   -------   ---------  --------  -----------
      1      0.0101    -0.0343     0.0000     0.0000    0:04:55      21.995
      2      0.0234    -0.0210     0.0000     0.0000    0:06:07      22.074
      3      0.0997     0.0553     0.0000     0.0000    0:07:20      22.045


Average Volume:   0.0444 cm3            Standard Deviation:  0.0395 cm3
Average Density:  0.0000 g/cm3          Standard Deviation: 0.0000 g/cm3
</pre>"""

_BAD_REPORT_8 = """<pre>
                           AccuPycII 1345 V4.00
                            Serial Number: 4467
                         Density and XXXX Report


Sample ID: Test this                    Started: 13/05/22  08:58:36
Sample Mass:   0.0000 g                 Completed: 13/05/22  09:06:55
Temperature: 22.080 °C
Number of Purges:  10                   Equilibration Rate:  0.0345 kPag/min
Cell Volume: 110.6135 cm3               Expansion Volume:  73.6274 cm3


            Volume    Deviation   Density   Deviation   Elapsed  Temperature
   Cycle#     cm3        cm3       g/cm3      g/cm3      Time        °C
   ------  --------   ---------   -------   ---------  --------  -----------
      1      0.0101    -0.0343     0.0000     0.0000    0:04:55      21.995
      2      0.0234    -0.0210     0.0000     0.0000    0:06:07      22.074
      3      0.0997     0.0553     0.0000     0.0000    0:07:20      22.045


Average Volume:   0.0444 cm3            Standard Deviation:  0.0395 cm3
Average Density:  0.0000 g/cm3          Standard Deviation: 0.0000 g/cm3
</pre>"""

_BAD_METHOD_A_1 = """<!-- saved from url=(0040)http://192.168.78.1/4467/untitled-3.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Seriennummer: 4467
                        Volumen-Bericht, korrigiert
                   Korrektur auf Basis Zellendimensionen


Probenname:                             Beginn: 23/05/22  13:09:51
Probengewicht:  67.0000 g               Ende: 23/05/22  13:14:57
Temperatur: 20.0 °C                     Geometrisches Vol.:   0.2500 in3
Spülzyklen:   1                         Intervall Dauer:    10 s
Zellvolumen:   6.7512 in3               Expansionsvolumen:   4.4992 in3
ZellXXXXdichte:  2.0000 g/cm3           Zellwanddichte:  2.0000 g/cm3
Sehnenlänge: 0.0394 in
Anzahl Häuete: 3


                                                         Zellwand+
                                                           Anteil
 Mess.    P1       P2     Volumen  Abweichung  Offen-   geschlossen Messzeit
  Nr     psig     psig      in3        in3   zelligk.%    Zellen %   (h:m:s)
------  -------  -------  -------- ---------- -------- ------------- -------
   1     3.8591   2.6854   -3.5646     0.0099  1505.10    -1405.10      0:01:43
   2     3.9332   2.7320   -3.5039     0.0706  1480.83    -1380.83      0:02:32
   3     3.9655   2.7693   -3.6879    -0.1134  1554.43    -1454.43      0:03:21
   4     3.9493   2.7515   -3.6064    -0.0319  1521.83    -1421.83      0:04:10
   5     3.9867   2.7696   -3.5096     0.0649  1483.09    -1383.09      0:04:59


Mittleres Volumen:  -3.5745 in3         Standardabweichung:  0.0681 in3


        -----------------------------------------------------------
        Volumen Zellwand:   2.0443 in3
        Prozentualer Anteil Zellwand: 817.72%
        Offenzelligkeit / %: 1509.05%
        Prozentualer Anteil Zellwand + geschlossene Zellen: -1409.05%
        -----------------------------------------------------------
</pre>
</body></html>"""

_BAD_METHOD_A_2 = """<!-- saved from url=(0040)http://192.168.78.1/4467/untitled-3.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Seriennummer: 4467
                        Volumen-Bericht, korrigiert
                   Korrektur auf Basis Zellendimensionen


Probenname:                             Beginn: 23/05/22  13:09:51
Probengewicht:  67.0000 g               Ende: 23/05/22  13:14:57
Temperatur: 20.0 °C                     Geometrisches Vol.:   0.2500 in3
Spülzyklen:   1                         Intervall Dauer:    10 s
Zellvolumen:   6.7512 in3               Expansionsvolumen:   4.4992 in3
Zellwanddichte:  2.0000 g/cm3           Aktive XXXXX: 1.5000 in2
Sehnenlänge: 0.0394 in
Anzahl Häuete: 3


                                                         Zellwand+
                                                           Anteil
 Mess.    P1       P2     Volumen  Abweichung  Offen-   geschlossen Messzeit
  Nr     psig     psig      in3        in3   zelligk.%    Zellen %   (h:m:s)
------  -------  -------  -------- ---------- -------- ------------- -------
   1     3.8591   2.6854   -3.5646     0.0099  1505.10    -1405.10      0:01:43
   2     3.9332   2.7320   -3.5039     0.0706  1480.83    -1380.83      0:02:32
   3     3.9655   2.7693   -3.6879    -0.1134  1554.43    -1454.43      0:03:21
   4     3.9493   2.7515   -3.6064    -0.0319  1521.83    -1421.83      0:04:10
   5     3.9867   2.7696   -3.5096     0.0649  1483.09    -1383.09      0:04:59


Mittleres Volumen:  -3.5745 in3         Standardabweichung:  0.0681 in3


        -----------------------------------------------------------
        Volumen Zellwand:   2.0443 in3
        Prozentualer Anteil Zellwand: 817.72%
        Offenzelligkeit / %: 1509.05%
        Prozentualer Anteil Zellwand + geschlossene Zellen: -1409.05%
        -----------------------------------------------------------
</pre>
</body></html>"""

_BAD_METHOD_A_3 = """<!-- saved from url=(0040)http://192.168.78.1/4467/untitled-3.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Seriennummer: 4467
                        Volumen-Bericht, korrigiert
                   Korrektur auf Basis Zellendimensionen


Probenname:                             Beginn: 23/05/22  13:09:51
Probengewicht:  67.0000 g               Ende: 23/05/22  13:14:57
Temperatur: 20.0 °C                     Geometrisches Vol.:   0.2500 in3
Spülzyklen:   1                         Intervall Dauer:    10 s
Zellvolumen:   6.7512 in3               Expansionsvolumen:   4.4992 in3
Zellwanddichte:  2.0000 g/cm3           Aktive Fläeche: 1.5000 in2
SehnenXXXlänge: 0.0394 in
Anzahl Häuete: 3


                                                         Zellwand+
                                                           Anteil
 Mess.    P1       P2     Volumen  Abweichung  Offen-   geschlossen Messzeit
  Nr     psig     psig      in3        in3   zelligk.%    Zellen %   (h:m:s)
------  -------  -------  -------- ---------- -------- ------------- -------
   1     3.8591   2.6854   -3.5646     0.0099  1505.10    -1405.10      0:01:43
   2     3.9332   2.7320   -3.5039     0.0706  1480.83    -1380.83      0:02:32
   3     3.9655   2.7693   -3.6879    -0.1134  1554.43    -1454.43      0:03:21
   4     3.9493   2.7515   -3.6064    -0.0319  1521.83    -1421.83      0:04:10
   5     3.9867   2.7696   -3.5096     0.0649  1483.09    -1383.09      0:04:59


Mittleres Volumen:  -3.5745 in3         Standardabweichung:  0.0681 in3


        -----------------------------------------------------------
        Volumen Zellwand:   2.0443 in3
        Prozentualer Anteil Zellwand: 817.72%
        Offenzelligkeit / %: 1509.05%
        Prozentualer Anteil Zellwand + geschlossene Zellen: -1409.05%
        -----------------------------------------------------------
</pre>
</body></html>"""

_BAD_METHOD_A_4 = """<!-- saved from url=(0040)http://192.168.78.1/4467/untitled-3.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Seriennummer: 4467
                        Volumen-Bericht, korrigiert
                   Korrektur auf Basis Zellendimensionen


Probenname:                             Beginn: 23/05/22  13:09:51
Probengewicht:  67.0000 g               Ende: 23/05/22  13:14:57
Temperatur: 20.0 °C                     Geometrisches Vol.:   0.2500 in3
Spülzyklen:   1                         Intervall Dauer:    10 s
Zellvolumen:   6.7512 in3               Expansionsvolumen:   4.4992 in3
ZellXXXdichte:  2.0000 g/cm3           Aktive Fläeche: 1.5000 in2
Sehnenlänge: 0.0394 in
Anzahl Häuete: 3


                                                         Zellwand+
                                                           Anteil
 Mess.    P1       P2     Volumen  Abweichung  Offen-   geschlossen Messzeit
  Nr     psig     psig      in3        in3   zelligk.%    Zellen %   (h:m:s)
------  -------  -------  -------- ---------- -------- ------------- -------
   1     3.8591   2.6854   -3.5646     0.0099  1505.10    -1405.10      0:01:43
   2     3.9332   2.7320   -3.5039     0.0706  1480.83    -1380.83      0:02:32
   3     3.9655   2.7693   -3.6879    -0.1134  1554.43    -1454.43      0:03:21
   4     3.9493   2.7515   -3.6064    -0.0319  1521.83    -1421.83      0:04:10
   5     3.9867   2.7696   -3.5096     0.0649  1483.09    -1383.09      0:04:59


Mittleres Volumen:  -3.5745 in3         Standardabweichung:  0.0681 in3


        -----------------------------------------------------------
        Volumen Zellwand:   2.0443 in3
        Prozentualer Anteil Zellwand: 817.72%
        Offenzelligkeit / %: 1509.05%
        Prozentualer Anteil Zellwand + geschlossene Zellen: -1409.05%
        -----------------------------------------------------------
</pre>
</body></html>"""

_BAD_METHOD_A_5 = """<!-- saved from url=(0040)http://192.168.78.1/4467/untitled-3.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Seriennummer: 4467
                        Volumen-Bericht, korrigiert
                   Korrektur auf Basis Zellendimensionen


Probenname:                             Beginn: 23/05/22  13:09:51
Probengewicht:  67.0000 g               Ende: 23/05/22  13:14:57
Temperatur: 20.0 °C                     Geometrisches Vol.:   0.2500 in3
Spülzyklen:   1                         Intervall Dauer:    10 s
Zellvolumen:   6.7512 in3               Expansionsvolumen:   4.4992 in3
Zellwanddichte:  2.0000 g/cm3           Aktive Fläeche: 1.5000 in2
Sehnenlänge: 0.0394 xx
Anzahl Häuete: 3


                                                         Zellwand+
                                                           Anteil
 Mess.    P1       P2     Volumen  Abweichung  Offen-   geschlossen Messzeit
  Nr     psig     psig      in3        in3   zelligk.%    Zellen %   (h:m:s)
------  -------  -------  -------- ---------- -------- ------------- -------
   1     3.8591   2.6854   -3.5646     0.0099  1505.10    -1405.10      0:01:43
   2     3.9332   2.7320   -3.5039     0.0706  1480.83    -1380.83      0:02:32
   3     3.9655   2.7693   -3.6879    -0.1134  1554.43    -1454.43      0:03:21
   4     3.9493   2.7515   -3.6064    -0.0319  1521.83    -1421.83      0:04:10
   5     3.9867   2.7696   -3.5096     0.0649  1483.09    -1383.09      0:04:59


Mittleres Volumen:  -3.5745 in3         Standardabweichung:  0.0681 in3


        -----------------------------------------------------------
        Volumen Zellwand:   2.0443 in3
        Prozentualer Anteil Zellwand: 817.72%
        Offenzelligkeit / %: 1509.05%
        Prozentualer Anteil Zellwand + geschlossene Zellen: -1409.05%
        -----------------------------------------------------------
</pre>
</body></html>"""

_BAD_METHOD_A_6 = """<!-- saved from url=(0040)http://192.168.78.1/4467/untitled-3.html -->
<html><head><meta http-equiv="Content-Type" content="text/html; charset=windows-1252"></head><body><pre>                           FoamPycII 1345 V4.00
                            Seriennummer: 4467
                        Volumen-Bericht, korrigiert
                   Korrektur auf Basis Zellendimensionen


Probenname:                             Beginn: 23/05/22  13:09:51
Probengewicht:  67.0000 g               Ende: 23/05/22  13:14:57
Temperatur: 20.0 °C                     Geometrisches Vol.:   0.2500 in3
Spülzyklen:   1                         Intervall Dauer:    10 s
Zellvolumen:   6.7512 in3               Expansionsvolumen:   4.4992 in3
Zellwanddichte:  2.0000 g/cm3           Aktive Fläeche: 1.5000 xx2
Sehnenlänge: 0.0394 in
Anzahl Häuete: 3


                                                         Zellwand+
                                                           Anteil
 Mess.    P1       P2     Volumen  Abweichung  Offen-   geschlossen Messzeit
  Nr     psig     psig      in3        in3   zelligk.%    Zellen %   (h:m:s)
------  -------  -------  -------- ---------- -------- ------------- -------
   1     3.8591   2.6854   -3.5646     0.0099  1505.10    -1405.10      0:01:43
   2     3.9332   2.7320   -3.5039     0.0706  1480.83    -1380.83      0:02:32
   3     3.9655   2.7693   -3.6879    -0.1134  1554.43    -1454.43      0:03:21
   4     3.9493   2.7515   -3.6064    -0.0319  1521.83    -1421.83      0:04:10
   5     3.9867   2.7696   -3.5096     0.0649  1483.09    -1383.09      0:04:59


Mittleres Volumen:  -3.5745 in3         Standardabweichung:  0.0681 in3


        -----------------------------------------------------------
        Volumen Zellwand:   2.0443 in3
        Prozentualer Anteil Zellwand: 817.72%
        Offenzelligkeit / %: 1509.05%
        Prozentualer Anteil Zellwand + geschlossene Zellen: -1409.05%
        -----------------------------------------------------------
</pre>
</body></html>"""

BAD_REPORTS = [
    _BAD_REPORT_1,
    _BAD_REPORT_2,
    _BAD_REPORT_3,
    _BAD_REPORT_4,
    _BAD_REPORT_5,
    _BAD_REPORT_6,
    _BAD_REPORT_7,
    _BAD_REPORT_8,
    _BAD_METHOD_A_1,
    _BAD_METHOD_A_2,
    _BAD_METHOD_A_3,
    _BAD_METHOD_A_4,
    _BAD_METHOD_A_5,
    _BAD_METHOD_A_6,
]

HTML_ROOT = """<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
<html>
 <head>
  <title>Index of /</title>
 </head>
 <body>
<h1>Index of /</h1>
  <table>
   <tr><th valign="top"><img src="icons/blank.gif" alt="[ICO]"></th><th><a href="index.html@C=N%3BO=D.html">Name</a></th><th><a href="index.html@C=M%3BO=A.html">Last modified</a></th><th><a href="index.html@C=S%3BO=A.html">Size</a></th><th><a href="index.html@C=D%3BO=A.html">Description</a></th></tr>
   <tr><th colspan="5"><hr></th></tr>
<tr><td valign="top"><img src="icons/folder.gif" alt="[DIR]"></td><td><a href="4466/index.html">4466/</a></td><td align="right">2022-05-13 09:09  </td><td align="right">  - </td><td>&nbsp;</td></tr>
<tr><td valign="top"><img src="icons/folder.gif" alt="[DIR]"></td><td><a href="4467/index.html">4467/</a></td><td align="right">2022-05-13 09:09  </td><td align="right">  - </td><td>&nbsp;</td></tr>
<tr><td valign="top"><img src="icons/folder.gif" alt="[DIR]"></td><td><a href="4474/index.html">4474/</a></td><td align="right">2022-05-13 09:09  </td><td align="right">  - </td><td>&nbsp;</td></tr>
   <tr><th colspan="5"><hr></th></tr>
</table>
<address>Apache/2.4.25 (Debian) Server at 192.168.140.26 Port 80</address>
</body></html>
"""

HTML_4466 = """<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
<html>
 <head>
  <title>Index of /4466</title>
 </head>
 <body>
<h1>Index of /4466</h1>
  <table>
   <tr><th valign="top"><img src="../icons/blank.gif" alt="[ICO]"></th><th><a href="index.html@C=N%3BO=D.html">Name</a></th><th><a href="index.html@C=M%3BO=A.html">Last modified</a></th><th><a href="index.html@C=S%3BO=A.html">Size</a></th><th><a href="index.html@C=D%3BO=A.html">Description</a></th></tr>
   <tr><th colspan="5"><hr></th></tr>
<tr><td valign="top"><img src="../icons/back.gif" alt="[PARENTDIR]"></td><td><a href="../index.html">Parent Directory</a></td><td>&nbsp;</td><td align="right">  - </td><td>&nbsp;</td></tr>
<tr><td valign="top"><img src="../icons/text.gif" alt="[TXT]"></td><td><a href="untitled-2.html">untitled-2.html</a></td><td align="right">2022-05-13 09:09  </td><td align="right"> 66 </td><td>&nbsp;</td></tr>
<tr><td valign="top"><img src="../icons/text.gif" alt="[TXT]"></td><td><a href="untitled.html">untitled.html</a></td><td align="right">2022-05-13 09:06  </td><td align="right"> 66 </td><td>&nbsp;</td></tr>
   <tr><th colspan="5"><hr></th></tr>
</table>
<address>Apache/2.4.25 (Debian) Server at 192.168.140.26 Port 80</address>
</body></html>"""

HTML_4467 = """<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
<html>
 <head>
  <title>Index of /4467</title>
 </head>
 <body>
<h1>Index of /4467</h1>
  <table>
   <tr><th valign="top"><img src="../icons/blank.gif" alt="[ICO]"></th><th><a href="index.html@C=N%3BO=D.html">Name</a></th><th><a href="index.html@C=M%3BO=A.html">Last modified</a></th><th><a href="index.html@C=S%3BO=A.html">Size</a></th><th><a href="index.html@C=D%3BO=A.html">Description</a></th></tr>
   <tr><th colspan="5"><hr></th></tr>
<tr><td valign="top"><img src="../icons/back.gif" alt="[PARENTDIR]"></td><td><a href="../index.html">Parent Directory</a></td><td>&nbsp;</td><td align="right">  - </td><td>&nbsp;</td></tr>
<tr><td valign="top"><img src="../icons/text.gif" alt="[TXT]"></td><td><a href="untitled-2.html">untitled-2.html</a></td><td align="right">2022-04-29 11:18  </td><td align="right">2.0K</td><td>&nbsp;</td></tr>
<tr><td valign="top"><img src="../icons/text.gif" alt="[TXT]"></td><td><a href="untitled-3.html">untitled-3.html</a></td><td align="right">2022-04-29 13:07  </td><td align="right">3.3K</td><td>&nbsp;</td></tr>
<tr><td valign="top"><img src="../icons/text.gif" alt="[TXT]"></td><td><a href="untitled-4.html">untitled-4.html</a></td><td align="right">2022-05-13 09:06  </td><td align="right">1.1K</td><td>&nbsp;</td></tr>
<tr><td valign="top"><img src="../icons/text.gif" alt="[TXT]"></td><td><a href="untitled-5.html">untitled-5.html</a></td><td align="right">2022-05-13 09:15  </td><td align="right">1.0K</td><td>&nbsp;</td></tr>
<tr><td valign="top"><img src="../icons/text.gif" alt="[TXT]"></td><td><a href="untitled.html">untitled.html</a></td><td align="right">2022-04-29 10:48  </td><td align="right">1.3K</td><td>&nbsp;</td></tr>
   <tr><th colspan="5"><hr></th></tr>
</table>
<address>Apache/2.4.25 (Debian) Server at 192.168.140.26 Port 80</address>
</body></html>"""

HTML_4474 = """<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
<html>
 <head>
  <title>Index of /4474</title>
 </head>
 <body>
<h1>Index of /4474</h1>
  <table>
   <tr><th valign="top"><img src="../icons/blank.gif" alt="[ICO]"></th><th><a href="index.html@C=N%3BO=D.html">Name</a></th><th><a href="index.html@C=M%3BO=A.html">Last modified</a></th><th><a href="index.html@C=S%3BO=A.html">Size</a></th><th><a href="index.html@C=D%3BO=A.html">Description</a></th></tr>
   <tr><th colspan="5"><hr></th></tr>
<tr><td valign="top"><img src="../icons/back.gif" alt="[PARENTDIR]"></td><td><a href="../index.html">Parent Directory</a></td><td>&nbsp;</td><td align="right">  - </td><td>&nbsp;</td></tr>
<tr><td valign="top"><img src="../icons/text.gif" alt="[TXT]"></td><td><a href="untitled-2.html">untitled-2.html</a></td><td align="right">2022-05-06 16:22  </td><td align="right">1.6K</td><td>&nbsp;</td></tr>
<tr><td valign="top"><img src="../icons/text.gif" alt="[TXT]"></td><td><a href="untitled-3.html">untitled-3.html</a></td><td align="right">2022-05-10 10:15  </td><td align="right"> 66 </td><td>&nbsp;</td></tr>
<tr><td valign="top"><img src="../icons/text.gif" alt="[TXT]"></td><td><a href="untitled-4.html">untitled-4.html</a></td><td align="right">2022-05-13 08:46  </td><td align="right">1.6K</td><td>&nbsp;</td></tr>
<tr><td valign="top"><img src="../icons/text.gif" alt="[TXT]"></td><td><a href="untitled-5.html">untitled-5.html</a></td><td align="right">2022-05-13 09:07  </td><td align="right">940 </td><td>&nbsp;</td></tr>
<tr><td valign="top"><img src="../icons/text.gif" alt="[TXT]"></td><td><a href="untitled-6.html">untitled-6.html</a></td><td align="right">2022-05-13 09:14  </td><td align="right"> 66 </td><td>&nbsp;</td></tr>
   <tr><th colspan="5"><hr></th></tr>
</table>
<address>Apache/2.4.25 (Debian) Server at 192.168.140.26 Port 80</address>
</body></html>"""


class TestParser(TestCase):
    """This class is used to test the accupyc1345 report parser."""

    def test_accu(self):
        "Test parsing of standard accupyc reports."
        accu.parse_ascii_report(_STD_REPORT_1, '2022-05-13 09:06')
        accu.parse_ascii_report(_STD_REPORT_1, '2022-05-13 09:06')
        accu.parse_ascii_report(_STD_REPORT_1A, '2021-05-13 09:06')
        self.assertEqual(1, Instrument.objects.filter(model='1345').count())
        inst1345 = Instrument.objects.get(model='1345')
        self.assertEqual(2, AnalysisResult1345.objects.filter(instrument=inst1345).count())

        accu.parse_ascii_report(_NO_DATA_REPORT, '2022-05-13 09:06')


class TestResults(TestCase):
    """This class is used to test the accupyc1345 results calculation."""

    def test_accu(self):
        "Test parsing of standard accupyc reports."
        accu.parse_ascii_report(_STD_REPORT_2, '2022-05-13 09:06')
        res = AnalysisResult1345.objects.latest('pk')
        ave_vol = res.results.get(result_title="Volume").value
        ave_den = res.results.get(result_title="Density").value
        last_den = res.results.get(result_title="Last Density").value
        self.assertEqual(res.name, "Sample ID for Stefan")
        self.assertAlmostEqual(ave_vol, 6.3605, places=4)
        self.assertAlmostEqual(ave_den, 0.0000, places=4)
        self.assertAlmostEqual(last_den, 0.0000, places=4)

        accu.parse_ascii_report(_STD_REPORT_3, '2022-05-23 12:00')
        res = AnalysisResult1345.objects.latest('pk')
        ave_vol = res.results.get(result_title="Volume").value
        ave_den = res.results.get(result_title="Density").value
        last_den = res.results.get(result_title="Last Density").value
        self.assertAlmostEqual(res.temperature, 23.990, places=3)
        self.assertEqual(res.endby, 'E')
        self.assertAlmostEqual(res.equilibration_rate, 0.0060, places=4)
        self.assertAlmostEqual(ave_vol, 6.3612, places=4)
        self.assertAlmostEqual(ave_den, 0.0000, places=4)
        self.assertAlmostEqual(last_den, 0.0000, places=4)

        accu.parse_ascii_report(_STD_REPORT_4, '2022-05-23 12:00')
        res = AnalysisResult1345.objects.latest('pk')
        ave_vol = res.results.get(result_title="Volume").value
        stddev_vol = res.results.get(result_title="Volume").std_dev
        self.assertEqual(res.endby, 'F')
        self.assertAlmostEqual(res.interval_time, 30, places=4)
        self.assertAlmostEqual(ave_vol, 50.9918, places=4)
        self.assertAlmostEqual(stddev_vol, 0.0905, places=4)

        accu.parse_ascii_report(_STD_REPORT_5, '2022-05-23 12:00')
        res = AnalysisResult1345.objects.latest('pk')
        ave_vol = res.results.get(result_title="Volume").value
        stddev_vol = res.results.get(result_title="Volume").std_dev
        self.assertAlmostEqual(ave_vol, -22.6175, places=4)
        self.assertAlmostEqual(stddev_vol, 0.0075, places=4)

        accu.parse_ascii_report(_STD_REPORT_6, '2022-05-23 12:00')
        res = AnalysisResult1345.objects.latest('pk')
        ave_vol = res.results.get(result_title="Volume").value
        stddev_vol = res.results.get(result_title="Volume").std_dev
        self.assertAlmostEqual(ave_vol, 6.3609, places=4)
        self.assertAlmostEqual(stddev_vol, 0.0005, places=4)

        accu.parse_ascii_report(_STD_REPORT_7, '2022-05-23 12:00')
        res = AnalysisResult1345.objects.latest('pk')
        ave_vol = res.results.get(result_title="Volume").value
        stddev_vol = res.results.get(result_title="Volume").std_dev
        self.assertAlmostEqual(ave_vol, 5.8113, places=4)
        self.assertAlmostEqual(stddev_vol, 0.0172, places=4)

        accu.parse_ascii_report(_STD_REPORT_8, '2022-05-23 12:00')
        res = AnalysisResult1345.objects.latest('pk')
        ave_vol = res.results.get(result_title="Volume").value
        stddev_vol = res.results.get(result_title="Volume").std_dev
        self.assertAlmostEqual(ave_vol, 5.7986, places=4)
        self.assertAlmostEqual(stddev_vol, 0.0078, places=4)

        accu.parse_ascii_report(_STD_REPORT_9, '2022-05-23 12:00')
        res = AnalysisResult1345.objects.latest('pk')
        ave_vol = res.results.get(result_title="Volume").value
        stddev_vol = res.results.get(result_title="Volume").std_dev
        self.assertAlmostEqual(ave_vol, 5.8347, places=4)
        self.assertAlmostEqual(stddev_vol, 0.0466, places=4)

        accu.parse_ascii_report(_STD_REPORT_10, '2022-05-23 12:00')
        res = AnalysisResult1345.objects.latest('pk')
        ave_vol = res.results.get(result_title="Volume").value
        stddev_vol = res.results.get(result_title="Volume").std_dev
        self.assertAlmostEqual(ave_vol, 5.7972, places=4)
        self.assertAlmostEqual(stddev_vol, 0.0295, places=3)

    def test_excluded(self):
        accu.parse_ascii_report(_STD_REPORT_11, '2022-05-23 12:00')
        res = AnalysisResult1345.objects.latest('pk')
        self.assertEqual(res.expansion.num, 9)
        self.assertEqual(res.expansion.excludes, (1, 1, 1, 1, 0, 0, 0, 0, 0))
        ave_vol = res.results.get(result_title="Volume").value
        stddev_vol = res.results.get(result_title="Volume").std_dev
        self.assertAlmostEqual(ave_vol, -2.1522, places=4)
        self.assertAlmostEqual(stddev_vol, 0.0456, places=3)

    def test_bad_report(self):
        for report in BAD_REPORTS:
            self.assertRaises(
                accu.BadReport,
                lambda report=report: accu.parse_ascii_report(report, '2022-05-23 12:00')
            )

    def test_foam_method(self):
        "Test foam pyc method a parsing."
        for data, result, places in FOAM_TEST_DATA:
            accu.parse_ascii_report(data, '2022-05-13 09:06')
            res = AnalysisResult1345.objects.get()
            self.assertAlmostEqual(res.results.get().value, result, places=places)
            res.delete()  # delete it to make sure the next one is created.

    def test_locale(self):
        "Test parsing of standard accupyc reports."
        settings = Settings.objects.get()
        settings.time_zone = "UTC"
        settings.save()
        accu.parse_ascii_report(_STD_REPORT_2, '2022-05-13 09:06')
        res = AnalysisResult1345.objects.latest('pk')
        self.assertEqual(res.start_time.isoformat(), "2022-05-23T08:46:03+00:00")
        self.assertEqual(res.end_time.isoformat(), "2022-05-23T09:11:50+00:00")
        res.delete()

        # If the times are interpreted as Eastern timezone, the utc time should be 5 hours later.
        settings.time_zone = "EST"
        settings.save()
        accu.parse_ascii_report(_STD_REPORT_2, '2022-05-13 09:06')
        res = AnalysisResult1345.objects.latest('pk')
        self.assertEqual(res.start_time.isoformat(), "2022-05-23T13:46:03+00:00")
        self.assertEqual(res.end_time.isoformat(), "2022-05-23T14:11:50+00:00")


def _mock_parse_report(report, iso_file_date):
    _mock_parse_report.called.append((report, iso_file_date))


class TestHTML(TestCase):
    """This class is used to the parsing of the html directories."""

    def setUp(self):
        self.requests = accu.requests
        accu.requests = mock_requsts
        self.org_parse = accu.parse_ascii_report
        _mock_parse_report.called = []
        accu.parse_ascii_report = _mock_parse_report

    def tearDown(self):
        accu.requests = self.requests
        accu.parse_ascii_report = self.org_parse

    def test_html_dir(self):
        with mock_requsts.http_context() as site:
            _setup_site(site, 'localhost')
            old_date = timezone.now() - datetime.timedelta(days=2)
            LegacyInstrument.objects.create(
                model='1345',
                ip_addr='localhost',
                last_communicated=old_date,
            )
            self.assertEqual(LegacyInstrument.objects.get().last_communicated, old_date)
            self.assertTrue(accu.check_available('localhost'))
            self.assertFalse(accu.check_available('notthere'))
            accu.scrape_all()
            self.assertNotEqual(LegacyInstrument.objects.get().last_communicated, old_date)
        self.assertEqual(
            _mock_parse_report.called, [
                (_BAD_REPORT_1, '2022-04-29 11:18'),
                (_METHOD_B_2, '2022-04-29 13:07'),
            ]
        )

class TestHTMLError(TestCase):
    """This class is used to the parsing of the html directories."""

    def setUp(self):
        self.requests = accu.requests
        accu.requests = mock_requsts

    def tearDown(self):
        accu.requests = self.requests

    def test_html_dir(self):
        with mock_requsts.http_context() as site:
            _setup_site(site, 'localhost')
            old_date = timezone.now() - datetime.timedelta(days=2)
            LegacyInstrument.objects.create(
                model='1345',
                ip_addr='localhost',
                last_communicated=old_date,
            )
            self.assertEqual(LegacyInstrument.objects.get().last_communicated, old_date)
            self.assertTrue(accu.check_available('localhost'))
            self.assertFalse(accu.check_available('notthere'))
            accu.scrape_all()
            accu.scrape_all()  # scrape twice to ensure only one error is set.
            self.assertNotEqual(LegacyInstrument.objects.get().last_communicated, old_date)

        self.assertEqual(
            LogMessage.objects.filter(message__startswith="Cannot parse report").count(), 1
        )


class TestReport(TestCase):
    "This class is used to test the reports generated from converted data."

    def test_accu(self):
        pass

    def test_method_a(self):
        accu.parse_ascii_report(_METHOD_A_5, '2022-05-13 09:06')
        anl = AnalysisResult1345.objects.last()
        model = cpp.CReportModel("")
        i1350.AddAccuPycResultsScreen(model, accu_or_foam_results_from_anl(anl))
        rpt = json.loads(model.AsJson())
        method_titles, method_values = rpt['pages'][1]['items'][1]['columns']
        method_titles = method_titles['column_string']
        method_values = method_values['column_string']
        match = 0
        for title, value in zip(method_titles, method_values):
            if title['format'] == 'Geometric Volume:':
                match = match + 1
                self.assertAlmostEqual(1.0 * pow(2.54, 3), value['values'][0]['value'], places=4)
        self.assertEqual(match, 1)

    def test_coverage(self):  # pylint: disable=no-self-use
        "Test the 1345 std and foam report generation just to test coverage"
        accu.parse_ascii_report(_STD_REPORT_1, '2022-05-13 09:06')
        anl = AnalysisResult1345.objects.get()
        model = cpp.CReportModel("")
        i1350.AddAccuPycResultsScreen(model, accu_or_foam_results_from_anl(anl))
        json.loads(model.AsJson())
        anl.delete()
        for data, _, _ in FOAM_TEST_DATA:
            accu.parse_ascii_report(data, '2022-05-13 09:06')
            anl = AnalysisResult1345.objects.get()
            model = cpp.CReportModel("")
            i1350.AddAccuPycResultsScreen(model, accu_or_foam_results_from_anl(anl))
            json.loads(model.AsJson())
            anl.delete()


# =================================================================================================
def _setup_site(site, root):
    site.add_file(f'http://{root}', f'index.html', HTML_ROOT)
    site.add_file(f'http://{root}', f'4466/index.html', HTML_4466)
    site.add_file(f'http://{root}', f'4467/index.html', HTML_4467)
    site.add_file(f'http://{root}', f'4474/index.html', HTML_4474)
    site.add_file(f'http://{root}', f'4467/untitled-2.html', _BAD_REPORT_1)
    site.add_file(f'http://{root}', f'4467/untitled-3.html', _METHOD_B_2)
