"""Tests for the migration that splits the AnalysisResults to a base and derived class."""
# pylint: disable=invalid-name,missing-function-docstring,missing-class-docstring,protected-access,too-many-locals
from django.utils import timezone
from django_test_migrations.contrib.unittest_case import MigratorTestCase


class TestAnalysisResultMigration(MigratorTestCase):
    """This class is used to test direct migrations."""

    migrate_from = ('pyc_sample', '0050_initial_inst_settings')
    migrate_to = ('pyc_sample', '0051_analysis_result_base')

    def prepare(self):
        """Prepare some data before the migration."""

        def _add_insert(name, kind):
            return OldInsert.objects.create(
                name=name,
                volume=1.0,
                temperature=22.0,
                thermal_expansion_um_per_mk=0.0,
                kind=kind,
                is_method=False,
            )

        def _add_prm(name, cup, insert):
            return OldAnalysisParameters.objects.create(
                name=name,
                is_method=False,
                gas=OldGas.objects.get(name="Helium"),
                cup=cup,
                insert=insert,
            )

        def _add_cal(cup, ref):
            return OldCalibration.objects.create(
                state='C',
                kind='C',
                gas=OldGas.objects.get(name="Helium"),
                instrument=OldInstrument.objects.get(),
                ref_ball=ref,
                cup=cup,
                last_updated=timezone.now(),
            )

        def _add_result():
            return OldAnalysisReult.objects.create(
                state='C',
                start_time=timezone.now(),
                end_time=timezone.now(),
                last_updated=timezone.now(),
                instrument=OldInstrument.objects.get(),
                mass=1.234,
                name='result name',
                parameters=OldAnalysisParameters.objects.first(),
                calibration=OldCalibration.objects.first(),
            )

        # pylint: disable=invalid-name
        OldInstrument = self.old_state.apps.get_model('pyc_sample', 'Instrument')
        OldGas = self.old_state.apps.get_model('pyc_sample', 'Gas')
        OldAnalysisParameters = self.old_state.apps.get_model('pyc_sample', 'AnalysisParameters')
        OldAnalysisReult = self.old_state.apps.get_model('pyc_sample', 'AnalysisResult')
        OldInsert = self.old_state.apps.get_model('pyc_sample', 'Insert')
        OldCalibration = self.old_state.apps.get_model('pyc_sample', 'Calibration')

        c1 = _add_insert("Cup 1", 'C')
        r1 = _add_insert("Ref 1", 'R')
        c2 = _add_insert("Cup 2", 'C')
        i2 = _add_insert("Ins 2", 'I')

        _add_prm("Prm 1", c1, i2)
        _add_cal(c2, r1)
        _add_result()

    def test_results(self):
        NewAnalysisResult1350 = self.new_state.apps.get_model('pyc_sample', 'AnalysisResult1350')
        NewAnalysisResult = self.new_state.apps.get_model('pyc_sample', 'AnalysisResult')
        self.assertEqual(1, len(NewAnalysisResult.objects.all()))
        self.assertEqual(1, len(NewAnalysisResult1350.objects.all()))
