"""Tests for the Insert model and associated functionality."""
# pylint: disable=invalid-name,missing-function-docstring,missing-class-docstring,protected-access,too-many-locals
from django.utils import timezone
from django_test_migrations.contrib.unittest_case import MigratorTestCase


class TestWithoutData(MigratorTestCase):
    """This class is used to test direct migrations."""

    migrate_from = ('pyc_sample', '0049_last_updated')
    migrate_to = ('pyc_sample', '0050_initial_inst_settings')

    def prepare(self):
        """Make sure we have no data."""
        OldInstrument = self.old_state.apps.get_model('pyc_sample', 'Instrument')
        OldSettings = self.old_state.apps.get_model('pyc_sample', 'Settings')
        self.assertEqual(len(OldInstrument.objects.all()), 0)
        self.assertEqual(len(OldSettings.objects.all()), 0)

    def test_inserted(self):
        NewInstrument = self.new_state.apps.get_model('pyc_sample', 'Instrument')
        NewSettings = self.new_state.apps.get_model('pyc_sample', 'Settings')
        self.assertEqual(len(NewInstrument.objects.all()), 1)
        self.assertEqual(len(NewSettings.objects.all()), 1)


class TestWithData(MigratorTestCase):
    """This class is used to test direct migrations."""

    migrate_from = ('pyc_sample', '0049_last_updated')
    migrate_to = ('pyc_sample', '0050_initial_inst_settings')

    def prepare(self):
        """Make sure we have no data."""
        OldInstrument = self.old_state.apps.get_model('pyc_sample', 'Instrument')
        OldSettings = self.old_state.apps.get_model('pyc_sample', 'Settings')
        self.assertEqual(len(OldInstrument.objects.all()), 0)
        self.assertEqual(len(OldSettings.objects.all()), 0)
        OldInstrument.objects.create(
            serial='0000', is_local=True, kind='T', last_updated=timezone.now()
        )
        OldSettings.objects.create()
        self.assertEqual(len(OldInstrument.objects.all()), 1)
        self.assertEqual(len(OldSettings.objects.all()), 1)

    def test_inserted(self):
        NewInstrument = self.new_state.apps.get_model('pyc_sample', 'Instrument')
        NewSettings = self.new_state.apps.get_model('pyc_sample', 'Settings')
        self.assertEqual(len(NewInstrument.objects.all()), 1)
        self.assertEqual(len(NewSettings.objects.all()), 1)
