"""Tests for the Insert model and associated functionality."""
# pylint: disable=invalid-name,missing-function-docstring,missing-class-docstring,protected-access
from django_test_migrations.contrib.unittest_case import MigratorTestCase


class TestMigration(MigratorTestCase):
    """This class is used to test direct migrations."""

    migrate_from = ('pyc_sample', '0047_insert_methods_and_copy')
    migrate_to = ('pyc_sample', '0048_save_inst_therm_expan_in_cal')

    def prepare(self):
        """Prepare some data before the migration."""

        def _add_insert(name, kind, is_method=True):
            return OldInsert.objects.create(
                name=name,
                volume=1.0,
                temperature=22.0,
                thermal_expansion_um_per_mk=0.0,
                kind=kind,
                is_method=is_method,
            )

        def _add_cal(cup, ref):
            return OldCalibration.objects.create(
                state='C',
                kind='C',
                gas=OldGas.objects.get(name="Helium"),
                instrument=OldInstrument.objects.get(),
                ref_ball=ref,
                cup=cup,
            )

        # pylint: disable=invalid-name
        OldInstrument = self.old_state.apps.get_model('pyc_sample', 'Instrument')
        OldGas = self.old_state.apps.get_model('pyc_sample', 'Gas')
        OldInstrument.objects.create(
            serial='0000', is_local=True, kind='T', thermal_expansion_um_per_mk=123 / 1e-6
        )
        OldInsert = self.old_state.apps.get_model('pyc_sample', 'Insert')
        OldCalibration = self.old_state.apps.get_model('pyc_sample', 'Calibration')

        c1 = _add_insert("Cup 1", 'C')
        r1 = _add_insert("Ref 1", 'R')
        _add_cal(c1, r1)

    def test_migration_main0003(self):
        """Run the test itself."""
        # pylint: disable=invalid-name
        NewCalibration = self.new_state.apps.get_model('pyc_sample', 'Calibration')

        # make sure the calibration instrument expansion was copied.
        cal = NewCalibration.objects.first()
        self.assertAlmostEqual(cal.instrument_thermal_expansion_um_per_mk, 123 / 1e-6)
