'''url configuration for pyc_sample app'''

from django.urls import path
from mic_python_lib import inst_scripts
from mic_python_lib.log_query import url_list
from mic_python_lib.quantity_formatter import init_units_view
from mic_python_lib.rest import make_json_view

from mic_python_lib.settings_views import (
    about_video_list_view,
    javascript_catalog_view,
    get_settings_general_view,
    settings_time_view,
    ui_settings_network_view,
    ui_settings_speaker_view,
    SettingsExportView,
    SettingsSMBPrinterView,
    password_protected_view,
)
import mic_python_lib.blocked_ui as bui
import mic_python_lib.sw_deb_upgrade_views as sw

from i1350 import (
    GetVersionInfo1350,
    UDPLogQueryUserResponded,
    UDPLogQueryInputUserResponded,
)

from .services import (
    analysis_done,
    analysis_run_data,
    analysis_set_equilibration,
    analysis_start,
    calibration_done,
    calibration_run_data,
    calibration_start,
    calibration_reset,
    calibration_user_save,
    idle_cancel,
    hwcal_save_pressure,
    hwcal_save_rtd,
    hwcal_start,
    initialize_analysis,
    insert_measure_start,
    insmeas_done,
    insmeas_redirect,
    insmeas_run_data,
    operation_cancel,
    operation_skip,
    other_operation_done,
    other_operation,
    reset_to_factory_defaults,
    reset_to_pristine_defaults,
    save_diagnostics,
    set_guided_setup_page,
)

from .views import (
    LegacyView,
    ui_anl_start,
    ui_operation_status,
    ui_anl_inprocess,
    ui_cal_start,
    ui_cal_inprocess,
    ui_cal_user,
    ui_edit_method,
    make_insert_view,
    ui_insert_measure,
    ui_insmeas_inprocess,
    ui_about,
    ui_anl_review_report,
    ui_cal_review_history,
    ui_cal_review_report,
    ui_results_edit_view,
    ui_review_done,
    ui_service_factory_reset,
    ui_service_instrument,
    ui_service_calibrations,
    ui_sample_results,
    ui_sort_filter_view,
    ui_settings_display,
    get_settings_1350_view,
    hwcal_results_view,
    settings_general_view,
    ScriptInterface1350,
)

from .settings_service import (
    hw_get_gas,
    hw_set_valve_view,
    hw_state_view,
    hw_set_temperature,
    hw_set_gas,
    hw_set_temp_control_view,
    hw_set_led,
    pcb_sw_update_avail,
    pcb_sw_update,
)

from . import rest_api

# for polling functions, disable the slow timezone middleware.
hw_state_view.ignore_time = True
ui_operation_status.ignore_time = True

app_name = 'pyc_sample'


_view_urls = [ # pylint: disable=invalid-name
    path('init_anal/', make_json_view(initialize_analysis), name='init_anal'),
    path('equildata/', make_json_view(analysis_set_equilibration), name='equil_data'),
    path('anldata/', make_json_view(analysis_run_data), name='anl_data'),
    path('anldone/', make_json_view(analysis_done), name='anl_done'),
    path('opercancel/', make_json_view(operation_cancel), name='oper_cancel'),
    path('operskip/', make_json_view(operation_skip), name='oper_skip'),
    path('anlstart/', make_json_view(analysis_start), name='anl_start'),
    path('calstart/', make_json_view(calibration_start), name='cal_start'),
    path('idlecancel/', make_json_view(idle_cancel), name='idle_cancel'),
    path('ui_anl_start/', ui_anl_start.as_view(), name='ui_anl_start'),
    path('ui_operation_status/', ui_operation_status, name='ui_operation_status'),
    path('ui_anl_inprocess/<int:anl_id>/', ui_anl_inprocess, name='ui_anl_inprocess'),
    path('ui_cal_start/', ui_cal_start.as_view(), name='ui_cal_start'),
    path('ui_cal_inprocess/', ui_cal_inprocess, name='ui_cal_inprocess'),
    path('ui_cal_reset/', make_json_view(calibration_reset), name='ui_cal_reset'),
    path('ui_cal_user_save/', make_json_view(calibration_user_save), name='ui_cal_user_save'),
    path('ui_cal_user/', ui_cal_user, name='ui_cal_user'),
    path('ui_results_edit/', ui_results_edit_view, name='ui_results_edit'),
    path('ui_review_done/', ui_review_done, name='ui_review_done'),
    path('ui_edit_method/', ui_edit_method.as_view(), name='ui_edit_method'),
    path('ui_edit_insert/', make_insert_view("I"), name='ui_edit_insert'),
    path('ui_insert_measure/', ui_insert_measure.as_view(), name='ui_insert_measure'),
    path('insert_measure_start/', make_json_view(insert_measure_start),
         name='insert_measure_start'),
    path('ui_insmeas_inprocess/<int:anl_id>/', ui_insmeas_inprocess, name='ui_insmeas_inprocess'),
    path('insmeas_run_data/', make_json_view(insmeas_run_data), name='insmeas_run_data'),
    path('insmeas_done/', make_json_view(insmeas_done), name='insmeas_done'),
    path('insmeas_redirect/', make_json_view(insmeas_redirect), name='insmeas_redirect'),
    path('ui_edit_reference/', make_insert_view("R"), name='ui_edit_reference'),
    path('ui_edit_cup/', make_insert_view("C"), name='ui_edit_cup'),
    path('ui_edit_legacy/', LegacyView.as_view(), name='ui_edit_legacy'),
    path('caldata/', make_json_view(calibration_run_data), name='cal_data'),
    path('caldone/', make_json_view(calibration_done), name='cal_done'),
    path('ui_about/', ui_about, name='ui_about'),
    path('ui_anl_review_report/<int:anl_id>/', ui_anl_review_report, name='ui_anl_review_report'),
    path('ui_cal_review_report/<int:cal_id>/', ui_cal_review_report, name='ui_cal_review_report'),
    path('ui_cal_review_history/<str:which>/', ui_cal_review_history, name='ui_cal_review_history'),
    path('ui_service_factory_reset/', ui_service_factory_reset.as_view(),
         name='ui_service_factory_reset'),
    path('ui_service_instrument/', ui_service_instrument.as_view(), name='ui_service_instrument'),
    path('ui_service_calibrations/', ui_service_calibrations, name='ui_service_cal'),
    path('ui_sample_results/', ui_sample_results, name='ui_sample_results'),
    path('ui_sample_results/sort_filter/', ui_sort_filter_view.as_view(), name='ui_sort_filter'),
    path('ui_settings_display/', ui_settings_display.as_view(), name='ui_settings_display'),
    path('get_settings_1350/', get_settings_1350_view, name='get_settings_1350'),
    path('ui_service_password/', password_protected_view, {'username': 'service'},
         name='ui_password'),
    path('reset_factory_defaults/', make_json_view(reset_to_factory_defaults),
         name='reset_factory_defaults'),
    path('reset_pristine_defaults/',
         make_json_view(lambda: reset_to_pristine_defaults("1350analysis")),
         name='reset_pristine_defaults'),
    path('save_diagnostics/', make_json_view(save_diagnostics), name='save_diagnostics'),
    path('other_operation/', make_json_view(other_operation), name='other_operation'),

    path('hw_state/', hw_state_view, name='hw_state'),
    path('hw_set_valve/', hw_set_valve_view, name='hw_set_valve'),
    path('hw_set_temperature/', hw_set_temperature.as_view(), name='hw_set_temperature'),
    path('hw_get_gas/', make_json_view(hw_get_gas), name='hw_get_gas'),
    path('hw_set_gas/', hw_set_gas.as_view(), name='hw_set_gas'),
    path('hw_set_temp_control/', hw_set_temp_control_view, name='hw_set_temp_control'),
    path('hw_set_led/', hw_set_led.as_view(), name='hw_set_led'),
    path('hwcal_start/', make_json_view(hwcal_start), name='hwcal_start'),
    path('hwcal_results/<str:which>/', hwcal_results_view, name='hwcal_results'),
    path('hwcal_save_pressure/', make_json_view(hwcal_save_pressure), name='hwcal_save_pressure'),
    path('hwcal_save_rtd/', make_json_view(hwcal_save_rtd), name='hwcal_save_rtd'),
    path('otheroper_done/', make_json_view(other_operation_done), name='otheroper_done'),
    path('pcbsw_update_avail/', make_json_view(pcb_sw_update_avail), name='pcbsw_update_avail'),
    path('pcbsw_update/', make_json_view(pcb_sw_update), name='pcbsw_update'),
    path('video/<str:tag>/', about_video_list_view, name='video-tips'),
]

# mic-python-lib units, and language/general settings urls.
_generic_urls = [ # pylint: disable=invalid-name
    path('initunits/', init_units_view),
    path('jsi18n/', javascript_catalog_view, name='javascript-catalog'),
    path('ui_settings_general/', settings_general_view, name='ui_settings_general'),
    path('ui_settings_time/', settings_time_view, name='ui_settings_time'),
    path('ui_settings_network/', ui_settings_network_view, name='ui_settings_network'),
    path('ui_settings_export/', SettingsExportView.as_view(), name='ui_settings_export'),
    path('ui_settings_smbprinter/', SettingsSMBPrinterView.as_view(),
         name='ui_settings_smbprinter'),
    path('ui_settings_speaker/', ui_settings_speaker_view, name='ui_settings_speaker_view'),
    path('get_settings_general/', get_settings_general_view, name='get_settings_general'),
    path('set_guided_setup_page/', make_json_view(set_guided_setup_page),
         name='set_guided_setup_page'),
    path('sw_update_version/', sw.make_sw_update_version_view('1350', GetVersionInfo1350())),
    path('sw_update/', sw.make_sw_update_view('1350')),
    path('blocked_exit/', bui.remove_from_list_view),
    path('blocked_state/', bui.state_view),
    path('blocked_block/', bui.block_view),
]

urlpatterns = (
    _view_urls + _generic_urls +
    url_list('log_query/', UDPLogQueryUserResponded, UDPLogQueryInputUserResponded) +
    inst_scripts.url_list("scripts/", ScriptInterface1350()) +
    rest_api.urlpatterns
)
